@@ -49,47 +49,47 @@
 /* ************************************************************************ */
 
 // Declaration
-#include "CMakePlugin.h"
-#include "processreaderthread.h"
-#include "asyncprocess.h"
 #include "CMakeBuilder.h"
+#include "CMakePlugin.h"
+#include "ICompilerLocator.h"
+#include "asyncprocess.h"
+#include "processreaderthread.h"
 
 // wxWidgets
 #include <wx/app.h>
-#include <wx/stdpaths.h>
-#include <wx/msgdlg.h>
-#include <wx/xrc/xmlres.h>
-#include <wx/mimetype.h>
-#include <wx/menu.h>
+#include <wx/busyinfo.h>
 #include <wx/dir.h>
 #include <wx/event.h>
-#include <wx/busyinfo.h>
+#include <wx/menu.h>
+#include <wx/mimetype.h>
+#include <wx/msgdlg.h>
+#include <wx/stdpaths.h>
+#include <wx/xrc/xmlres.h>
 
 // CodeLite
+#include "async_executable_cmd.h"
+#include "build_config.h"
+#include "build_settings_config.h"
+#include "build_system.h"
+#include "detachedpanesinfo.h"
+#include "dirsaver.h"
+#include "dockablepane.h"
 #include "environmentconfig.h"
 #include "event_notifier.h"
+#include "file_logger.h"
 #include "globals.h"
-#include "dirsaver.h"
+#include "macromanager.h"
 #include "procutils.h"
 #include "project.h"
 #include "workspace.h"
-#include "build_settings_config.h"
-#include "build_config.h"
-#include "build_system.h"
-#include "file_logger.h"
-#include "macromanager.h"
-#include "async_executable_cmd.h"
-#include "dockablepane.h"
-#include "detachedpanesinfo.h"
 
 // CMakePlugin
 #include "CMake.h"
 #include "CMakeGenerator.h"
+#include "CMakeHelpTab.h"
+#include "CMakeProjectSettings.h"
 #include "CMakeSettingsDialog.h"
 #include "CMakeSettingsManager.h"
-#include "CMakeProjectSettings.h"
-#include "CMakeGenerator.h"
-#include "CMakeHelpTab.h"
 
 /* ************************************************************************ */
 /* VARIABLES                                                                */
@@ -166,24 +166,22 @@ CMakePlugin::CMakePlugin(IManager* manager)
     m_shortName = "CMakePlugin";
 
     // Create CMake configuration file
-    m_configuration.reset(new CMakeConfiguration(
-        clStandardPaths::Get().GetUserDataDir() + wxFileName::GetPathSeparator() + "config/cmake.ini"));
+    m_configuration.reset(new CMakeConfiguration(clStandardPaths::Get().GetUserDataDir() +
+                                                 wxFileName::GetPathSeparator() + "config/cmake.ini"));
 
     // Create cmake application
     m_cmake.reset(new CMake(m_configuration->GetProgramPath()));
 
     Notebook* book = m_mgr->GetWorkspacePaneNotebook();
-    cmakeImages images;
-    const wxBitmap& bmp = images.Bitmap("cmake_16");
-
+    auto images = book->GetBitmaps();
     if(IsPaneDetached()) {
-        DockablePane* cp =
-            new DockablePane(book->GetParent()->GetParent(), book, HELP_TAB_NAME, false, bmp, wxSize(200, 200));
+        DockablePane* cp = new DockablePane(book->GetParent()->GetParent(), book, HELP_TAB_NAME, false,
+                                            images->Add("cmake"), wxSize(200, 200));
         m_helpTab = new CMakeHelpTab(cp, this);
         cp->SetChildNoReparent(m_helpTab);
     } else {
         m_helpTab = new CMakeHelpTab(book, this);
-        book->AddPage(m_helpTab, HELP_TAB_NAME, false, bmp);
+        book->AddPage(m_helpTab, HELP_TAB_NAME, false, images->Add("cmake"));
         m_mgr->AddWorkspaceTab(HELP_TAB_NAME);
     }
 
@@ -234,7 +232,8 @@ wxString CMakePlugin::GetSelectedProjectConfig() const
 {
     BuildConfigPtr configPtr = GetSelectedBuildConfig();
 
-    if(configPtr) return configPtr->GetName();
+    if(configPtr)
+        return configPtr->GetName();
 
     return wxEmptyString;
 }
@@ -286,11 +285,7 @@ bool CMakePlugin::IsPaneDetached() const
 
 /* ************************************************************************ */
 
-clToolBar* CMakePlugin::CreateToolBar(wxWindow* parent)
-{
-    wxUnusedVar(parent);
-    return NULL;
-}
+void CMakePlugin::CreateToolBar(clToolBar* toolbar) { wxUnusedVar(toolbar); }
 
 /* ************************************************************************ */
 
@@ -351,7 +346,7 @@ void CMakePlugin::OpenCMakeLists(wxFileName filename) const
 
     if(!m_mgr->OpenFile(filename.GetFullPath()))
         wxMessageBox("Unable to open \"" + filename.GetFullPath() + "\"", wxMessageBoxCaptionStr,
-            wxOK | wxCENTER | wxICON_ERROR);
+                     wxOK | wxCENTER | wxICON_ERROR);
 }
 
 /* ************************************************************************ */
@@ -381,9 +376,8 @@ void CMakePlugin::OnToggleHelpTab(clCommandEvent& event)
 
     if(event.IsSelected()) {
         // show it
-        cmakeImages images;
-        const wxBitmap& bmp = images.Bitmap("cmake_16");
-        m_mgr->GetWorkspacePaneNotebook()->AddPage(m_helpTab, HELP_TAB_NAME, false, bmp);
+        auto images = m_mgr->GetWorkspacePaneNotebook()->GetBitmaps();
+        m_mgr->GetWorkspacePaneNotebook()->AddPage(m_helpTab, HELP_TAB_NAME, true, images->Add("cmake"));
     } else {
         int where = m_mgr->GetWorkspacePaneNotebook()->GetPageIndex(HELP_TAB_NAME);
         if(where != wxNOT_FOUND) {
@@ -485,9 +479,9 @@ void CMakePlugin::OnOpenCMakeLists(wxCommandEvent& event)
 
 void CMakePlugin::OnExportCMakeLists(wxCommandEvent& event)
 {
-    ProjectPtr proj = (event.GetId() == XRCID("cmake_export_active_project")) ?
-        clCxxWorkspaceST::Get()->GetActiveProject() :
-        GetSelectedProject();
+    ProjectPtr proj = (event.GetId() == XRCID("cmake_export_active_project"))
+                          ? clCxxWorkspaceST::Get()->GetActiveProject()
+                          : GetSelectedProject();
 
     CHECK_PTR_RET(proj);
 
@@ -543,7 +537,7 @@ void CMakePlugin::OnFileRemoved(clCommandEvent& event)
 
     // Ensure we are a CMake project
     CHECK_COND_RET(buildConf->GetBuilder()->GetName() == "CMake");
-    
+
     DoRunCMake(p);
 }
 
@@ -575,40 +569,48 @@ void CMakePlugin::DoRunCMake(ProjectPtr p)
     }
 
     wxString args = buildConf->GetBuildSystemArguments();
-    
+
     // Expand CodeLite macros
     args = MacroManager::Instance()->Expand(args, m_mgr, p->GetName(), buildConf->GetName());
     wxString cmakeExe = GetCMake()->GetPath().GetFullPath();
-    
+
     // Did the user provide a generator to use?
     bool hasGeneratorInArgs = (args.Find("-G") != wxNOT_FOUND);
     wxUnusedVar(hasGeneratorInArgs);
-    
+
     // Build the working directory
     wxFileName fnWorkingDirectory(CMakeBuilder::GetProjectBuildFolder(p->GetName(), false), "");
 
     // Ensure that the build directory exists
     fnWorkingDirectory.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
     ::WrapWithQuotes(cmakeExe);
-    
-    // We run the cmake 
+
+    // We run the cmake
     wxString command;
     wxString projectFolder = p->GetFileName().GetPath();
     ::WrapWithQuotes(projectFolder);
-    
-    command << cmakeExe <<  " " << projectFolder << " " << args;
+
+    command << cmakeExe << " " << projectFolder << " " << args;
+
 #ifdef __WXMSW__
     if(!hasGeneratorInArgs) {
+        bool is_msys =
+            buildConf->GetCompiler() && buildConf->GetCompiler()->GetCompilerFamily() == COMPILER_FAMILY_MSYS2;
         // On Windows, generate MinGW makefiles
-        command << " -G\"MinGW Makefiles\"";
+        if(is_msys) {
+            command << " -G\"MSYS Makefiles\"";
+        } else {
+            command << " -G\"MinGW Makefiles\"";
+        }
     }
 #endif
 
     // Execute it
-    IProcess* proc = ::CreateAsyncProcess(this, command, IProcessCreateDefault, fnWorkingDirectory.GetPath());
+    IProcess* proc =
+        ::CreateAsyncProcess(this, command, IProcessCreateDefault | IProcessWrapInShell, fnWorkingDirectory.GetPath());
     if(!proc) {
         ::wxMessageBox(_("Failed to execute:\n") + command, "CodeLite", wxICON_ERROR | wxOK | wxCENTER,
-            EventNotifier::Get()->TopFrame());
+                       EventNotifier::Get()->TopFrame());
         return;
     }
     m_mgr->ShowOutputPane(_("Build"));
