@@ -25,9 +25,9 @@ protected:
 public:
     MessageWithParams();
     virtual ~MessageWithParams();
-    virtual JSONItem ToJSON(const wxString& name, IPathConverter::Ptr_t pathConverter) const;
-    virtual void FromJSON(const JSONItem& json, IPathConverter::Ptr_t pathConverter);
-    virtual std::string ToString(IPathConverter::Ptr_t pathConverter) const;
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
+    virtual std::string ToString() const;
 
     void SetMethod(const wxString& method) { this->m_method = method; }
     const wxString& GetMethod() const { return m_method; }
