@@ -26,6 +26,9 @@
 #if USE_SFTP
 #include "cl_sftp.h"
 #include "cl_standard_paths.h"
+#include "file_logger.h"
+#include "wx/tokenzr.h"
+#include <atomic>
 #include <libssh/sftp.h>
 #include <string.h>
 #include <sys/stat.h>
@@ -129,16 +132,17 @@ void clSFTP::Write(const wxFileName& localFile, const wxString& remotePath)
                                      << ::strerror(errno));
     }
 
-    char buffer[4096];
     wxMemoryBuffer memBuffer;
+    size_t len = fp.Length();
+    void* buffer = memBuffer.GetWriteBuf(len);
     size_t nbytes(0);
-    while(!fp.Eof()) {
-        nbytes = fp.Read(buffer, sizeof(buffer));
-        if(nbytes == 0)
-            break;
-        memBuffer.AppendData(buffer, nbytes);
+    nbytes = fp.Read(buffer, fp.Length());
+    if(nbytes != (size_t)fp.Length()) {
+        throw clException(wxString() << "failed to read local file content. expected read size: " << len
+                                     << ". bytes read: " << nbytes);
     }
     fp.Close();
+    memBuffer.SetDataLen(len);
     Write(memBuffer, remotePath);
 }
 
@@ -148,12 +152,14 @@ void clSFTP::Write(const wxMemoryBuffer& fileContent, const wxString& remotePath
         throw clException("SFTP is not initialized");
     }
 
+    static size_t counter = 0;
     int access_type = O_WRONLY | O_CREAT | O_TRUNC;
     sftp_file file;
     wxString tmpRemoteFile = remotePath;
-    tmpRemoteFile << ".codelitesftp";
+    tmpRemoteFile << ".codelitesftp" << (++counter);
 
-    file = sftp_open(m_sftp, tmpRemoteFile.mb_str(wxConvUTF8).data(), access_type, 0644);
+    auto cb = tmpRemoteFile.mb_str(wxConvUTF8);
+    file = sftp_open(m_sftp, cb.data(), access_type, 0644);
     if(file == NULL) {
         throw clException(wxString() << _("Can't open file: ") << tmpRemoteFile << ". "
                                      << ssh_get_error(m_ssh->GetSession()),
@@ -179,16 +185,17 @@ void clSFTP::Write(const wxMemoryBuffer& fileContent, const wxString& remotePath
     sftp_close(file);
 
     // Unlink the original file if it exists
-    SFTPAttribute::Ptr_t pattr(new SFTPAttribute(sftp_stat(m_sftp, remotePath.mb_str(wxConvISO8859_1).data())));
+    auto char_buffer_remote = remotePath.mb_str(wxConvUTF8);
+    SFTPAttribute::Ptr_t pattr(new SFTPAttribute(sftp_stat(m_sftp, char_buffer_remote.data())));
 
-    if(pattr->IsOk() && sftp_unlink(m_sftp, remotePath.mb_str(wxConvUTF8).data()) < 0) {
+    if(pattr->IsOk() && sftp_unlink(m_sftp, char_buffer_remote.data()) < 0) {
         throw clException(wxString() << _("Failed to unlink file: ") << remotePath << ". "
                                      << ssh_get_error(m_ssh->GetSession()),
                           sftp_get_error(m_sftp));
     }
 
     // Rename the file
-    if(sftp_rename(m_sftp, tmpRemoteFile.mb_str(wxConvUTF8).data(), remotePath.mb_str(wxConvUTF8).data()) < 0) {
+    if(sftp_rename(m_sftp, cb.data(), char_buffer_remote.data()) < 0) {
         throw clException(wxString() << _("Failed to rename file: ") << tmpRemoteFile << " -> " << remotePath << ". "
                                      << ssh_get_error(m_ssh->GetSession()),
                           sftp_get_error(m_sftp));
@@ -314,7 +321,7 @@ void clSFTP::CreateDir(const wxString& dirname)
     }
 
     int rc;
-    rc = sftp_mkdir(m_sftp, dirname.mb_str(wxConvISO8859_1).data(), S_IRWXU);
+    rc = sftp_mkdir(m_sftp, dirname.mb_str(wxConvUTF8).data(), S_IRWXU);
 
     if(rc != SSH_OK) {
         throw clException(wxString() << _("Failed to create directory: ") << dirname << ". "
@@ -330,7 +337,7 @@ void clSFTP::Rename(const wxString& oldpath, const wxString& newpath)
     }
 
     int rc;
-    rc = sftp_rename(m_sftp, oldpath.mb_str(wxConvISO8859_1).data(), newpath.mb_str(wxConvISO8859_1).data());
+    rc = sftp_rename(m_sftp, oldpath.mb_str(wxConvUTF8).data(), newpath.mb_str(wxConvUTF8).data());
 
     if(rc != SSH_OK) {
         throw clException(wxString() << _("Failed to rename path. ") << ssh_get_error(m_ssh->GetSession()),
@@ -345,12 +352,10 @@ void clSFTP::RemoveDir(const wxString& dirname)
     }
 
     int rc;
-    rc = sftp_rmdir(m_sftp, dirname.mb_str(wxConvISO8859_1).data());
+    rc = sftp_rmdir(m_sftp, dirname.mb_str(wxConvUTF8).data());
 
     if(rc != SSH_OK) {
-        throw clException(wxString() << _("Failed to remove directory: ") << dirname << ". "
-                                     << ssh_get_error(m_ssh->GetSession()),
-                          sftp_get_error(m_sftp));
+        throw clException(wxString() << _("Failed to remove directory: ") << dirname << "\n" << GetErrorString());
     }
 }
 
@@ -361,7 +366,7 @@ void clSFTP::UnlinkFile(const wxString& path)
     }
 
     int rc;
-    rc = sftp_unlink(m_sftp, path.mb_str(wxConvISO8859_1).data());
+    rc = sftp_unlink(m_sftp, path.mb_str(wxConvUTF8).data());
 
     if(rc != SSH_OK) {
         throw clException(wxString() << _("Failed to unlink path: ") << path << ". "
@@ -376,7 +381,7 @@ SFTPAttribute::Ptr_t clSFTP::Stat(const wxString& path)
         throw clException("SFTP is not initialized");
     }
 
-    sftp_attributes attr = sftp_stat(m_sftp, path.mb_str(wxConvISO8859_1).data());
+    sftp_attributes attr = sftp_stat(m_sftp, path.mb_str(wxConvUTF8).data());
     if(!attr) {
         throw clException(wxString() << _("Could not stat: ") << path << ". " << ssh_get_error(m_ssh->GetSession()),
                           sftp_get_error(m_sftp));
@@ -384,7 +389,7 @@ SFTPAttribute::Ptr_t clSFTP::Stat(const wxString& path)
     wxString target;
     if(attr->type == SSH_FILEXFER_TYPE_SYMLINK) {
         // this is a symlink file, read the symlink info
-        const char* ctarget = sftp_readlink(m_sftp, path.mb_str(wxConvISO8859_1).data());
+        const char* ctarget = sftp_readlink(m_sftp, path.mb_str(wxConvUTF8).data());
         if(!ctarget) {
             throw clException(wxString() << _("Failed to read symlink target. ") << ssh_get_error(m_ssh->GetSession()));
         }
@@ -404,6 +409,13 @@ void clSFTP::CreateRemoteFile(const wxString& remoteFullPath, const wxString& co
     Write(content, remoteFullPath);
 }
 
+void clSFTP::CreateEmptyFile(const wxString& remotePath)
+{
+    Mkpath(wxFileName(remotePath).GetPath());
+    wxMemoryBuffer mb;
+    Write(mb, remotePath);
+}
+
 void clSFTP::Mkpath(const wxString& remoteDirFullpath)
 {
     if(!m_sftp) {
@@ -423,7 +435,7 @@ void clSFTP::Mkpath(const wxString& remoteDirFullpath)
     curdir << "/";
     for(size_t i = 0; i < dirs.GetCount(); ++i) {
         curdir << dirs.Item(i);
-        sftp_attributes attr = sftp_stat(m_sftp, curdir.mb_str(wxConvISO8859_1).data());
+        sftp_attributes attr = sftp_stat(m_sftp, curdir.mb_str(wxConvUTF8).data());
         if(!attr) {
             // directory does not exists
             CreateDir(curdir);
@@ -487,4 +499,137 @@ wxFileName clSFTP::GetLocalFileName(const SSHAccountInfo& accountInfo, const wxS
     return localFile.GetFullPath();
 }
 
+wxString clSFTP::GetErrorString() const
+{
+    if(!m_sftp) {
+        return wxEmptyString;
+    }
+
+    int errorCode = sftp_get_error(m_sftp);
+    switch(errorCode) {
+    case SSH_FX_OK:
+        return "no error";
+    case SSH_FX_EOF:
+        return "end-of-file encountered";
+    case SSH_FX_NO_SUCH_FILE:
+        return "file does not exist";
+    case SSH_FX_PERMISSION_DENIED:
+        return "permission denied";
+    case SSH_FX_FAILURE:
+        return "generic failure";
+    case SSH_FX_BAD_MESSAGE:
+        return "garbage received from server";
+    case SSH_FX_NO_CONNECTION:
+        return "no connection has been set up";
+    case SSH_FX_CONNECTION_LOST:
+        return "there was a connection, but we lost it";
+    case SSH_FX_OP_UNSUPPORTED:
+        return "operation not supported by libssh yet";
+    case SSH_FX_INVALID_HANDLE:
+        return "invalid file handle";
+    case SSH_FX_NO_SUCH_PATH:
+        return "no such file or directory path exists";
+    case SSH_FX_FILE_ALREADY_EXISTS:
+        return "an attempt to create an already existing file or directory has been made";
+    case SSH_FX_WRITE_PROTECT:
+        return "write-protected filesystem";
+    case SSH_FX_NO_MEDIA:
+        return "no media was in remote drive";
+    default:
+        return wxEmptyString;
+    }
+}
+
+void clSFTP::SendKeepAlive()
+{
+    if(!m_sftp || !m_ssh) {
+        return;
+    }
+    m_ssh->SendIgnore();
+}
+
+SFTPAttribute::List_t clSFTP::Chdir(const wxString& remotePath)
+{
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
+
+    // Check that the directory exists
+    auto attr = Stat(remotePath);
+    if(!attr->IsFolder()) {
+        throw clException("Chdir failed. " + remotePath + " is not a directory");
+    }
+    return List(remotePath, SFTP_BROWSE_FILES | SFTP_BROWSE_FOLDERS);
+}
+
+wxString clSFTP::ExecuteCommand(const wxString& command)
+{
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
+
+    ssh_channel channel = ssh_channel_new(m_ssh->GetSession());
+    if(!channel) {
+        throw clException("Failed to allocate ssh channel");
+    }
+
+    int rc = ssh_channel_open_session(channel);
+    if(rc != SSH_OK) {
+        ssh_channel_free(channel);
+        throw clException("Failed to open ssh channel");
+    }
+    rc = ssh_channel_request_exec(channel, command.mb_str(wxConvUTF8).data());
+    if(rc != SSH_OK) {
+        ssh_channel_close(channel);
+        ssh_channel_free(channel);
+        throw clException(wxString() << "Failed to execute command: " << command);
+    }
+
+    // read the result
+    char buffer[256];
+    int nbytes;
+
+    wxString result;
+    nbytes = ssh_channel_read(channel, buffer, sizeof(buffer) - 1, 0);
+    while(nbytes > 0) {
+        buffer[nbytes] = 0;
+        result << buffer;
+        nbytes = ssh_channel_read(channel, buffer, sizeof(buffer), 0);
+    }
+
+    if(nbytes < 0) {
+        ssh_channel_close(channel);
+        ssh_channel_free(channel);
+        throw clException(wxString() << "Failed to read from channel. Command: " << command);
+    }
+
+    ssh_channel_send_eof(channel);
+    ssh_channel_close(channel);
+    ssh_channel_free(channel);
+    return result;
+}
+
+bool clSFTP::GetChecksum(const wxString& remoteFile, size_t* checksum)
+{
+    wxString command;
+    command << "cksum " << remoteFile;
+    try {
+        wxString output = ExecuteCommand(command);
+        auto parts = ::wxStringTokenize(output, " \t", wxTOKEN_STRTOK);
+        if(parts.empty()) {
+            return false;
+        }
+        // the checksum is the first part
+        unsigned long ck;
+        if(!parts[0].ToCULong(&ck)) {
+            return false;
+        }
+        *checksum = ck;
+        return true;
+    } catch(clException& e) {
+        clWARNING() << e.What() << endl;
+        return false;
+    }
+}
+
 #endif // USE_SFTP
