@@ -4,10 +4,15 @@ wxDEFINE_EVENT(wxEVT_FILE_DELETED, clFileSystemEvent);
 wxDEFINE_EVENT(wxEVT_FOLDER_DELETED, clFileSystemEvent);
 wxDEFINE_EVENT(wxEVT_INIT_DONE, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_EDITOR_CONFIG_CHANGED, wxCommandEvent);
-wxDEFINE_EVENT(wxEVT_WORKSPACE_LOADED, wxCommandEvent);
+
+// workspace loading related event
+wxDEFINE_EVENT(wxEVT_WORKSPACE_LOADED, clWorkspaceEvent);
+wxDEFINE_EVENT(wxEVT_WORKSPACE_RELOAD_STARTED, clWorkspaceEvent);
+wxDEFINE_EVENT(wxEVT_WORKSPACE_RELOAD_ENDED, clWorkspaceEvent);
+wxDEFINE_EVENT(wxEVT_WORKSPACE_CLOSED, clWorkspaceEvent);
+wxDEFINE_EVENT(wxEVT_WORKSPACE_CLOSING, clWorkspaceEvent);
+
 wxDEFINE_EVENT(wxEVT_WORKSPACE_CONFIG_CHANGED, wxCommandEvent);
-wxDEFINE_EVENT(wxEVT_WORKSPACE_CLOSED, wxCommandEvent);
-wxDEFINE_EVENT(wxEVT_WORKSPACE_CLOSING, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_FILE_VIEW_INIT_DONE, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_FILE_VIEW_REFRESHED, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_FILE_EXP_INIT_DONE, wxCommandEvent);
@@ -25,7 +30,7 @@ wxDEFINE_EVENT(wxEVT_FILE_RENAMED, clFileSystemEvent);
 wxDEFINE_EVENT(wxEVT_FILE_SAVEAS, clFileSystemEvent);
 wxDEFINE_EVENT(wxEVT_FILE_CREATED, clFileSystemEvent);
 wxDEFINE_EVENT(wxEVT_FOLDER_CREATED, clFileSystemEvent);
-wxDEFINE_EVENT(wxEVT_FILE_RETAGGED, wxCommandEvent);
+wxDEFINE_EVENT(wxEVT_FILE_FIND_MATCHING_PAIR, clFileSystemEvent);
 wxDEFINE_EVENT(wxEVT_ACTIVE_EDITOR_CHANGED, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_EDITOR_CLOSING, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_ALL_EDITORS_CLOSING, wxCommandEvent);
@@ -52,16 +57,25 @@ wxDEFINE_EVENT(wxEVT_GET_ADDITIONAL_COMPILEFLAGS, clBuildEvent);
 wxDEFINE_EVENT(wxEVT_GET_ADDITIONAL_LINKFLAGS, clBuildEvent);
 wxDEFINE_EVENT(wxEVT_PLUGIN_EXPORT_MAKEFILE, clBuildEvent);
 wxDEFINE_EVENT(wxEVT_GET_IS_BUILD_IN_PROGRESS, clBuildEvent);
+wxDEFINE_EVENT(wxEVT_BUILD_OUTPUT_HOTSPOT_CLICKED, clBuildEvent);
 wxDEFINE_EVENT(wxEVT_DEBUG_STARTING, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DEBUG_STARTED, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DEBUG_ENDING, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DEBUG_ENDED, clDebugEvent);
+wxDEFINE_EVENT(wxEVT_DEBUG_SET_FILELINE, clDebugEvent);
+wxDEFINE_EVENT(wxEVT_DEBUG_BREAKPOINTS_LIST, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DEBUGGER_REFRESH_PANE, clDebugEvent);
+wxDEFINE_EVENT(wxEVT_BREAKPOINTS_UPDATED, clDebugEvent);
+wxDEFINE_EVENT(wxEVT_BREAKPOINTS_UI_UPDATED, clDebugEvent);
+wxDEFINE_EVENT(wxEVT_BREAKPOINTS_UI_EDITOR_UPDATED, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DEBUGGER_SET_MEMORY, clDebugEvent);
+wxDEFINE_EVENT(wxEVT_QUICK_DEBUG, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_QUICK_DEBUG_DLG_SHOWING, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_QUICK_DEBUG_DLG_DISMISSED_OK, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DEBUG_EDITOR_LOST_CONTROL, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_DEBUG_EDITOR_GOT_CONTROL, wxCommandEvent);
+wxDEFINE_EVENT(wxEVT_CC_SEMANTICS_HIGHLIGHT, clCodeCompletionEvent);
+wxDEFINE_EVENT(wxEVT_CC_WORKSPACE_SYMBOLS, clCodeCompletionEvent);
 wxDEFINE_EVENT(wxEVT_CC_CODE_COMPLETE, clCodeCompletionEvent);
 wxDEFINE_EVENT(wxEVT_CC_WORD_COMPLETE, clCodeCompletionEvent);
 wxDEFINE_EVENT(wxEVT_CCBOX_SELECTION_MADE, clCodeCompletionEvent);
@@ -73,6 +87,7 @@ wxDEFINE_EVENT(wxEVT_CC_TYPEINFO_TIP, clCodeCompletionEvent);
 wxDEFINE_EVENT(wxEVT_CC_CODE_COMPLETE_LANG_KEYWORD, clCodeCompletionEvent);
 wxDEFINE_EVENT(wxEVT_CC_JUMP_HYPER_LINK, clCodeCompletionEvent);
 wxDEFINE_EVENT(wxEVT_CC_FIND_SYMBOL, clCodeCompletionEvent);
+wxDEFINE_EVENT(wxEVT_CC_FIND_HEADER_FILE, clCodeCompletionEvent);
 wxDEFINE_EVENT(wxEVT_CC_FIND_SYMBOL_DECLARATION, clCodeCompletionEvent);
 wxDEFINE_EVENT(wxEVT_CC_FIND_SYMBOL_DEFINITION, clCodeCompletionEvent);
 wxDEFINE_EVENT(wxEVT_CC_GENERATE_DOXY_BLOCK, clCodeCompletionEvent);
@@ -81,6 +96,7 @@ wxDEFINE_EVENT(wxEVT_CC_BLOCK_COMMENT_CODE_COMPLETE, clCodeCompletionEvent);
 wxDEFINE_EVENT(wxEVT_CC_BLOCK_COMMENT_WORD_COMPLETE, clCodeCompletionEvent);
 wxDEFINE_EVENT(wxEVT_CMD_CREATE_NEW_WORKSPACE, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_CMD_OPEN_WORKSPACE, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_SWITCHING_TO_WORKSPACE, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_CMD_CLOSE_WORKSPACE, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_CMD_IS_WORKSPACE_OPEN, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_CMD_RETAG_WORKSPACE, wxCommandEvent);
@@ -99,6 +115,7 @@ wxDEFINE_EVENT(wxEVT_FINDBAR_ABOUT_TO_SHOW, clFindEvent);
 wxDEFINE_EVENT(wxEVT_FINDBAR_RELEASE_EDITOR, clFindEvent);
 wxDEFINE_EVENT(wxEVT_FINDINFILES_DLG_SHOWING, clFindInFilesEvent);
 wxDEFINE_EVENT(wxEVT_FINDINFILES_DLG_DISMISSED, clFindInFilesEvent);
+wxDEFINE_EVENT(wxEVT_FINDINFILES_OPEN_MATCH, clFindInFilesEvent);
 wxDEFINE_EVENT(wxEVT_CMD_BUILD_PROJECT_ONLY, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_CMD_CLEAN_PROJECT_ONLY, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_CL_THEME_CHANGED, wxCommandEvent);
@@ -137,8 +154,6 @@ wxDEFINE_EVENT(wxEVT_DBG_UI_DELETE_ALL_BREAKPOINTS, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DBG_UI_ENABLE_ALL_BREAKPOINTS, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_DBG_UI_DISABLE_ALL_BREAKPOINTS, clDebugEvent);
 wxDEFINE_EVENT(wxEVT_CMD_OPEN_PROJ_SETTINGS, clCommandEvent);
-wxDEFINE_EVENT(wxEVT_WORKSPACE_RELOAD_STARTED, clCommandEvent);
-wxDEFINE_EVENT(wxEVT_WORKSPACE_RELOAD_ENDED, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_NEW_PROJECT_WIZARD_SHOWING, clNewProjectEvent);
 wxDEFINE_EVENT(wxEVT_NEW_PROJECT_WIZARD_FINISHED, clNewProjectEvent);
 wxDEFINE_EVENT(wxEVT_COMPILER_LIST_UPDATED, clCompilerEvent);
@@ -188,3 +203,16 @@ wxDEFINE_EVENT(wxEVT_SOURCE_CONTROL_PUSHED, clSourceControlEvent);
 wxDEFINE_EVENT(wxEVT_SOURCE_CONTROL_COMMIT_LOCALLY, clSourceControlEvent);
 wxDEFINE_EVENT(wxEVT_SOURCE_CONTROL_RESET_FILES, clSourceControlEvent);
 wxDEFINE_EVENT(wxEVT_SOURCE_CONTROL_PULLED, clSourceControlEvent);
+wxDEFINE_EVENT(wxEVT_LSP_STOP_ALL, clLanguageServerEvent);
+wxDEFINE_EVENT(wxEVT_LSP_START_ALL, clLanguageServerEvent);
+wxDEFINE_EVENT(wxEVT_LSP_RESTART_ALL, clLanguageServerEvent);
+wxDEFINE_EVENT(wxEVT_LSP_STOP, clLanguageServerEvent);
+wxDEFINE_EVENT(wxEVT_LSP_START, clLanguageServerEvent);
+wxDEFINE_EVENT(wxEVT_LSP_RESTART, clLanguageServerEvent);
+wxDEFINE_EVENT(wxEVT_LSP_DELETE, clLanguageServerEvent);
+wxDEFINE_EVENT(wxEVT_LSP_CONFIGURE, clLanguageServerEvent);
+wxDEFINE_EVENT(wxEVT_LSP_OPEN_SETTINGS_DLG, clLanguageServerEvent);
+wxDEFINE_EVENT(wxEVT_LSP_ENABLE_SERVER, clLanguageServerEvent);
+wxDEFINE_EVENT(wxEVT_LSP_DISABLE_SERVER, clLanguageServerEvent);
+wxDEFINE_EVENT(wxEVT_DOWNLOAD_FILE, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_OPEN_FILE, clCommandEvent);
