@@ -23,21 +23,23 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-#include "event_notifier.h"
 #include "codelite_events.h"
+#include "event_notifier.h"
 #include <wx/app.h>
 
 static EventNotifier* eventNotifier = NULL;
 
 EventNotifier* EventNotifier::Get()
 {
-    if(eventNotifier == NULL) eventNotifier = new EventNotifier();
+    if(eventNotifier == NULL)
+        eventNotifier = new EventNotifier();
     return eventNotifier;
 }
 
 void EventNotifier::Release()
 {
-    if(eventNotifier) delete eventNotifier;
+    if(eventNotifier)
+        delete eventNotifier;
     eventNotifier = NULL;
 }
 
@@ -50,7 +52,8 @@ EventNotifier::~EventNotifier() {}
 
 bool EventNotifier::SendCommandEvent(int eventId, void* clientData)
 {
-    if(_eventsDiabled) return false;
+    if(_eventsDiabled)
+        return false;
 
     wxCommandEvent evt(eventId);
     evt.SetClientData(clientData);
@@ -59,7 +62,8 @@ bool EventNotifier::SendCommandEvent(int eventId, void* clientData)
 
 bool EventNotifier::SendCommandEvent(int eventId, void* clientData, const wxString& s)
 {
-    if(_eventsDiabled) return false;
+    if(_eventsDiabled)
+        return false;
 
     wxCommandEvent evt(eventId);
     evt.SetClientData(clientData);
@@ -69,7 +73,8 @@ bool EventNotifier::SendCommandEvent(int eventId, void* clientData, const wxStri
 
 void EventNotifier::PostCommandEvent(int eventId, void* clientData)
 {
-    if(_eventsDiabled) return;
+    if(_eventsDiabled)
+        return;
 
     wxCommandEvent evt(eventId);
     evt.SetClientData(clientData);
@@ -82,7 +87,8 @@ wxFrame* EventNotifier::TopFrame() { return static_cast<wxFrame*>(wxTheApp->GetT
 
 void EventNotifier::PostFileSavedEvent(const wxString& filename)
 {
-    if(_eventsDiabled) return;
+    if(_eventsDiabled)
+        return;
     clCommandEvent event(wxEVT_FILE_SAVED);
     event.SetString(filename);
     event.SetFileName(filename);
@@ -91,14 +97,16 @@ void EventNotifier::PostFileSavedEvent(const wxString& filename)
 
 void EventNotifier::PostReloadExternallyModifiedEvent(bool prompt)
 {
-    if(_eventsDiabled) return;
+    if(_eventsDiabled)
+        return;
     wxCommandEvent event(prompt ? wxEVT_CMD_RELOAD_EXTERNALLY_MODIFIED : wxEVT_CMD_RELOAD_EXTERNALLY_MODIFIED_NOPROMPT);
     AddPendingEvent(event);
 }
 
 void EventNotifier::PostFileRemovedEvent(const wxArrayString& files)
 {
-    if(_eventsDiabled) return;
+    if(_eventsDiabled)
+        return;
     clCommandEvent filesRemovedEvent(wxEVT_PROJ_FILE_REMOVED);
     filesRemovedEvent.SetStrings(files);
     AddPendingEvent(filesRemovedEvent);
@@ -106,16 +114,18 @@ void EventNotifier::PostFileRemovedEvent(const wxArrayString& files)
 
 void EventNotifier::NotifyWorkspaceReloadEndEvent(const wxString& workspaceFile)
 {
-    if(_eventsDiabled) return;
-    clCommandEvent event(wxEVT_WORKSPACE_RELOAD_ENDED);
+    if(_eventsDiabled)
+        return;
+    clWorkspaceEvent event(wxEVT_WORKSPACE_RELOAD_ENDED);
     event.SetFileName(workspaceFile);
     ProcessEvent(event);
 }
 
 void EventNotifier::NotifyWorkspaceReloadStartEvet(const wxString& workspaceFile)
 {
-    if(_eventsDiabled) return;
-    clCommandEvent event(wxEVT_WORKSPACE_RELOAD_STARTED);
+    if(_eventsDiabled)
+        return;
+    clWorkspaceEvent event(wxEVT_WORKSPACE_RELOAD_STARTED);
     event.SetFileName(workspaceFile);
     ProcessEvent(event);
 }
