@@ -22,6 +22,8 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+#include "fileutils.h"
+
 #include "StringUtils.h"
 #include "asyncprocess.h"
 #include "clConsoleBase.h"
@@ -29,17 +31,19 @@
 #include "cl_standard_paths.h"
 #include "dirsaver.h"
 #include "file_logger.h"
-#include "fileutils.h"
 #include "macros.h"
 #include "procutils.h"
 #include "wx/string.h"
 #include "wxStringHash.h"
+
 #include <algorithm>
 #include <fstream>
 #include <map>
 #include <wx/ffile.h>
 #include <wx/file.h>
 #include <wx/log.h>
+#include <wx/regex.h>
+#include <wx/uri.h>
 #if wxUSE_GUI
 #include <wx/msgdlg.h>
 #endif
@@ -52,8 +56,25 @@
 #include <sys/wait.h>
 #include <unistd.h>
 #endif
+#include <functional>
+#include <memory>
 #include <wx/filename.h>
 
+using namespace std;
+// internal helper method
+namespace
+{
+bool write_file_content(const wxFileName& fn, const wxString& content, const wxMBConv& conv)
+{
+    wxFile file(fn.GetFullPath(), wxFile::write);
+    if(file.IsOpened()) {
+        return file.Write(content, conv);
+    } else {
+        return false;
+    }
+}
+} // namespace
+
 void FileUtils::OpenFileExplorer(const wxString& path)
 {
     // Wrap the path with quotes if needed
@@ -87,16 +108,40 @@ void FileUtils::OpenTerminal(const wxString& path, const wxString& user_command,
 
 bool FileUtils::WriteFileContent(const wxFileName& fn, const wxString& content, const wxMBConv& conv)
 {
-    wxFile file(fn.GetFullPath(), wxFile::write);
-    if(file.IsOpened()) {
-        return file.Write(content, conv);
-    } else {
+    wxFileName tmpFile = CreateTempFileName(fn.GetPath(), "cltmp", fn.GetExt());
+    // make sure we erase the temp file
+    FileUtils::Deleter d(tmpFile);
+    if(!write_file_content(tmpFile, content, conv)) {
         return false;
     }
+
+    // rename tmp -> real file
+    return ::wxRenameFile(tmpFile.GetFullPath(), fn.GetFullPath(), true);
 }
 
 bool FileUtils::ReadFileContent(const wxFileName& fn, wxString& data, const wxMBConv& conv)
 {
+    std::string rawdata;
+    if(!ReadFileContentRaw(fn, rawdata)) {
+        return false;
+    }
+
+    // convert
+    data = wxString(rawdata.c_str(), conv, rawdata.length());
+    if(data.IsEmpty() && !rawdata.empty()) {
+        // Conversion failed
+        data = wxString::From8BitData(rawdata.c_str(), rawdata.length());
+    }
+    return true;
+}
+
+bool FileUtils::ReadFileContentRaw(const wxFileName& fn, std::string& data)
+{
+    // fopen() may return non NULL for directories too, so we have to test it ourselves
+    if(!fn.FileExists()) {
+        return false;
+    }
+
     wxString filename = fn.GetFullPath();
     data.clear();
     const char* cfile = filename.mb_str(wxConvUTF8).data();
@@ -112,29 +157,23 @@ bool FileUtils::ReadFileContent(const wxFileName& fn, wxString& data, const wxMB
     fseek(fp, 0, SEEK_SET);
 
     // Allocate buffer for the read
-    char* buffer = (char*)malloc(fsize + 1);
-    long bytes_read = fread(buffer, 1, fsize, fp);
+    data.reserve(fsize + 1);
+
+    // use unique_ptr to auto release the buffer
+    unique_ptr<char, function<void(char*)>> buffer(new char[fsize + 1], [](char* d) { delete[] d; });
+
+    long bytes_read = fread(buffer.get(), 1, fsize, fp);
     if(bytes_read != fsize) {
         // failed to read
         clERROR() << "Failed to read file content:" << fn << "." << strerror(errno);
         fclose(fp);
-        free(buffer);
         return false;
     }
-    buffer[fsize] = 0;
-
-    // Close the handle
+    buffer.get()[fsize] = 0;
     fclose(fp);
 
-    // Convert it into wxString
-    data = wxString(buffer, conv, fsize);
-    if(data.IsEmpty() && fsize != 0) {
-        // Conversion failed
-        data = wxString::From8BitData(buffer, fsize);
-    }
-
-    // Release the C-buffer allocated earlier
-    free(buffer);
+    // Close the handle
+    data = buffer.get();
     return true;
 }
 
@@ -333,12 +372,12 @@ wxString FileUtils::DecodeURI(const wxString& uri)
 
 wxString FileUtils::EncodeURI(const wxString& uri)
 {
-    static std::unordered_map<int, wxString> sEncodeMap = {
-        { (int)'!', "%21" }, { (int)'#', "%23" }, { (int)'$', "%24" }, { (int)'&', "%26" }, { (int)'\'', "%27" },
-        { (int)'(', "%28" }, { (int)')', "%29" }, { (int)'*', "%2A" }, { (int)'+', "%2B" }, { (int)',', "%2C" },
-        { (int)';', "%3B" }, { (int)'=', "%3D" }, { (int)'?', "%3F" }, { (int)'@', "%40" }, { (int)'[', "%5B" },
-        { (int)']', "%5D" }, { (int)' ', "%20" }
-    };
+    static unordered_map<int, wxString> sEncodeMap = { { (int)'!', "%21" }, { (int)'#', "%23" },  { (int)'$', "%24" },
+                                                       { (int)'&', "%26" }, { (int)'\'', "%27" }, { (int)'(', "%28" },
+                                                       { (int)')', "%29" }, { (int)'*', "%2A" },  { (int)'+', "%2B" },
+                                                       { (int)',', "%2C" }, { (int)';', "%3B" },  { (int)'=', "%3D" },
+                                                       { (int)'?', "%3F" }, { (int)'@', "%40" },  { (int)'[', "%5B" },
+                                                       { (int)']', "%5D" }, { (int)' ', "%20" } };
 
     wxString encoded;
     for(size_t i = 0; i < uri.length(); ++i) {
@@ -619,7 +658,7 @@ std::string FileUtils::ToStdString(const wxString& str) { return StringUtils::To
 
 bool FileUtils::ReadBufferFromFile(const wxFileName& fn, wxString& data, size_t bufferSize)
 {
-    std::wifstream fin(fn.GetFullPath().c_str(), std::ios::binary);
+    std::wifstream fin(fn.GetFullPath().ToStdString(), std::ios::binary);
     if(fin.bad()) {
         clERROR() << "Failed to open file:" << fn;
         return false;
@@ -686,8 +725,9 @@ clEnvList_t FileUtils::CreateEnvironment(const wxString& envstr)
     }
     return L;
 }
-
-bool FileUtils::FindExe(const wxString& name, wxFileName& exepath, const wxArrayString& hint)
+namespace
+{
+bool DoFindExe(const wxString& name, wxFileName& exepath, const wxArrayString& hint)
 {
     wxString path;
     if(!::wxGetEnv("PATH", &path)) {
@@ -736,3 +776,214 @@ bool FileUtils::FindExe(const wxString& name, wxFileName& exepath, const wxArray
     }
     return false;
 }
+} // namespace
+
+bool FileUtils::FindExe(const wxString& name, wxFileName& exepath, const wxArrayString& hint,
+                        const wxArrayString& suffix_list)
+{
+    wxArrayString possible_suffix;
+    possible_suffix.Add(wxEmptyString);
+    if(!suffix_list.empty()) {
+        possible_suffix.reserve(possible_suffix.size() + suffix_list.size());
+        possible_suffix.insert(possible_suffix.end(), suffix_list.begin(), suffix_list.end());
+    }
+    for(const wxString& suffix : possible_suffix) {
+        if(DoFindExe(name + suffix, exepath, hint)) {
+            return true;
+        }
+    }
+    return false;
+}
+
+wxFileName FileUtils::CreateTempFileName(const wxString& folder, const wxString& prefix, const wxString& ext)
+{
+    static bool srandInit = false;
+    if(!srandInit) {
+        srand(time(nullptr));
+        srandInit = true;
+    }
+
+    static const char alphanum[] = "0123456789"
+                                   "abcdefghijklmnopqrstuvwxyz"
+                                   "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+    size_t N = sizeof(alphanum) - 1;
+    wxString full_name = prefix;
+    full_name << "-";
+    for(size_t i = 0; i < 8; ++i) {
+        size_t index = rand() / (RAND_MAX / N + 1);
+        full_name += alphanum[index];
+    }
+    full_name += "." + ext;
+    return wxFileName(folder, full_name);
+}
+
+size_t FileUtils::FindSimilar(const wxFileName& filename, const std::vector<wxString>& extensions,
+                              std::vector<wxFileName>& vout)
+{
+    wxFileName fn(filename);
+    vout.reserve(extensions.size());
+    for(const wxString& ext : extensions) {
+        fn.SetExt(ext);
+        if(fn.FileExists()) {
+            vout.emplace_back(fn);
+        }
+    }
+    return vout.size();
+}
+
+bool FileUtils::ParseURI(const wxString& uri, wxString& path, wxString& scheme, wxString& user, wxString& host,
+                         wxString& port)
+{
+    if(uri.StartsWith("file://")) {
+        path = uri.Mid(7);
+        scheme = "file://";
+        return true;
+    } else if(uri.StartsWith("ssh://")) {
+        // expected syntax:
+        // ssh://user@host:port:/path
+        scheme = "ssh://";
+        wxString remainder = uri.Mid(6);
+        user = remainder.BeforeFirst('@');
+        remainder = remainder.AfterFirst('@');
+        host = remainder.BeforeFirst(':');
+        remainder = remainder.AfterFirst(':');
+
+        // at this point we got:
+        // port:/path
+        // OR -
+        // /path
+        if(remainder.empty()) {
+            return true;
+        }
+
+        if(remainder[0] == '/') {
+            path = remainder;
+        } else {
+            port = remainder.BeforeFirst(':');
+            path = remainder.AfterFirst(':');
+        }
+        return true;
+    } else {
+        return false;
+    }
+}
+
+wxString FileUtils::FilePathToURI(const wxString& filepath)
+{
+    if(filepath.StartsWith("file://")) {
+        return filepath;
+    } else {
+        wxString uri;
+        uri << "file://";
+        if(!filepath.StartsWith("/")) {
+            uri << "/";
+        }
+        wxString file_part = filepath;
+        file_part.Replace("\\", "/");
+        file_part = EncodeURI(file_part);
+        uri << file_part;
+        return uri;
+    }
+}
+
+wxString FileUtils::FilePathFromURI(const wxString& uri)
+{
+    wxString rest;
+    if(uri.StartsWith("file://", &rest)) {
+#ifdef __WXMSW__
+        // check if the file path starts with /C: (Windows drive)
+        wxRegEx re_windows_drive("/[a-z]{1}:", wxRE_DEFAULT | wxRE_ICASE);
+        if(re_windows_drive.IsValid() && re_windows_drive.Matches(rest)) {
+            rest.Remove(0, 1); // remove the leading slash
+            // since we know that his is a Windows style path
+            // make sure we are using backslashes
+            rest.Replace("/", "\\");
+        }
+#endif
+        rest = DecodeURI(rest);
+        return rest;
+    } else {
+        return uri;
+    }
+}
+
+namespace
+{
+/* Number of bytes to read at once.  */
+constexpr size_t BUFLEN = (1 << 16);
+
+uint_fast32_t const crctab[256] = {
+    0x00000000, 0x04c11db7, 0x09823b6e, 0x0d4326d9, 0x130476dc, 0x17c56b6b, 0x1a864db2, 0x1e475005, 0x2608edb8,
+    0x22c9f00f, 0x2f8ad6d6, 0x2b4bcb61, 0x350c9b64, 0x31cd86d3, 0x3c8ea00a, 0x384fbdbd, 0x4c11db70, 0x48d0c6c7,
+    0x4593e01e, 0x4152fda9, 0x5f15adac, 0x5bd4b01b, 0x569796c2, 0x52568b75, 0x6a1936c8, 0x6ed82b7f, 0x639b0da6,
+    0x675a1011, 0x791d4014, 0x7ddc5da3, 0x709f7b7a, 0x745e66cd, 0x9823b6e0, 0x9ce2ab57, 0x91a18d8e, 0x95609039,
+    0x8b27c03c, 0x8fe6dd8b, 0x82a5fb52, 0x8664e6e5, 0xbe2b5b58, 0xbaea46ef, 0xb7a96036, 0xb3687d81, 0xad2f2d84,
+    0xa9ee3033, 0xa4ad16ea, 0xa06c0b5d, 0xd4326d90, 0xd0f37027, 0xddb056fe, 0xd9714b49, 0xc7361b4c, 0xc3f706fb,
+    0xceb42022, 0xca753d95, 0xf23a8028, 0xf6fb9d9f, 0xfbb8bb46, 0xff79a6f1, 0xe13ef6f4, 0xe5ffeb43, 0xe8bccd9a,
+    0xec7dd02d, 0x34867077, 0x30476dc0, 0x3d044b19, 0x39c556ae, 0x278206ab, 0x23431b1c, 0x2e003dc5, 0x2ac12072,
+    0x128e9dcf, 0x164f8078, 0x1b0ca6a1, 0x1fcdbb16, 0x018aeb13, 0x054bf6a4, 0x0808d07d, 0x0cc9cdca, 0x7897ab07,
+    0x7c56b6b0, 0x71159069, 0x75d48dde, 0x6b93dddb, 0x6f52c06c, 0x6211e6b5, 0x66d0fb02, 0x5e9f46bf, 0x5a5e5b08,
+    0x571d7dd1, 0x53dc6066, 0x4d9b3063, 0x495a2dd4, 0x44190b0d, 0x40d816ba, 0xaca5c697, 0xa864db20, 0xa527fdf9,
+    0xa1e6e04e, 0xbfa1b04b, 0xbb60adfc, 0xb6238b25, 0xb2e29692, 0x8aad2b2f, 0x8e6c3698, 0x832f1041, 0x87ee0df6,
+    0x99a95df3, 0x9d684044, 0x902b669d, 0x94ea7b2a, 0xe0b41de7, 0xe4750050, 0xe9362689, 0xedf73b3e, 0xf3b06b3b,
+    0xf771768c, 0xfa325055, 0xfef34de2, 0xc6bcf05f, 0xc27dede8, 0xcf3ecb31, 0xcbffd686, 0xd5b88683, 0xd1799b34,
+    0xdc3abded, 0xd8fba05a, 0x690ce0ee, 0x6dcdfd59, 0x608edb80, 0x644fc637, 0x7a089632, 0x7ec98b85, 0x738aad5c,
+    0x774bb0eb, 0x4f040d56, 0x4bc510e1, 0x46863638, 0x42472b8f, 0x5c007b8a, 0x58c1663d, 0x558240e4, 0x51435d53,
+    0x251d3b9e, 0x21dc2629, 0x2c9f00f0, 0x285e1d47, 0x36194d42, 0x32d850f5, 0x3f9b762c, 0x3b5a6b9b, 0x0315d626,
+    0x07d4cb91, 0x0a97ed48, 0x0e56f0ff, 0x1011a0fa, 0x14d0bd4d, 0x19939b94, 0x1d528623, 0xf12f560e, 0xf5ee4bb9,
+    0xf8ad6d60, 0xfc6c70d7, 0xe22b20d2, 0xe6ea3d65, 0xeba91bbc, 0xef68060b, 0xd727bbb6, 0xd3e6a601, 0xdea580d8,
+    0xda649d6f, 0xc423cd6a, 0xc0e2d0dd, 0xcda1f604, 0xc960ebb3, 0xbd3e8d7e, 0xb9ff90c9, 0xb4bcb610, 0xb07daba7,
+    0xae3afba2, 0xaafbe615, 0xa7b8c0cc, 0xa379dd7b, 0x9b3660c6, 0x9ff77d71, 0x92b45ba8, 0x9675461f, 0x8832161a,
+    0x8cf30bad, 0x81b02d74, 0x857130c3, 0x5d8a9099, 0x594b8d2e, 0x5408abf7, 0x50c9b640, 0x4e8ee645, 0x4a4ffbf2,
+    0x470cdd2b, 0x43cdc09c, 0x7b827d21, 0x7f436096, 0x7200464f, 0x76c15bf8, 0x68860bfd, 0x6c47164a, 0x61043093,
+    0x65c52d24, 0x119b4be9, 0x155a565e, 0x18197087, 0x1cd86d30, 0x029f3d35, 0x065e2082, 0x0b1d065b, 0x0fdc1bec,
+    0x3793a651, 0x3352bbe6, 0x3e119d3f, 0x3ad08088, 0x2497d08d, 0x2056cd3a, 0x2d15ebe3, 0x29d4f654, 0xc5a92679,
+    0xc1683bce, 0xcc2b1d17, 0xc8ea00a0, 0xd6ad50a5, 0xd26c4d12, 0xdf2f6bcb, 0xdbee767c, 0xe3a1cbc1, 0xe760d676,
+    0xea23f0af, 0xeee2ed18, 0xf0a5bd1d, 0xf464a0aa, 0xf9278673, 0xfde69bc4, 0x89b8fd09, 0x8d79e0be, 0x803ac667,
+    0x84fbdbd0, 0x9abc8bd5, 0x9e7d9662, 0x933eb0bb, 0x97ffad0c, 0xafb010b1, 0xab710d06, 0xa6322bdf, 0xa2f33668,
+    0xbcb4666d, 0xb8757bda, 0xb5365d03, 0xb1f740b4
+};
+
+bool cksum(const std::string& file, size_t* checksum)
+{
+    unsigned char buf[BUFLEN];
+    uint_fast32_t crc = 0;
+    size_t length = 0;
+    size_t bytes_read;
+    FILE* fp;
+
+    fp = fopen(file.c_str(), "rb");
+    if(fp == NULL) {
+        return false;
+    }
+
+    while((bytes_read = fread(buf, 1, BUFLEN, fp)) > 0) {
+        unsigned char* cp = buf;
+        length += bytes_read;
+        while(bytes_read--)
+            crc = (crc << 8) ^ crctab[((crc >> 24) ^ *cp++) & 0xFF];
+        if(feof(fp))
+            break;
+    }
+
+    if(ferror(fp)) {
+        return false;
+    }
+
+    if(fclose(fp) == EOF) {
+        return false;
+    }
+
+    for(; length; length >>= 8)
+        crc = (crc << 8) ^ crctab[((crc >> 24) ^ length) & 0xFF];
+
+    crc = ~crc & 0xFFFFFFFF;
+    *checksum = crc;
+    return true;
+}
+} // namespace
+
+bool FileUtils::GetChecksum(const wxString& filepath, size_t* checksum)
+{
+    return cksum(ToStdString(filepath), checksum);
+}
