@@ -58,7 +58,9 @@ void clDockerDriver::OnProcessOutput(clProcessEvent& event)
 
 void clDockerDriver::OnProcessTerminated(clProcessEvent& event)
 {
-    if(!event.GetProcess() || m_processes.count(event.GetProcess()) == 0) { return; } // Not our process !?
+    if(!event.GetProcess() || m_processes.count(event.GetProcess()) == 0) {
+        return;
+    } // Not our process !?
 
     IProcess* process = event.GetProcess();
     m_processes.erase(process);
@@ -90,11 +92,14 @@ void clDockerDriver::ListContainers() { DoListContainers(); }
 void clDockerDriver::RemoveContainers(const wxArrayString& ids)
 {
     // Sanity
-    if(IsRunning()) return;
-    if(ids.IsEmpty()) return;
+    if(IsRunning())
+        return;
+    if(ids.IsEmpty())
+        return;
 
     wxString command = GetDockerExe();
-    if(command.IsEmpty()) return;
+    if(command.IsEmpty())
+        return;
 
     wxString message;
     message << _("Choosing 'Yes' will remove ") << ids.size() << _(" container(s)\nContinue?");
@@ -106,8 +111,8 @@ void clDockerDriver::RemoveContainers(const wxArrayString& ids)
     for(size_t i = 0; i < ids.size(); ++i) {
         command << " " << ids[i];
     }
-    ::WrapInShell(command);
-    StartProcessAsync(command, "", IProcessCreateDefault, kKillContainers);
+
+    StartProcessAsync(command, "", IProcessCreateDefault | IProcessWrapInShell, kKillContainers);
 }
 
 void clDockerDriver::StartProcessAsync(const wxString& command, const wxString& wd, size_t flags,
@@ -116,7 +121,9 @@ void clDockerDriver::StartProcessAsync(const wxString& command, const wxString&
     m_output.Clear();
     m_context = context;
     IProcess* process = ::CreateAsyncProcess(this, command, flags, wd);
-    if(process) { m_processes.insert(process); }
+    if(process) {
+        m_processes.insert(process);
+    }
 }
 
 wxString clDockerDriver::GetDockerExe() const
@@ -141,7 +148,9 @@ void clDockerDriver::ProcessListContainersCommand()
     wxArrayString lines = ::wxStringTokenize(m_output, "\n", wxTOKEN_STRTOK);
     for(size_t i = 0; i < lines.size(); ++i) {
         clDockerContainer container;
-        if(container.Parse(lines.Item(i))) { L.push_back(container); }
+        if(container.Parse(lines.Item(i))) {
+            L.push_back(container);
+        }
     }
     m_plugin->GetTerminal()->SetContainers(L);
 }
@@ -152,7 +161,9 @@ void clDockerDriver::ProcessListImagesCommand()
     clDockerImage::Vect_t L;
     for(size_t i = 0; i < lines.size(); ++i) {
         clDockerImage image;
-        if(image.Parse(lines.Item(i))) { L.push_back(image); }
+        if(image.Parse(lines.Item(i))) {
+            L.push_back(image);
+        }
     }
     m_plugin->GetTerminal()->SetImages(L);
 }
@@ -160,17 +171,18 @@ void clDockerDriver::ProcessListImagesCommand()
 void clDockerDriver::DoListContainers()
 {
     // Build the command
-    if(IsRunning()) return;
+    if(IsRunning())
+        return;
 
     wxString command = GetDockerExe();
-    if(command.IsEmpty()) return;
+    if(command.IsEmpty())
+        return;
 
     command << " ps "
                "--format=\"{{.ID}}|{{.Image}}|{{.Command}}|{{.CreatedAt}}|{{.Status}}|{{.Ports}}|{{.Names}}\" -a";
-    ::WrapInShell(command);
 
     // Get list of all containers
-    StartProcessAsync(command, "", IProcessCreateDefault, kListContainers);
+    StartProcessAsync(command, "", IProcessCreateDefault | IProcessWrapInShell, kListContainers);
 }
 
 void clDockerDriver::ListImages() { DoListImages(); }
@@ -178,41 +190,50 @@ void clDockerDriver::ListImages() { DoListImages(); }
 void clDockerDriver::DoListImages()
 {
     // Build the command
-    if(IsRunning()) return;
+    if(IsRunning())
+        return;
 
     wxString command = GetDockerExe();
-    if(command.IsEmpty()) return;
+    if(command.IsEmpty())
+        return;
 
     command << " image ls "
                "--format=\"{{.ID}}|{{.Repository}}|{{.Tag}}|{{.CreatedAt}}|{{.Size}}\" -a";
-    ::WrapInShell(command);
-    StartProcessAsync(command, "", IProcessCreateDefault, kListImages);
+
+    StartProcessAsync(command, "", IProcessCreateDefault | IProcessWrapInShell, kListImages);
 }
 
 void clDockerDriver::ClearUnusedImages()
 {
     // Build the command
-    if(IsRunning()) return;
+    if(IsRunning())
+        return;
 
     wxString command = GetDockerExe();
-    if(command.IsEmpty()) return;
+    if(command.IsEmpty())
+        return;
 
     command << " image prune --force";
     clDockerSettings s;
     s.Load();
-    if(s.IsRemoveAllImages()) { command << " --all"; }
-    ::WrapInShell(command);
-    StartProcessAsync(command, "", IProcessCreateDefault, kDeleteUnusedImages);
+    if(s.IsRemoveAllImages()) {
+        command << " --all";
+    }
+
+    StartProcessAsync(command, "", IProcessCreateDefault | IProcessWrapInShell, kDeleteUnusedImages);
 }
 
 void clDockerDriver::AttachTerminal(const wxArrayString& names)
 {
     // Sanity
-    if(IsRunning()) return;
-    if(names.IsEmpty()) return;
+    if(IsRunning())
+        return;
+    if(names.IsEmpty())
+        return;
 
     wxString command = GetDockerExe();
-    if(command.IsEmpty()) return;
+    if(command.IsEmpty())
+        return;
 
     for(size_t i = 0; i < names.size(); ++i) {
         wxString message;
@@ -225,47 +246,55 @@ wxString clDockerDriver::StartProcessSync(const wxString& command, const wxStrin
 {
     wxString outputString;
     IProcess::Ptr_t proc(::CreateSyncProcess(command, flags, wd));
-    if(proc) { proc->WaitForTerminate(outputString); }
+    if(proc) {
+        proc->WaitForTerminate(outputString);
+    }
     return outputString;
 }
 
 void clDockerDriver::ExecContainerCommand(const wxString& containerName, const wxString& containerCommand)
 {
     wxString command = GetDockerExe();
-    if(command.IsEmpty()) return;
+    if(command.IsEmpty())
+        return;
 
     command << " " << containerCommand << " " << containerName;
-    ::WrapInShell(command);
+
     StartProcessSync(command, "", IProcessCreateDefault);
 }
 
 void clDockerDriver::StopContainer(const wxString& containerName)
 {
-    if(IsRunning()) return;
+    if(IsRunning())
+        return;
 
     wxString command = GetDockerExe();
-    if(command.IsEmpty()) return;
+    if(command.IsEmpty())
+        return;
 
     command << " stop " << containerName;
-    ::WrapInShell(command);
-    StartProcessAsync(command, "", IProcessCreateDefault, kContext_StopContainer);
+
+    StartProcessAsync(command, "", IProcessCreateDefault | IProcessWrapInShell, kContext_StopContainer);
 }
 
 void clDockerDriver::StartContainer(const wxString& containerName)
 {
-    if(IsRunning()) return;
+    if(IsRunning())
+        return;
 
     wxString command = GetDockerExe();
-    if(command.IsEmpty()) return;
+    if(command.IsEmpty())
+        return;
 
     command << " restart " << containerName;
-    ::WrapInShell(command);
-    StartProcessAsync(command, "", IProcessCreateDefault, kContext_StartContainer);
+
+    StartProcessAsync(command, "", IProcessCreateDefault | IProcessWrapInShell, kContext_StartContainer);
 }
 
 void clDockerDriver::Build(const wxFileName& filepath, const clDockerWorkspaceSettings& settings)
 {
-    if(IsRunning()) return;
+    if(IsRunning())
+        return;
     clDockerBuildableFile::Ptr_t info = settings.GetFileInfo(filepath);
     wxString command = info->GetBuildBaseCommand();
     clGetManager()->ShowOutputPane(_("Docker"));
@@ -276,29 +305,31 @@ void clDockerDriver::Build(const wxFileName& filepath, const clDockerWorkspaceSe
     // Since we are building from the Dockerfile directory
     // we simply pass "."
     command << " . " << buildOptions;
-    ::WrapInShell(command);
+
     clDEBUG() << "Docker build:" << command;
 
     m_plugin->GetTerminal()->Clear();
     m_plugin->GetTerminal()->SelectTab("Output");
     m_plugin->GetTerminal()->AddOutputTextWithEOL(command);
-    StartProcessAsync(command, filepath.GetPath(), IProcessCreateDefault, kBuild);
+    StartProcessAsync(command, filepath.GetPath(), IProcessCreateDefault | IProcessWrapInShell, kBuild);
 }
 
 void clDockerDriver::Run(const wxFileName& filepath, const clDockerWorkspaceSettings& settings)
 {
     clDockerBuildableFile::Ptr_t info = settings.GetFileInfo(filepath);
-    
+
     // get the base command (docker exe + run/up)
     wxString command, args;
     info->GetRunBaseCommand(command, args);
-    
+
     // get user defined options
     wxString runOptions = info->GetRunOptions();
     runOptions.Trim().Trim(false);
-    if(!runOptions.empty()) { args << " " << runOptions; }
+    if(!runOptions.empty()) {
+        args << " " << runOptions;
+    }
     clDEBUG() << "Docker run:" << command << " " << args;
-    
+
     // Open terminal, and execute the command
     clConsoleBase::Ptr_t console = clConsoleBase::GetTerminal();
     console->SetTerminalNeeded(true);
