@@ -28,22 +28,35 @@
 #include "newclassdlg.h"
 #include "newwxprojectinfo.h"
 #include "plugin.h"
-#include "vector"
+#include <vector>
 
+using namespace std;
 class WizardsPlugin : public IPlugin
 {
     void CreateClass(NewClassInfo& info);
-    wxString DoGetVirtualFuncImpl(const NewClassInfo& info);
-    wxString DoGetVirtualFuncDecl(const NewClassInfo& info, const wxString& separator);
     std::vector<wxMenuItem*> m_vdDynItems;
     wxString m_folderpath;
 
 protected:
-    void CreateWxProject(NewWxProjectInfo& info);
     void GizmosRemoveDuplicates(std::vector<TagEntryPtr>& src, std::vector<TagEntryPtr>& target);
     void DoPopupButtonMenu(wxPoint pt);
     void OnFolderContentMenu(clContextMenuEvent& event);
 
+    /**
+     * @brief read the contet of multiple files
+     * @param files vector of pairs {`file-name` -> `file-content`}
+     * @param path_prefix prepend this prefix to each file before reading it
+     * @return false if we failed to read one or more files. In addition, both vectors size must me the same
+     */
+    bool BulkRead(vector<pair<wxString, wxString*>>& files, const wxString& path_prefix = wxEmptyString) const;
+    /**
+     * @brief read the contet of multiple files to the file system
+     * @param files vector of pairs {`file-name` -> `file-content`}
+     * @param path_prefix prepend this prefix to each file before reading it
+     * @return false if we failed to write one or more files. In addition, both vectors size must me the same
+     */
+    bool BulkWrite(const vector<pair<wxString, wxString>>& files, const wxString& path_prefix = wxEmptyString) const;
+
 public:
     WizardsPlugin(IManager* manager);
     ~WizardsPlugin();
@@ -58,14 +71,11 @@ public:
 
     void DoCreateNewPlugin();
     void DoCreateNewClass();
-    void DoCreateNewWxProject();
     // event handlers
     virtual void OnNewPlugin(wxCommandEvent& e);
     virtual void OnNewClass(wxCommandEvent& e);
     virtual void OnNewClassUI(wxUpdateUIEvent& e);
     virtual void OnNewPluginUI(wxUpdateUIEvent& e);
-    virtual void OnNewWxProject(wxCommandEvent& e);
-    virtual void OnNewWxProjectUI(wxUpdateUIEvent& e);
 
     // event handlers
     virtual void OnGizmos(wxCommandEvent& e);
