@@ -24,12 +24,12 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "LLDBSettings.h"
-#include <wx/filename.h>
 #include "cl_standard_paths.h"
-#include <wx/ffile.h>
-#include "cl_standard_paths.h"
-#include <wx/utils.h>
+#include "fileutils.h"
 #include "globals.h"
+#include <wx/ffile.h>
+#include <wx/filename.h>
+#include <wx/utils.h>
 
 #ifdef __WXMAC__
 static const wxString s_DefaultTypes = "type summary add wxString --summary-string \"${var.m_impl}\"\n"
@@ -53,27 +53,19 @@ LLDBSettings::LLDBSettings()
     m_types = s_DefaultTypes;
     wxFileName exePath;
 #ifdef __WXGTK__
-    // Default path to lldb-server
-    wxString path;
-    ::wxGetEnv("PATH", &path);
-    wxArrayString lldbServerOptions;
-    lldbServerOptions.Add("lldb-server"); // no version suffix
-    for(size_t major = 3; major < 8; ++major) {
-        for(size_t minor = 0; minor < 10; ++minor) {
-            lldbServerOptions.Add(wxString() << "lldb-server-" << major << "." << minor);
-        }
-    }
-    for(size_t i = 0; i < lldbServerOptions.size(); ++i) {
-        if(::clFindExecutable(lldbServerOptions.Item(i), exePath)) {
-            break;
-        }
+    // try to locate lldb-server
+    wxArrayString suffix_list;
+    suffix_list.reserve(30);
+    for(int i = 30; i > 0; --i) {
+        suffix_list.Add(wxString() << "-" << i);
     }
+    FileUtils::FindExe("lldb-server", exePath, {}, suffix_list);
 
 #elif defined(__WXOSX__)
     exePath = wxFileName(clStandardPaths::Get().GetBinaryFullPath("debugserver"));
 #endif
 
-    if(exePath.IsOk() && exePath.FileExists()) {
+    if(exePath.IsOk() && exePath.FileExists() && m_debugserver.empty()) {
         m_debugserver = exePath.GetFullPath();
     }
 }
