@@ -25,6 +25,7 @@ bool LSPClangdDetector::DoLocate()
         ConfigureFile(clangdExe);
         return true;
     }
+
 #elif defined(__WXOSX__)
     // Try the installation folder first
     wxFileName clangdExe(clStandardPaths::Get().GetBinaryFullPath("clangd"));
@@ -33,20 +34,23 @@ bool LSPClangdDetector::DoLocate()
         return true;
     }
 #elif defined(__WXGTK__)
-    wxFileName clangdExe(clStandardPaths::Get().GetUserDataDir(), "");
-    clangdExe.AppendDir("lsp");
-    clangdExe.AppendDir("clang-tools");
-    clangdExe.SetFullName("clangd");
-    if(clangdExe.FileExists()) {
-        ConfigureFile(clangdExe);
-        // this clangd requires LD_LIBRARY_PATH set properly
-        clEnvList_t environment;
-        environment.push_back({ "LD_LIBRARY_PATH", clangdExe.GetPath() });
-        SetEnv(environment);
+    // try the obvious name first: "clangd"
+    wxFileName fnClangdExe("/usr/bin", "clangd");
+    if(fnClangdExe.FileExists()) {
+        clSYSTEM() << "Found clangd ==>" << fnClangdExe << endl;
+        ConfigureFile(fnClangdExe);
         return true;
     }
+    wxArrayString suffix;
+    for(size_t i = 20; i >= 7; --i) {
+        fnClangdExe.SetFullName(wxString() << "clangd-" << i);
+        if(fnClangdExe.FileExists()) {
+            clSYSTEM() << "Found clangd ==>" << fnClangdExe << endl;
+            ConfigureFile(fnClangdExe);
+            return true;
+        }
+    }
 #endif
-
     CompilerLocatorCLANG locator;
     wxFileName fnClangd;
 #if defined(__WXMSW__)
