@@ -32,7 +32,6 @@
 #include <EditDlg.h>
 #include <build_config.h>
 #include <build_settings_config.h>
-#include <cl_aui_notebook_art.h>
 #include <event_notifier.h>
 #include <globals.h>
 #include <windowattrmanager.h>
@@ -90,10 +89,10 @@ CompilerMainPage::CompilerMainPage(wxWindow* parent)
     m_listLinkerOptions->InsertColumn(0, _("Switch"));
     m_listLinkerOptions->InsertColumn(1, _("Help"));
 
-    BitmapLoader* bmps = clGetManager()->GetStdIcons();
-    m_toolbar->AddTool(wxID_NEW, _("Add an existing compiler"), bmps->LoadBitmap("file_new"));
-    m_toolbar->AddTool(wxID_COPY, _("Copy compiler"), bmps->LoadBitmap("copy"));
-    m_toolbar->AddTool(wxID_FIND, _("Scan for compilers"), bmps->LoadBitmap("find"));
+    auto images = m_toolbar->GetBitmapsCreateIfNeeded();
+    m_toolbar->AddTool(wxID_NEW, _("Add an existing compiler"), images->Add("file_new"));
+    m_toolbar->AddTool(wxID_COPY, _("Copy compiler"), images->Add("copy"));
+    m_toolbar->AddTool(wxID_FIND, _("Scan for compilers"), images->Add("find"));
     m_toolbar->Realize();
     m_toolbar->Bind(wxEVT_TOOL, &CompilerMainPage::OnAddExistingCompiler, this, wxID_NEW);
     m_toolbar->Bind(wxEVT_TOOL, &CompilerMainPage::OnCloneCompiler, this, wxID_COPY);
@@ -713,6 +712,7 @@ void CompilerMainPage::InitializeAdvancePage()
     m_textObjectExtension->ChangeValue("");
     m_textDependExtension->ChangeValue("");
     m_textPreprocessExtension->ChangeValue("");
+    m_checkBoxGenerateDependenciesFiles->Enable(false);
     m_checkBoxGenerateDependenciesFiles->SetValue(false);
     m_textCtrlGlobalIncludePath->ChangeValue("");
     m_textCtrlGlobalLibPath->ChangeValue("");
@@ -722,6 +722,7 @@ void CompilerMainPage::InitializeAdvancePage()
     m_textObjectExtension->ChangeValue(m_compiler->GetObjectSuffix());
     m_textDependExtension->ChangeValue(m_compiler->GetDependSuffix());
     m_textPreprocessExtension->ChangeValue(m_compiler->GetPreprocessSuffix());
+    m_checkBoxGenerateDependenciesFiles->Enable(m_compiler->IsGnuCompatibleCompiler());
     m_checkBoxGenerateDependenciesFiles->SetValue(m_compiler->GetGenerateDependeciesFile());
     m_textCtrlGlobalIncludePath->ChangeValue(m_compiler->GetGlobalIncludePath());
     m_textCtrlGlobalLibPath->ChangeValue(m_compiler->GetGlobalLibPath());
