@@ -22,12 +22,15 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+#include "findresultstab.h"
+
 #include "ColoursAndFontsManager.h"
 #include "attribute_style.h"
 #include "bitmap_loader.h"
 #include "clStrings.h"
 #include "clToolBarButtonBase.h"
 #include "cl_aui_tool_stickness.h"
+#include "cl_command_event.h"
 #include "cl_config.h"
 #include "cl_editor.h"
 #include "codelite_events.h"
@@ -35,7 +38,6 @@
 #include "drawingutils.h"
 #include "editor_config.h"
 #include "event_notifier.h"
-#include "findresultstab.h"
 #include "frame.h"
 #include "globals.h"
 #include "lexer_configuration.h"
@@ -43,17 +45,13 @@
 #include "optionsconfig.h"
 #include "pluginmanager.h"
 #include "search_thread.h"
-#include "theme_handler.h"
+
 #include <algorithm>
 #include <wx/tokenzr.h>
 #include <wx/wupdlock.h>
 #include <wx/xrc/xmlres.h>
 
 BEGIN_EVENT_TABLE(FindResultsTab, OutputTabWindow)
-EVT_COMMAND(wxID_ANY, wxEVT_SEARCH_THREAD_SEARCHSTARTED, FindResultsTab::OnSearchStart)
-EVT_COMMAND(wxID_ANY, wxEVT_SEARCH_THREAD_MATCHFOUND, FindResultsTab::OnSearchMatch)
-EVT_COMMAND(wxID_ANY, wxEVT_SEARCH_THREAD_SEARCHEND, FindResultsTab::OnSearchEnded)
-EVT_COMMAND(wxID_ANY, wxEVT_SEARCH_THREAD_SEARCHCANCELED, FindResultsTab::OnSearchCancel)
 EVT_UPDATE_UI(XRCID("hold_pane_open"), FindResultsTab::OnHoldOpenUpdateUI)
 END_EVENT_TABLE()
 
@@ -61,17 +59,16 @@ FindResultsTab::FindResultsTab(wxWindow* parent, wxWindowID id, const wxString&
     : OutputTabWindow(parent, id, name)
     , m_searchInProgress(false)
 {
+    BindSearchEvents(this);
     m_sci->Connect(wxEVT_STC_STYLENEEDED, wxStyledTextEventHandler(FindResultsTab::OnStyleNeeded), NULL, this);
-
-    BitmapLoader& loader = *(PluginManager::Get()->GetStdIcons());
-
     wxTheApp->Connect(XRCID("find_in_files"), wxEVT_COMMAND_MENU_SELECTED,
                       wxCommandEventHandler(FindResultsTab::OnFindInFiles), NULL, this);
     m_tb->Bind(wxEVT_TOOL_DROPDOWN, &FindResultsTab::OnRecentSearches, this, XRCID("recent_searches"));
     m_tb->Bind(wxEVT_UPDATE_UI, &FindResultsTab::OnRecentSearchesUI, this, XRCID("recent_searches"));
 
-    m_tb->AddTool(XRCID("stop_search"), _("Stop current search"), loader.LoadBitmap("stop"), _("Stop current search"));
-    m_tb->AddTool(XRCID("recent_searches"), _("Show Recent Searches"), loader.LoadBitmap("history"),
+    auto images = m_tb->GetBitmapsCreateIfNeeded();
+    m_tb->AddTool(XRCID("stop_search"), _("Stop current search"), images->Add("stop"), _("Stop current search"));
+    m_tb->AddTool(XRCID("recent_searches"), _("Show Recent Searches"), images->Add("history"),
                   _("Show Recent Searches"), wxITEM_DROPDOWN);
 
     Connect(XRCID("stop_search"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(FindResultsTab::OnStopSearch),
@@ -89,6 +86,7 @@ FindResultsTab::FindResultsTab(wxWindow* parent, wxWindowID id, const wxString&
 
 FindResultsTab::~FindResultsTab()
 {
+    UnbindSearchEvents(this);
     EventNotifier::Get()->Connect(wxEVT_CL_THEME_CHANGED, wxCommandEventHandler(FindResultsTab::OnThemeChanged), NULL,
                                   this);
     wxTheApp->Disconnect(XRCID("find_in_files"), wxEVT_COMMAND_MENU_SELECTED,
@@ -116,13 +114,15 @@ void FindResultsTab::Clear()
 void FindResultsTab::OnFindInFiles(wxCommandEvent& e)
 {
     if(m_searchInProgress) {
-        ::wxMessageBox(_("The search thread is currently busy"), _("CodeLite"), wxICON_INFORMATION | wxOK);
+        ::wxMessageBox(_("Another search is currently running, try again later"), _("CodeLite"),
+                       wxICON_WARNING | wxOK | wxOK_DEFAULT);
         return;
     }
 
     // Fire the wxEVT_CMD_FIND_IN_FILES_SHOWING showing event
     clFindInFilesEvent eventFifShowing(wxEVT_FINDINFILES_DLG_SHOWING);
-    EventNotifier::Get()->ProcessEvent(eventFifShowing);
+    if(EventNotifier::Get()->ProcessEvent(eventFifShowing))
+        return;
 
     // Display the Find In Files dialog
     FindReplaceData frd;
@@ -150,15 +150,20 @@ void FindResultsTab::OnFindInFiles(wxCommandEvent& e)
 
         // Prepare the fif dialog
         FindInFilesDialog dlg(EventNotifier::Get()->TopFrame(), frd);
-        if(!fifPaths.IsEmpty()) { dlg.SetSearchPaths(fifPaths, !transientPaths.IsEmpty()); }
-        if(!mask.IsEmpty()) { dlg.SetFileMask(mask); }
+        if(!fifPaths.IsEmpty()) {
+            dlg.SetSearchPaths(fifPaths, !transientPaths.IsEmpty());
+        }
+
+        if(!mask.IsEmpty()) {
+            dlg.SetFileMask(mask);
+        }
 
         // Show it
         if((dlg.ShowDialog() == wxID_OK) && sendDismissEvent) {
             // Notify about the dialog dismissal
             clFindInFilesEvent eventDismiss(wxEVT_FINDINFILES_DLG_DISMISSED);
             eventDismiss.SetFileMask(frd.GetSelectedMask());
-            eventDismiss.SetPaths(frd.GetSearchPaths());
+            eventDismiss.SetPaths(frd.GetWhere());
             EventNotifier::Get()->ProcessEvent(eventDismiss);
         }
     }
@@ -196,24 +201,21 @@ void FindResultsTab::OnSearchStart(wxCommandEvent& e)
 void FindResultsTab::OnSearchMatch(wxCommandEvent& e)
 {
     SearchResultList* res = (SearchResultList*)e.GetClientData();
-    if(!res) return;
+    if(!res)
+        return;
 
     SearchResultList::iterator iter = res->begin();
     for(; iter != res->end(); ++iter) {
         if(m_matchInfo.empty() || m_matchInfo.rbegin()->second.GetFileName() != iter->GetFileName()) {
-            if(!m_matchInfo.empty()) { AppendText("\n"); }
-            wxFileName fn(iter->GetFileName());
-            fn.MakeRelativeTo();
-            AppendText(fn.GetFullPath() + wxT("\n"));
+            if(!m_matchInfo.empty()) {
+                AppendText("\n");
+            }
+            AppendText(iter->GetFileName() + wxT("\n"));
         }
 
         int lineno = m_sci->GetLineCount() - 1;
         m_matchInfo.insert(std::make_pair(lineno, *iter));
         wxString text = iter->GetPattern();
-        // int delta = -text.Length();
-        // text.Trim(false);
-        // delta += text.Length();
-        // text.Trim();
 
         wxString linenum = wxString::Format(wxT(" %5u: "), iter->GetLineNumber());
         SearchData* d = GetSearchData();
@@ -221,7 +223,9 @@ void FindResultsTab::OnSearchMatch(wxCommandEvent& e)
         if(d->GetDisplayScope()) {
             TagEntryPtr tag = TagsManagerST::Get()->FunctionFromFileLine(iter->GetFileName(), iter->GetLineNumber());
             wxString scopeName(wxT("global"));
-            if(tag) { scopeName = tag->GetPath(); }
+            if(tag) {
+                scopeName = tag->GetPath();
+            }
 
             linenum << wxT("[ ") << scopeName << wxT(" ] ");
             iter->SetScope(scopeName);
@@ -240,7 +244,8 @@ void FindResultsTab::OnSearchEnded(wxCommandEvent& e)
 {
     m_searchInProgress = false;
     SearchSummary* summary = (SearchSummary*)e.GetClientData();
-    if(!summary) return;
+    if(!summary)
+        return;
 
     // did the page closed before the search ended?
     AppendText(summary->GetMessage() + wxT("\n"));
@@ -272,7 +277,9 @@ void FindResultsTab::OnSearchEnded(wxCommandEvent& e)
     clMainFrame::Get()->GetMainBook()->GetAllEditors(editors, MainBook::kGetAll_IncludeDetached);
     for(size_t n = 0; n < editors.size(); ++n) {
         clEditor* editor = dynamic_cast<clEditor*>(*(editors.begin() + n));
-        if(editor) { editor->OnFindInFiles(); }
+        if(editor) {
+            editor->OnFindInFiles();
+        }
     }
 }
 
@@ -309,7 +316,9 @@ void FindResultsTab::OnMouseDClick(wxStyledTextEvent& e)
 
     } else {
         MatchInfo_t::const_iterator m = m_matchInfo.find(clickedLine);
-        if(m != m_matchInfo.end()) { DoOpenSearchResult(m->second, m_sci, m->first); }
+        if(m != m_matchInfo.end()) {
+            DoOpenSearchResult(m->second, m_sci, m->first);
+        }
     }
 }
 
@@ -319,7 +328,9 @@ void FindResultsTab::NextMatch()
 {
     // locate the last match
     int firstLine = m_sci->MarkerNext(0, 255);
-    if(firstLine == wxNOT_FOUND) { firstLine = 0; }
+    if(firstLine == wxNOT_FOUND) {
+        firstLine = 0;
+    }
 
     // We found the last marker
     for(int i = firstLine + 1; i < m_sci->GetLineCount(); i++) {
@@ -343,7 +354,9 @@ void FindResultsTab::PrevMatch()
 {
     // locate the last match
     int firstLine = m_sci->MarkerPrevious(m_sci->GetLineCount() - 1, 255);
-    if(firstLine == wxNOT_FOUND) { firstLine = m_sci->GetLineCount(); }
+    if(firstLine == wxNOT_FOUND) {
+        firstLine = m_sci->GetLineCount();
+    }
 
     // We found the last marker
     for(int i = firstLine - 1; i >= 0; i--) {
@@ -365,6 +378,23 @@ void FindResultsTab::PrevMatch()
 void FindResultsTab::DoOpenSearchResult(const SearchResult& result, wxStyledTextCtrl* sci, int markerLine)
 {
     if(!result.GetFileName().IsEmpty()) {
+        // let plugins handle this first
+        clFindInFilesEvent open_event(wxEVT_FINDINFILES_OPEN_MATCH);
+
+        // prepare a single match entry and fire it
+        clFindInFilesEvent::Match match;
+        clFindInFilesEvent::Location loc;
+        match.file = result.GetFileName();
+        loc.column_start = result.GetColumn();
+        loc.column_end = result.GetColumn() + result.GetLen();
+        loc.line = result.GetLineNumber();
+        match.locations.push_back(loc);
+        open_event.GetMatches().push_back(match);
+
+        if(EventNotifier::Get()->ProcessEvent(open_event)) {
+            return;
+        }
+
         clEditor* editor = clMainFrame::Get()->GetMainBook()->OpenFile(result.GetFileName());
         if(editor && result.GetLen() >= 0) {
             // Update the destination position if there have been subsequent changes in the editor
@@ -394,17 +424,15 @@ void FindResultsTab::DoOpenSearchResult(const SearchResult& result, wxStyledText
                 }
             }
             if(!removed) {
-                editor->SetEnsureCaretIsVisible(
-                    position + resultLength, true,
-                    true); // The 3rd parameter sets a small delay, otherwise it fails for long folded files
+                // use the "Async" way of loading the file and then selecting the match
+                // this ensures that the results are visible and centered in screen
                 int lineNumber = editor->LineFromPos(position);
-                if(lineNumber) { lineNumber--; }
-                editor->SetLineVisible(lineNumber);
-                editor->SetSelection(position, position + resultLength);
-
-#ifdef __WXGTK__
-                editor->ScrollToColumn(0);
-#endif
+                auto callback = [=](IEditor* p_editor) {
+                    p_editor->GetCtrl()->ClearSelections();
+                    p_editor->GetCtrl()->SetSelection(position, position + resultLength);
+                    p_editor->CenterLinePreserveSelection(lineNumber);
+                };
+                clGetManager()->OpenFileAndAsyncExecute(editor->GetFileName().GetFullPath(), std::move(callback));
 
                 if(sci) {
                     // remove the previous marker and add the new one
@@ -429,7 +457,9 @@ void FindResultsTab::OnStopSearchUI(wxUpdateUIEvent& e) { e.Enable(m_searchInPro
 void FindResultsTab::OnHoldOpenUpdateUI(wxUpdateUIEvent& e)
 {
     int sel = clMainFrame::Get()->GetOutputPane()->GetNotebook()->GetSelection();
-    if(clMainFrame::Get()->GetOutputPane()->GetNotebook()->GetPage(sel) != this) { return; }
+    if(clMainFrame::Get()->GetOutputPane()->GetNotebook()->GetPage(sel) != this) {
+        return;
+    }
 
     if(EditorConfigST::Get()->GetOptions()->GetHideOutpuPaneOnUserClick()) {
         e.Enable(true);
@@ -444,7 +474,8 @@ void FindResultsTab::OnHoldOpenUpdateUI(wxUpdateUIEvent& e)
 void FindResultsTab::OnStyleNeeded(wxStyledTextEvent& e)
 {
     wxStyledTextCtrl* ctrl = dynamic_cast<wxStyledTextCtrl*>(e.GetEventObject());
-    if(!ctrl) return;
+    if(!ctrl)
+        return;
     StyleText(ctrl, e);
 }
 
@@ -479,7 +510,9 @@ void FindResultsTab::OnRecentSearches(wxCommandEvent& e)
     int clearHistory = ::wxNewId();
     menu.Append(clearHistory, _("Clear History"));
     int sel = m_tb->GetMenuSelectionFromUser(XRCID("recent_searches"), &menu);
-    if(sel == wxID_NONE) { return; }
+    if(sel == wxID_NONE) {
+        return;
+    }
     if(sel == clearHistory) {
         m_history.Clear();
 
@@ -501,7 +534,9 @@ void FindResultsTab::SaveSearchData()
     entry.indicators = m_indicators;
 
     // search for an entry with the same title
-    if(m_history.Contains(entry.title)) { m_history.Remove(entry.title); }
+    if(m_history.Contains(entry.title)) {
+        m_history.Remove(entry.title);
+    }
     m_history.PushBack(entry.title, entry);
 }
 
@@ -525,12 +560,32 @@ void FindResultsTab::OnRecentSearchesUI(wxUpdateUIEvent& e) { e.Enable(!m_histor
 
 void FindResultsTab::ResetStyler() { m_styler->Reset(); }
 
-void FindResultsTab::OnWorkspaceClosed(wxCommandEvent& event)
+void FindResultsTab::OnWorkspaceClosed(clWorkspaceEvent& event)
 {
     event.Skip();
     Clear();
 }
 
+void FindResultsTab::UnbindSearchEvents(wxEvtHandler* binder)
+{
+    if(!m_searchEventsConnected)
+        return;
+    m_searchEventsConnected = false;
+    binder->Unbind(wxEVT_SEARCH_THREAD_SEARCHSTARTED, &FindResultsTab::OnSearchStart, this);
+    binder->Unbind(wxEVT_SEARCH_THREAD_MATCHFOUND, &FindResultsTab::OnSearchMatch, this);
+    binder->Unbind(wxEVT_SEARCH_THREAD_SEARCHEND, &FindResultsTab::OnSearchEnded, this);
+    binder->Unbind(wxEVT_SEARCH_THREAD_SEARCHCANCELED, &FindResultsTab::OnSearchCancel, this);
+}
+
+void FindResultsTab::BindSearchEvents(wxEvtHandler* binder)
+{
+    binder->Bind(wxEVT_SEARCH_THREAD_SEARCHSTARTED, &FindResultsTab::OnSearchStart, this);
+    binder->Bind(wxEVT_SEARCH_THREAD_MATCHFOUND, &FindResultsTab::OnSearchMatch, this);
+    binder->Bind(wxEVT_SEARCH_THREAD_SEARCHEND, &FindResultsTab::OnSearchEnded, this);
+    binder->Bind(wxEVT_SEARCH_THREAD_SEARCHCANCELED, &FindResultsTab::OnSearchCancel, this);
+    m_searchEventsConnected = true;
+}
+
 /////////////////////////////////////////////////////////////////////////////////
 
 void EditorDeltasHolder::GetChanges(std::vector<int>& changes)
