@@ -24,27 +24,27 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "options_dlg2.h"
-#include "plugin.h"
-#include "editorsettingsdockingwidows.h"
-#include "editorsettingsterminal.h"
-#include "editorsettingscaret.h"
-#include "globals.h"
 
-#include "frame.h"
-#include "editor_options_general_guides_panel.h"
+#include "EditorOptionsGeneralEdit.h"
+#include "EditorOptionsGeneralGuidesPanel.h"
+#include "clTabRendererMinimal.hpp"
 #include "editoroptionsgeneralindentationpanel.h"
 #include "editoroptionsgeneralrightmarginpanel.h"
 #include "editoroptionsgeneralsavepanel.h"
-#include "globals.h"
-
+#include "editorsettingsbookmarkspanel.h"
+#include "editorsettingscaret.h"
 #include "editorsettingscomments.h"
 #include "editorsettingscommentsdoxygenpanel.h"
-#include "editorsettingsbookmarkspanel.h"
+#include "editorsettingsdockingwidows.h"
 #include "editorsettingsfolding.h"
 #include "editorsettingsmiscpanel.h"
+#include "editorsettingsterminal.h"
+#include "frame.h"
+#include "globals.h"
 #include "manager.h"
+#include "plugin.h"
 #include "windowattrmanager.h"
-#include "EditorOptionsGeneralEdit.h"
+
 #include <wx/persist.h>
 #include <wx/persist/bookctrl.h>
 #include <wx/persist/toplevel.h>
@@ -56,13 +56,6 @@ PreferencesDialog::PreferencesDialog(wxWindow* parent)
     , restartRquired(false)
 {
     Initialize();
-    SetName("PreferencesDialog");
-    WindowAttrManager::Load(this);
-    MSWSetNativeTheme(m_treeBook->GetTreeCtrl());
-    GetSizer()->Fit(this);
-    GetSizer()->Layout();
-    CenterOnParent();
-    //::clSetDialogBestSizeAndPosition(this);
 }
 
 PreferencesDialog::~PreferencesDialog() {}
@@ -85,8 +78,7 @@ void PreferencesDialog::DoSave()
     // for performance reasons, we start a transaction for the configuration
     // file
     EditorConfigST::Get()->Begin();
-    typedef std::list<TreeBookNodeBase*>::iterator ContentIter;
-    for(ContentIter it = m_contentObjects.begin(), end = m_contentObjects.end(); it != end; ++it) {
+    for(auto it = m_contentObjects.begin(), end = m_contentObjects.end(); it != end; ++it) {
         if(*it) {
             TreeBookNodeBase* child = *it;
             child->Save(options);
@@ -111,17 +103,16 @@ void PreferencesDialog::Initialize()
     AddPage(new EditorOptionsGeneralGuidesPanel(m_treeBook), _("Guides"), true);
     AddPage(new EditorOptionsGeneralEdit(m_treeBook), _("Edit"), false);
     AddPage(new EditorOptionsGeneralIndentationPanel(m_treeBook), _("Indentation"));
-    AddPage(new EditorOptionsGeneralRightMarginPanel(m_treeBook), _("Right Margin Indicator"));
-    AddPage(new EditorSettingsCaret(m_treeBook), _("Caret & Scrolling"));
+    AddPage(new EditorOptionsGeneralRightMarginPanel(m_treeBook), _("Right Margin"));
+    AddPage(new EditorSettingsCaret(m_treeBook), _("Caret / Scrolling"));
     AddPage(new EditorOptionsGeneralSavePanel(m_treeBook), _("Save Options"));
     AddPage(new EditorSettingsComments(m_treeBook), _("Code"));
     AddPage(new EditorSettingsCommentsDoxygenPanel(m_treeBook), _("Documentation"));
     AddPage(new EditorSettingsFolding(m_treeBook), _("Folding"));
     AddPage(new EditorSettingsBookmarksPanel(m_treeBook), _("Bookmarks"));
-    AddPage(new EditorSettingsDockingWindows(m_treeBook), _("Windows & Tabs"));
-
-    // the Terminal page should NOT be added under Windows
+    AddPage(new EditorSettingsDockingWindows(m_treeBook), _("Windows / Tabs"));
     AddPage(new EditorSettingsTerminal(m_treeBook), _("Terminal"));
     AddPage(new EditorSettingsMiscPanel(m_treeBook), _("Misc"));
-    SetMinSize(wxSize(300, 200));
+    SetMinSize(wxSize(500, 300));
+    clSetDialogBestSizeAndPosition(this);
 }
