@@ -23,24 +23,28 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
+#include "syntaxhighlightdlg.h"
+
 #include "ColoursAndFontsManager.h"
-#include "EclipseCXXThemeImporter.h"
-#include "EclipseThemeImporterManager.h"
 #include "NewThemeDialog.h"
+#include "ThemeImporterCXX.hpp"
+#include "ThemeImporterManager.hpp"
+#include "clSystemSettings.h"
 #include "clZipReader.h"
 #include "clZipWriter.h"
 #include "cl_config.h"
+#include "cl_defs.h"
 #include "context_manager.h"
 #include "editor_config.h"
 #include "event_notifier.h"
+#include "file_logger.h"
 #include "fileutils.h"
 #include "frame.h"
 #include "free_text_dialog.h"
 #include "macros.h"
 #include "manager.h"
-#include "syntaxhighlightdlg.h"
-#include "theme_handler.h"
 #include "windowattrmanager.h"
+
 #include <algorithm>
 #include <wx/busyinfo.h>
 #include <wx/choicdlg.h>
@@ -53,7 +57,6 @@
 #include <wx/utils.h>
 #include <wx/wupdlock.h>
 #include <wx/xrc/xmlres.h>
-#include "clSystemSettings.h"
 
 #define CXX_AND_JAVASCRIPT "c++"
 
@@ -69,7 +72,8 @@ const wxString sampleText = "class Demo {\n"
                             "     * Creates a new demo.\n"
                             "     * @param o The object\n"
                             "     */\n"
-                            "    Demo(const Demo &other) {\n"
+                            "    CallMethod(const Demo& other) {\n"
+                            "        std::string a_string = \"hello world\";\n"
                             "        m_str = other.m_str;\n"
                             "        m_integer = other.m_integer;\n"
                             "    }\n"
@@ -88,7 +92,9 @@ SyntaxHighlightDlg::SyntaxHighlightDlg(wxWindow* parent)
     wxString lexerName;
     clEditor* editor = clMainFrame::Get()->GetMainBook()->GetActiveEditor(true);
     wxArrayString lexers = ColoursAndFontsManager::Get().GetAllLexersNames();
-    if(editor) { lexerName = editor->GetContext()->GetName().Lower(); }
+    if(editor) {
+        lexerName = editor->GetContext()->GetName().Lower();
+    }
 
     for(size_t i = 0; i < lexers.GetCount(); ++i) {
         if(lexers.Item(i) == "c++") {
@@ -112,25 +118,43 @@ SyntaxHighlightDlg::SyntaxHighlightDlg(wxWindow* parent)
     m_choiceGlobalTheme->SetStringSelection(ColoursAndFontsManager::Get().GetGlobalTheme());
 
     // Set the current editor font to the default one
-    wxFont font = clConfig::Get().Read("GlobalThemeFont", wxNullFont);
-    if(font.IsOk()) { m_fontPickerGlobal->SetSelectedFont(font); }
+    // but first check that we have entry in the configuration file
+    // for this
+    bool found_font = false;
+    wxFont font;
+    clConfig::Get().Read("GlobalThemeFont", [&found_font](const JSONItem& item) { found_font = true; });
+
+    if(found_font) {
+        wxMessageBox("Font found!");
+        wxFont font = clConfig::Get().Read("GlobalThemeFont", wxNullFont);
+        m_fontPickerGlobal->SetSelectedFont(font);
+    }
 
     DoUpdatePreview();
 
-    m_isModified = false;
+    // incase we don't have initial font display, use the preview window's font
+    if(!found_font) {
+        wxFont initialFont = m_stcPreview->StyleGetFont(0);
+        if(initialFont.IsOk()) {
+            m_fontPickerGlobal->SetSelectedFont(initialFont);
+        }
+    }
+    m_isModified = true;
+
+    // for now, we only allow selection with fg colour
+    m_checkBoxCustomSelectionFgColour->SetValue(true);
+    m_checkBoxCustomSelectionFgColour->Enable(false);
+
     SetName("SyntaxHighlightDlg");
     WindowAttrManager::Load(this);
-    m_toolbar->SetMiniToolBar(false);
-    m_toolbar->AddTool(wxID_NEW, _("New Theme"), clGetManager()->GetStdIcons()->LoadBitmap("file_new"));
-    m_toolbar->AddTool(wxID_SAVE, _("Export"), clGetManager()->GetStdIcons()->LoadBitmap("file_save"));
-    m_toolbar->AddTool(XRCID("export_all"), _("Export All"),
-                       clGetManager()->GetStdIcons()->LoadBitmap("file_save_all"));
-    m_toolbar->AddTool(XRCID("import_zip"), _("Import from ZIP file"),
-                       clGetManager()->GetStdIcons()->LoadBitmap("file_open"));
-    m_toolbar->AddTool(XRCID("revert_changes"), _("Reaload Default Settings"),
-                       clGetManager()->GetStdIcons()->LoadBitmap("file_reload"));
-    m_toolbar->AddTool(XRCID("import_eclipse_theme"), _("Import Eclipse Theme"),
-                       clGetManager()->GetStdIcons()->LoadBitmap("eclipse"), "", wxITEM_DROPDOWN);
+    auto images = clGetManager()->GetStdIcons();
+
+    m_toolbar->AddTool(wxID_NEW, _("New.."), images->LoadBitmap("file_new", 24));
+    m_toolbar->AddTool(wxID_SAVE, _("Export.."), images->LoadBitmap("file_save", 24));
+    m_toolbar->AddTool(XRCID("export_all"), _("Export All"), images->LoadBitmap("file_save_all", 24));
+    m_toolbar->AddTool(XRCID("import_zip"), _("Import from ZIP file"), images->LoadBitmap("file_open", 24));
+    m_toolbar->AddTool(XRCID("revert_changes"), _("Restore"), images->LoadBitmap("file_reload", 24));
+    m_toolbar->AddTool(XRCID("import_eclipse_theme"), _("Import"), images->LoadBitmap("file_open", 24));
     m_toolbar->Realize();
     m_toolbar->Bind(wxEVT_TOOL, &SyntaxHighlightDlg::OnNewTheme, this, wxID_NEW);
     m_toolbar->Bind(wxEVT_TOOL, &SyntaxHighlightDlg::OnExportSelective, this, wxID_SAVE);
@@ -138,19 +162,9 @@ SyntaxHighlightDlg::SyntaxHighlightDlg(wxWindow* parent)
     m_toolbar->Bind(wxEVT_TOOL, &SyntaxHighlightDlg::OnImport, this, XRCID("import_zip"));
     m_toolbar->Bind(wxEVT_TOOL, &SyntaxHighlightDlg::OnRestoreDefaults, this, XRCID("revert_changes"));
     m_toolbar->Bind(wxEVT_TOOL, &SyntaxHighlightDlg::OnImportEclipseTheme, this, XRCID("import_eclipse_theme"));
-    m_toolbar->Bind(
-        wxEVT_TOOL_DROPDOWN,
-        [&](wxCommandEvent& e) {
-            wxMenu m;
-            m.Append(XRCID("load_eclipse_theme_website"), _("Load Eclipse Themes WebSite.."));
-            m.Bind(wxEVT_MENU, &SyntaxHighlightDlg::OnLoadEclipseThemeWebsite, this,
-                   XRCID("load_eclipse_theme_website"));
-            m_toolbar->ShowMenuForButton(XRCID("import_eclipse_theme"), &m);
-        },
-        XRCID("import_eclipse_theme"));
 
     // Theme handling
-    wxColour baseColour = clConfig::Get().Read("BaseColour", clSystemSettings::GetColour(wxSYS_COLOUR_3DFACE));
+    wxColour baseColour = clConfig::Get().Read("BaseColour", clSystemSettings::GetDefaultPanelColour());
     m_colourPickerBaseColour->SetColour(baseColour);
     m_useBaseColourInitial = clConfig::Get().Read("UseCustomBaseColour", false);
     m_useBaseColourEnding = m_useBaseColourInitial;
@@ -159,7 +173,7 @@ SyntaxHighlightDlg::SyntaxHighlightDlg(wxWindow* parent)
         m_initialTheme = DrawingUtils::IsDark(baseColour) ? kTHEME_DARK : kTHEME_LIGHT;
         m_endingTheme = m_initialTheme;
     }
-    ::clSetDialogBestSizeAndPosition(this);
+    ::clSetTLWindowBestSizeAndPosition(this);
 }
 
 void SyntaxHighlightDlg::DoUpdatePreview()
@@ -167,13 +181,30 @@ void SyntaxHighlightDlg::DoUpdatePreview()
     // Populate the preview
     LexerConf::Ptr_t previewLexer =
         ColoursAndFontsManager::Get().GetLexer("c++", m_choiceGlobalTheme->GetStringSelection());
-    if(previewLexer) { previewLexer->Apply(m_stcPreview, true); }
-    m_stcPreview->SetKeyWords(1, "Demo std string");
-    m_stcPreview->SetKeyWords(3, "other");
+
+    int class_index = 1;
+    int locals_index = 1;
+    int methods_index = 1;
+    int other_index = 1;
+
+    if(previewLexer) {
+        previewLexer->Apply(m_stcPreview, true);
+        class_index = previewLexer->GetWordSetClassIndex();
+        locals_index = previewLexer->GetWordSetLocalsIndex();
+        methods_index = previewLexer->GetWordSetFunctionsIndex();
+        other_index = previewLexer->GetWordSetOthersIndex();
+    }
+
+    m_stcPreview->SetKeyWords(class_index, "Demo std string");
+    m_stcPreview->SetKeyWords(locals_index, "other");
+    m_stcPreview->SetKeyWords(methods_index, "CallMethod");
+    m_stcPreview->SetKeyWords(other_index, wxEmptyString);
+
     m_stcPreview->SetEditable(true);
     m_stcPreview->SetText(sampleText);
     m_stcPreview->HideSelection(true);
     m_stcPreview->SetEditable(false);
+
     ::clRecalculateSTCHScrollBar(m_stcPreview);
 }
 
@@ -204,14 +235,14 @@ void SyntaxHighlightDlg::Clear()
     // Global Settings page
     m_choiceLexerThemes->Clear();
     m_globalFontPicker->SetSelectedFont(clSystemSettings::GetFont(wxSYS_ANSI_FIXED_FONT));
-    m_globalBgColourPicker->SetColour(clSystemSettings::GetColour(wxSYS_COLOUR_WINDOW));
+    m_globalBgColourPicker->SetColour(clSystemSettings::GetDefaultPanelColour());
     m_fileSpec->ChangeValue("");
 
     // Customize page
     m_properties->Clear();
     m_fontPicker->SetSelectedFont(clSystemSettings::GetFont(wxSYS_ANSI_FIXED_FONT));
     m_colourPicker->SetColour(clSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT));
-    m_bgColourPicker->SetColour(clSystemSettings::GetColour(wxSYS_COLOUR_WINDOW));
+    m_bgColourPicker->SetColour(clSystemSettings::GetDefaultPanelColour());
     m_eolFilled->SetValue(false);
     m_styleWithinPreProcessor->SetValue(false);
 
@@ -225,9 +256,12 @@ void SyntaxHighlightDlg::LoadLexer(const wxString& themeName)
     wxWindowUpdateLocker locker(this);
     Clear();
     wxString lexer = m_listBox->GetStringSelection();
-    if(lexer.IsEmpty()) return;
+    if(lexer.IsEmpty())
+        return;
 
-    if(lexer == CXX_AND_JAVASCRIPT) { lexer = "c++"; }
+    if(lexer == CXX_AND_JAVASCRIPT) {
+        lexer = "c++";
+    }
 
     m_lexer = ColoursAndFontsManager::Get().GetLexer(lexer, themeName);
     CreateLexerPage();
@@ -264,13 +298,13 @@ void SyntaxHighlightDlg::SaveChanges()
         // Set the theme, it will update the global theme as well
         ColoursAndFontsManager::Get().SetTheme(m_choiceGlobalTheme->GetStringSelection());
         m_globalThemeChanged = false;
-        
+
         // Match the active tab colour with the selected theme
         LexerConf::Ptr_t cppLexer = ColoursAndFontsManager::Get().GetLexer("c++");
         if(cppLexer) {
             clConfig::Get().Write("ActiveTabMarkerColour", wxColour(cppLexer->GetProperty(wxSTC_C_WORD).GetFgColour()));
         }
-        
+
         m_lexer = ColoursAndFontsManager::Get().GetLexer(m_lexer->GetName());
         CallAfter(&SyntaxHighlightDlg::LoadLexer, m_lexer->GetThemeName());
     }
@@ -279,6 +313,9 @@ void SyntaxHighlightDlg::SaveChanges()
     clConfig::Get().Write("BaseColour", m_colourPickerBaseColour->GetColour());
     clConfig::Get().Write("UseCustomBaseColour", m_cbUseCustomBaseColour->IsChecked());
 
+    // Update the text selection colours
+    UpdateTextSelectionColours();
+
     // Now save the changes to the file system
     ColoursAndFontsManager::Get().Save();
     m_isModified = false;
@@ -288,7 +325,9 @@ SyntaxHighlightDlg::~SyntaxHighlightDlg()
 {
     // Write the global font
     wxFont font = m_fontPickerGlobal->GetSelectedFont();
-    if(font.IsOk()) { clConfig::Get().Write("GlobalThemeFont", font); }
+    if(font.IsOk()) {
+        clConfig::Get().Write("GlobalThemeFont", font);
+    }
 }
 
 void SyntaxHighlightDlg::OnColourChanged(wxColourPickerEvent& event)
@@ -359,7 +398,9 @@ void SyntaxHighlightDlg::OnEolFilled(wxCommandEvent& event)
     m_isModified = true;
     StyleProperty::Map_t& properties = m_lexer->GetLexerProperties();
     StyleProperty::Map_t::iterator iter = GetSelectedStyle();
-    if(iter != properties.end()) { iter->second.SetEolFilled(event.IsChecked()); }
+    if(iter != properties.end()) {
+        iter->second.SetEolFilled(event.IsChecked());
+    }
 }
 
 void SyntaxHighlightDlg::OnFontChanged(wxFontPickerEvent& event)
@@ -373,25 +414,17 @@ void SyntaxHighlightDlg::OnFontChanged(wxFontPickerEvent& event)
     if(obj == m_fontPicker) {
         wxFont f = event.GetFont();
         StyleProperty::Map_t::iterator iter = GetSelectedStyle();
-
-        iter->second.SetBold(f.GetWeight() == wxFONTWEIGHT_BOLD);
-        iter->second.SetFaceName(f.GetFaceName());
-        iter->second.SetFontSize(f.GetPointSize());
-        iter->second.SetUnderlined(f.GetUnderlined());
-        iter->second.SetItalic(f.GetStyle() == wxFONTSTYLE_ITALIC);
+        DoFontChanged(iter->second, f);
 
     } else if(obj == m_globalFontPicker) {
         wxFont f = event.GetFont();
         StyleProperty::Map_t::iterator iter = properties.begin();
         for(; iter != properties.end(); ++iter) {
-            iter->second.SetBold(f.GetWeight() == wxFONTWEIGHT_BOLD);
-            iter->second.SetFaceName(f.GetFaceName());
-            iter->second.SetFontSize(f.GetPointSize());
-            iter->second.SetUnderlined(f.GetUnderlined());
-            iter->second.SetItalic(f.GetStyle() == wxFONTSTYLE_ITALIC);
+            DoFontChanged(iter->second, f);
         }
         // update the style f picker as well
         m_fontPicker->SetSelectedFont(f);
+        ColoursAndFontsManager::Get().SetGlobalFont(f);
     }
 }
 
@@ -436,11 +469,10 @@ void SyntaxHighlightDlg::OnSelTextChanged(wxColourPickerEvent& event)
 {
     CHECK_PTR_RET(m_lexer);
     event.Skip();
-    StyleProperty& selProp = m_lexer->GetProperty(SEL_TEXT_ATTR_ID);
-    if(!selProp.IsNull()) {
-        m_isModified = true;
-        selProp.SetBgColour(event.GetColour().GetAsString(wxC2S_HTML_SYNTAX));
-    }
+    m_isModified = true;
+    ColoursAndFontsManager::Get().SetThemeTextSelectionColours(m_lexer->GetThemeName(),
+                                                               m_colourPickerSelTextBgColour->GetColour(),
+                                                               m_colourPickerSelTextFgColour->GetColour(), true);
 }
 
 void SyntaxHighlightDlg::OnStyleWithinPreprocessor(wxCommandEvent& event)
@@ -488,26 +520,20 @@ void SyntaxHighlightDlg::CreateLexerPage()
         }
     }
 
-    if(m_properties->GetCount()) { m_properties->SetSelection(0); }
+    if(m_properties->GetCount()) {
+        m_properties->SetSelection(0);
+    }
 
     wxString initialColor = clSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT).GetAsString(wxC2S_HTML_SYNTAX);
-    wxString bgInitialColor = clSystemSettings::GetColour(wxSYS_COLOUR_WINDOW).GetAsString(wxC2S_HTML_SYNTAX);
-    wxFont initialFont = wxNullFont;
+    wxString bgInitialColor = clSystemSettings::GetDefaultPanelColour().GetAsString(wxC2S_HTML_SYNTAX);
     // bool     initialEolFilled (false);
     bool initialStyleWithinPreProcessor(true);
 
-    if(m_propertyList.empty() == false) {
-        StyleProperty p;
-        p = m_propertyList.begin()->second;
-        initialColor = p.GetFgColour();
-        bgInitialColor = p.GetBgColour();
-
-        int size = p.GetFontSize();
-        wxString face = p.GetFaceName();
-        bool bold = p.IsBold();
-        initialFont = wxFont(size, wxFONTFAMILY_TELETYPE, wxFONTSTYLE_NORMAL,
-                             bold ? wxFONTWEIGHT_BOLD : wxFONTWEIGHT_NORMAL, false, face);
+    wxFont initialFont = ColoursAndFontsManager::Get().GetGlobalFont();
+    if(!initialFont.IsOk()) {
+        initialFont = DrawingUtils::GetDefaultFixedFont();
     }
+
     initialStyleWithinPreProcessor = m_lexer->GetStyleWithinPreProcessor();
     const StyleProperty& defaultStyle = m_lexer->GetProperty(0);
     if(!defaultStyle.IsNull()) {
@@ -518,13 +544,16 @@ void SyntaxHighlightDlg::CreateLexerPage()
 
     m_fontPicker->SetSelectedFont(initialFont);
     m_globalFontPicker->SetSelectedFont(initialFont);
+
     m_fileSpec->ChangeValue(m_lexer->GetFileSpec());
     m_styleWithinPreProcessor->SetValue(initialStyleWithinPreProcessor);
 
     // Update selected text properties
+    clDEBUG() << "Setting theme:" << m_lexer->GetName() << "selection colour: bg:" << selTextProperties.GetBgColour()
+              << ", fg:" << selTextProperties.GetFgColour() << endl;
     m_colourPickerSelTextBgColour->SetColour(selTextProperties.GetBgColour());
     m_colourPickerSelTextFgColour->SetColour(selTextProperties.GetFgColour());
-    m_checkBoxCustomSelectionFgColour->SetValue(m_lexer->IsUseCustomTextSelectionFgColour());
+    m_checkBoxCustomSelectionFgColour->SetValue(true);
 
     if(m_propertyList.empty()) {
         m_fontPicker->Enable(false);
@@ -535,9 +564,13 @@ void SyntaxHighlightDlg::CreateLexerPage()
     m_choiceLexerThemes->Clear();
     wxArrayString themes = ColoursAndFontsManager::Get().GetAvailableThemesForLexer(m_lexer->GetName());
     int sel = themes.Index(m_lexer->GetThemeName());
-    if(sel == -1) { sel = 0; }
+    if(sel == -1) {
+        sel = 0;
+    }
     m_choiceLexerThemes->Append(themes);
-    if(!m_choiceLexerThemes->IsEmpty()) { m_choiceLexerThemes->SetSelection(sel); }
+    if(!m_choiceLexerThemes->IsEmpty()) {
+        m_choiceLexerThemes->SetSelection(sel);
+    }
 }
 
 StyleProperty::Map_t::iterator SyntaxHighlightDlg::GetSelectedStyle()
@@ -550,9 +583,13 @@ StyleProperty::Map_t::iterator SyntaxHighlightDlg::GetSelectedStyle()
 void SyntaxHighlightDlg::OnLexerSelected(wxCommandEvent& event)
 {
     wxString lexerName = m_listBox->GetStringSelection();
-    if(lexerName == CXX_AND_JAVASCRIPT) { lexerName = "c++"; }
+    if(lexerName == CXX_AND_JAVASCRIPT) {
+        lexerName = "c++";
+    }
 
-    if(m_isModified) { SaveChanges(); }
+    if(m_isModified) {
+        SaveChanges();
+    }
     m_isModified = false;
     m_lexer = ColoursAndFontsManager::Get().GetLexer(lexerName);
     LoadLexer("");
@@ -560,20 +597,14 @@ void SyntaxHighlightDlg::OnLexerSelected(wxCommandEvent& event)
 
 void SyntaxHighlightDlg::OnButtonApplyUI(wxUpdateUIEvent& event) { event.Enable(m_isModified); }
 
-void SyntaxHighlightDlg::OnTextSelFgUI(wxUpdateUIEvent& event)
-{
-    event.Enable(m_checkBoxCustomSelectionFgColour->IsChecked());
-}
+void SyntaxHighlightDlg::OnTextSelFgUI(wxUpdateUIEvent& event) { event.Enable(true); }
 
 void SyntaxHighlightDlg::OnSelTextFgChanged(wxColourPickerEvent& event)
 {
     CHECK_PTR_RET(m_lexer);
     event.Skip();
-    StyleProperty& selProp = m_lexer->GetProperty(SEL_TEXT_ATTR_ID);
-    if(!selProp.IsNull()) {
-        m_isModified = true;
-        selProp.SetFgColour(event.GetColour().GetAsString(wxC2S_HTML_SYNTAX));
-    }
+    m_isModified = true;
+    UpdateTextSelectionColours();
 }
 
 void SyntaxHighlightDlg::OnUseCustomFgTextColour(wxCommandEvent& event)
@@ -581,7 +612,14 @@ void SyntaxHighlightDlg::OnUseCustomFgTextColour(wxCommandEvent& event)
     CHECK_PTR_RET(m_lexer);
     event.Skip();
     m_isModified = true;
-    m_lexer->SetUseCustomTextSelectionFgColour(event.IsChecked());
+    UpdateTextSelectionColours();
+}
+
+void SyntaxHighlightDlg::UpdateTextSelectionColours()
+{
+    ColoursAndFontsManager::Get().SetThemeTextSelectionColours(m_lexer->GetThemeName(),
+                                                               m_colourPickerSelTextBgColour->GetColour(),
+                                                               m_colourPickerSelTextFgColour->GetColour(), true);
 }
 
 void SyntaxHighlightDlg::OnNewTheme(wxCommandEvent& event)
@@ -593,14 +631,17 @@ void SyntaxHighlightDlg::OnNewTheme(wxCommandEvent& event)
         // Create new XML and load it
         LexerConf::Ptr_t newLexer =
             ColoursAndFontsManager::Get().CopyTheme(dlg.GetLexerName(), dlg.GetThemeName(), dlg.GetBaseTheme());
-        if(newLexer) { LoadLexer(newLexer->GetName()); }
+        if(newLexer) {
+            LoadLexer(newLexer->GetName());
+        }
     }
 }
 
 void SyntaxHighlightDlg::OnImport(wxCommandEvent& event)
 {
     wxString path = ::wxFileSelector(_("Select file"), "", "", "", "Zip Files (*.zip)|*.zip", wxFD_OPEN);
-    if(path.IsEmpty()) return;
+    if(path.IsEmpty())
+        return;
 
     wxFileName fn(path);
     clZipReader zr(fn);
@@ -632,53 +673,60 @@ void SyntaxHighlightDlg::OnExportSelective(wxCommandEvent& event)
     DoExport(lexersToExport);
 }
 
-void SyntaxHighlightDlg::OnExportAll(wxCommandEvent& event)
-{
-    // EclipseThemeImporterManager importer;
-    // importer.ImportCxxToAll();
-    DoExport();
-}
+void SyntaxHighlightDlg::OnExportAll(wxCommandEvent& event) { DoExport(); }
 
-void SyntaxHighlightDlg::OnToolExportAll(wxCommandEvent& event)
-{
-    // EclipseThemeImporterManager importer;
-    // importer.ImportCxxToAll();
-    DoExport();
-}
+void SyntaxHighlightDlg::OnToolExportAll(wxCommandEvent& event) { DoExport(); }
 
 void SyntaxHighlightDlg::OnRestoreDefaults(wxCommandEvent& event)
 {
     // Ask for confirmation
     if(::wxMessageBox(_("Are you sure you want to restore colours to factory defaults?\nBy choosing 'Yes', you will "
                         "lose all your local modifications"),
-                      _("Confirm"), wxICON_WARNING | wxYES_NO | wxCANCEL | wxNO_DEFAULT | wxCENTER, this) == wxYES) {
-        // Restore defaults
-        ColoursAndFontsManager::Get().RestoreDefaults();
-        // Dismiss the dialog
-        EndModal(wxID_OK);
-        // and reload it
-        wxCommandEvent openEvent(wxEVT_COMMAND_MENU_SELECTED, XRCID("syntax_highlight"));
-        clMainFrame::Get()->GetEventHandler()->AddPendingEvent(openEvent);
+                      _("Confirm"), wxICON_WARNING | wxYES_NO | wxCANCEL | wxNO_DEFAULT | wxCENTER, this) != wxYES) {
+        return;
     }
+
+    // Restore defaults
+    ColoursAndFontsManager::Get().RestoreDefaults();
+
+    // Dismiss the dialog
+    EndModal(wxID_OK);
+    // and reload it
+    wxCommandEvent openEvent(wxEVT_COMMAND_MENU_SELECTED, XRCID("syntax_highlight"));
+    clMainFrame::Get()->GetEventHandler()->AddPendingEvent(openEvent);
 }
 
 void SyntaxHighlightDlg::OnImportEclipseTheme(wxCommandEvent& event)
 {
-    wxFileDialog selector(this, _("Select eclipse XML theme file"), "", "", "Eclipse Theme Files (*.xml)|*.xml",
-                          wxFD_OPEN | wxFD_MULTIPLE | wxFD_FILE_MUST_EXIST);
+    wxFileDialog selector(this, _("Select theme to import"), "", "",
+                          "VSCode JSON Theme (*.json)|*.json|Eclipse Theme Files (*.xml)|*.xml",
+                          wxFD_OPEN | wxFD_FILE_MUST_EXIST);
     if(selector.ShowModal() == wxID_OK) {
-        wxArrayString files;
-        selector.GetPaths(files);
-        if(files.IsEmpty()) return;
-        for(size_t i = 0; i < files.size(); ++i) {
-            ColoursAndFontsManager::Get().ImportEclipseTheme(files.Item(i));
-        }
-        // Mark the dialg is modified and force a save
+
+        wxString path = selector.GetPath();
+        if(path.empty())
+            return;
+
         wxBusyCursor bc;
+        wxString theme_name = ColoursAndFontsManager::Get().ImportEclipseTheme(path);
+
+        wxString message;
+        message << _("Theme : '") << theme_name << _("' imported successfully!");
+        ::wxMessageBox(message);
+
+        int pos = m_choiceGlobalTheme->Append(theme_name);
+        if(pos != wxNOT_FOUND) {
+            m_choiceGlobalTheme->SetSelection(pos);
+        }
+
+        // Make this lexer the active one
+        LoadLexer(theme_name);
+        DoUpdatePreview();
+
+        // Mark the dialg is modified and force a save
         m_isModified = true;
         SaveChanges();
 
-        ::wxMessageBox(_("File imported successfully!"));
         // Dismiss the dialog
         EndModal(wxID_OK);
         // and reload it
@@ -695,13 +743,11 @@ void SyntaxHighlightDlg::OnLoadEclipseThemeWebsite(wxCommandEvent& event)
 
 void SyntaxHighlightDlg::OnGlobalThemeSelected(wxCommandEvent& event)
 {
-    m_globalThemeChanged = true;
-    m_isModified = true;
     DoUpdatePreview();
-
     LexerConf::Ptr_t previewLexer =
         ColoursAndFontsManager::Get().GetLexer("text", m_choiceGlobalTheme->GetStringSelection());
 
+    LoadLexer(m_choiceGlobalTheme->GetStringSelection());
     if(previewLexer && previewLexer->IsDark() && m_cbUseCustomBaseColour->IsChecked()) {
         wxColour bgColour = ColoursAndFontsManager::Get().GetBackgroundColourFromLexer(previewLexer);
         m_colourPickerBaseColour->SetColour(bgColour);
@@ -712,6 +758,8 @@ void SyntaxHighlightDlg::OnGlobalThemeSelected(wxCommandEvent& event)
         m_colourPickerBaseColour->SetColour(bgColour);
         m_endingTheme = kTHEME_LIGHT;
     }
+    m_globalThemeChanged = true;
+    m_isModified = true;
 }
 
 void SyntaxHighlightDlg::OnGlobalFontSelected(wxFontPickerEvent& event)
@@ -727,7 +775,8 @@ void SyntaxHighlightDlg::DoSetGlobalBgColour(const wxColour& colour)
     StyleProperty::Map_t::iterator iter = properties.begin();
     for(; iter != properties.end(); ++iter) {
         // Dont change the text selection using the global font picker
-        if(iter->second.GetName() == wxT("Text Selection")) continue;
+        if(iter->second.GetName() == wxT("Text Selection"))
+            continue;
         iter->second.SetBgColour(colour.GetAsString(wxC2S_HTML_SYNTAX));
     }
 
@@ -742,13 +791,17 @@ void SyntaxHighlightDlg::DoExport(const wxArrayString& lexers)
     // Select the 'save' path
     wxString path = ::wxFileSelector(_("Save as"), "", "MySettings.zip", "", wxFileSelectorDefaultWildcardStr,
                                      wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
-    if(path.IsEmpty()) { return; }
+    if(path.IsEmpty()) {
+        return;
+    }
 
     wxFileName jsonFile(path);
     jsonFile.SetFullName("lexers.json");
     // Delete the file when done
     FileUtils::Deleter deleter(jsonFile);
-    if(!ColoursAndFontsManager::Get().ExportThemesToFile(jsonFile, lexers)) { return; }
+    if(!ColoursAndFontsManager::Get().ExportThemesToFile(jsonFile, lexers)) {
+        return;
+    }
 
     // Add the file to the zip
     clZipWriter zw(path);
@@ -778,13 +831,30 @@ void SyntaxHighlightDlg::OnUseCustomBaseColour(wxCommandEvent& event)
         LexerConf::Ptr_t lexer =
             ColoursAndFontsManager::Get().GetLexer("text", m_choiceGlobalTheme->GetStringSelection());
         wxColour bgColour = ColoursAndFontsManager::Get().GetBackgroundColourFromLexer(lexer);
-        if(bgColour.IsOk()) { m_colourPickerBaseColour->SetColour(bgColour); }
+        if(bgColour.IsOk()) {
+            m_colourPickerBaseColour->SetColour(bgColour);
+        }
     }
     m_endingTheme = DrawingUtils::IsDark(m_colourPickerBaseColour->GetColour()) ? kTHEME_DARK : kTHEME_LIGHT;
     event.Skip();
 }
 
-bool SyntaxHighlightDlg::IsRestartRequired() const
+bool SyntaxHighlightDlg::IsRestartRequired() const { return false; }
+void SyntaxHighlightDlg::OnUseCustomBaseColourUI(wxUpdateUIEvent& event)
 {
-    return (m_useBaseColourEnding != m_useBaseColourInitial) || (m_initialTheme != m_endingTheme);
+#if CL_USE_NATIVEBOOK
+    event.Enable(false);
+    event.Check(false);
+#else
+    event.Enable(true);
+#endif
+}
+
+void SyntaxHighlightDlg::DoFontChanged(StyleProperty& sp, const wxFont& font)
+{
+    sp.SetBold(font.GetWeight() == wxFONTWEIGHT_BOLD);
+    sp.SetFaceName(font.GetFaceName());
+    sp.SetFontSize(font.GetPointSize());
+    sp.SetUnderlined(font.GetUnderlined());
+    sp.SetItalic(font.GetStyle() == wxFONTSTYLE_ITALIC);
 }
