@@ -1,5 +1,7 @@
 #include "ColoursAndFontsManager.h"
-#include "EclipseThemeImporterManager.h"
+
+#include "JSON.h"
+#include "ThemeImporterManager.hpp"
 #include "cl_command_event.h"
 #include "cl_standard_paths.h"
 #include "editor_config.h"
@@ -8,12 +10,13 @@
 #include "fileextmanager.h"
 #include "fileutils.h"
 #include "globals.h"
-#include "JSON.h"
 #include "macros.h"
 #include "wxStringHash.h"
 #include "xmlutils.h"
+
 #include <algorithm>
 #include <codelite_events.h>
+#include <imanager.h>
 #include <wx/busyinfo.h>
 #include <wx/dir.h>
 #include <wx/filename.h>
@@ -22,10 +25,7 @@
 #include <wx/sstream.h>
 #include <wx/tokenzr.h>
 #include <wx/xml/xml.h>
-#include "globals.h"
-#include <imanager.h>
 #include <wx/xrc/xmlres.h>
-#include "theme_handler_helper.h"
 
 // Upgrade macros
 #define LEXERS_VERSION_STRING "LexersVersion"
@@ -35,7 +35,9 @@ wxDEFINE_EVENT(wxEVT_UPGRADE_LEXERS_START, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_UPGRADE_LEXERS_END, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_UPGRADE_LEXERS_PROGRESS, clCommandEvent);
 
-static const wxString LexerTextDefaultXML =
+namespace
+{
+const wxString LexerTextDefaultXML =
     "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
     "<Lexer Name=\"text\" Theme=\"Default\" IsActive=\"No\" UseCustomTextSelFgColour=\"Yes\" "
     "StylingWithinPreProcessor=\"yes\" Id=\"1\">"
@@ -87,6 +89,52 @@ static const wxString LexerTextDefaultXML =
     "  </Properties>"
     "</Lexer>";
 
+void AddLexerKeywords(LexerConf::Ptr_t lexer, int setIndex, const std::vector<wxString>& words)
+{
+    wxString curwords = lexer->GetKeyWords(setIndex);
+    wxArrayString arrWords = ::wxStringTokenize(curwords, " ", wxTOKEN_STRTOK);
+    // use std::set to make sure that the elements are sorted
+    std::set<wxString> uniqueSet;
+    for(size_t i = 0; i < arrWords.size(); ++i) {
+        uniqueSet.insert(arrWords.Item(i));
+    }
+
+    // add the new words
+    for(const wxString& new_word : words) {
+        uniqueSet.insert(new_word);
+    }
+
+    // serialise them back to space delimited string
+    curwords.clear();
+    for(const auto& word : uniqueSet) {
+        curwords << word << " ";
+    }
+    lexer->SetKeyWords(curwords, setIndex);
+}
+
+wxString DEFAULT_THEME = "Atom One-Dark";
+
+void AddFileExtension(LexerConf::Ptr_t lexer, const wxString& extension)
+{
+    wxString spec = lexer->GetFileSpec();
+    wxString ext = extension;
+    ext.Replace(".", wxEmptyString);
+    ext.Replace("*", wxEmptyString);
+    ext.Prepend(".").Prepend("*");
+
+    wxString as_str;
+    auto extensions = ::wxStringTokenize(spec, ";,", wxTOKEN_STRTOK);
+    if(extensions.Index(ext) == wxNOT_FOUND) {
+        extensions.Add(ext);
+        as_str = ::wxJoin(extensions, ';');
+        lexer->SetFileSpec(as_str);
+    } else {
+        // already exists
+    }
+}
+
+} // namespace
+
 class clCommandEvent;
 ColoursAndFontsManager::ColoursAndFontsManager()
     : m_initialized(false)
@@ -143,7 +191,8 @@ struct ColoursAndFontsManagerLoaderHelper {
         for(size_t i = 0; i < files.GetCount(); ++i) {
             wxString content;
             wxFFile xmlFile(files.Item(i), "rb");
-            if(!xmlFile.IsOpened()) continue;
+            if(!xmlFile.IsOpened())
+                continue;
             if(xmlFile.ReadAll(&content, wxConvUTF8)) {
                 wxXmlDocument* doc = new wxXmlDocument();
                 wxStringInputStream sis(content);
@@ -163,20 +212,26 @@ struct ColoursAndFontsManagerLoaderHelper {
 
 void ColoursAndFontsManager::Load()
 {
-    if(m_initialized) return;
+    if(m_initialized)
+        return;
     m_lexersMap.clear();
     m_initialized = true;
-    m_globalTheme = "Default";
+    m_globalTheme = DEFAULT_THEME;
 
     // Load the global settings
     if(GetConfigFile().FileExists()) {
         JSON root(GetConfigFile());
-        if(root.isOk()) { m_globalTheme = root.toElement().namedObject("m_globalTheme").toString("Default"); }
+        if(root.isOk()) {
+            m_globalTheme = root.toElement().namedObject("m_globalTheme").toString("Atom One-Dark");
+        }
     }
 
     // Load the lexers
     ColoursAndFontsManagerLoaderHelper loader(this);
     loader.Load();
+
+    // read the global font property
+    m_globalFont = clConfig::Get().Read("GlobalThemeFont", DrawingUtils::GetDefaultFixedFont());
 }
 
 void ColoursAndFontsManager::LoadOldXmls(const std::vector<wxXmlDocument*>& xmlFiles, bool userLexers)
@@ -184,15 +239,16 @@ void ColoursAndFontsManager::LoadOldXmls(const std::vector<wxXmlDocument*>& xmlF
     // Each XMl represents a single lexer (the old format)
     for(size_t i = 0; i < xmlFiles.size(); ++i) {
         wxXmlDocument* doc = xmlFiles.at(i);
-        DoAddLexer(doc->GetRoot());
+        DEPRECATRED_DoAddLexer(doc->GetRoot());
     }
 }
 
-LexerConf::Ptr_t ColoursAndFontsManager::DoAddLexer(wxXmlNode* node)
+LexerConf::Ptr_t ColoursAndFontsManager::DEPRECATRED_DoAddLexer(wxXmlNode* node)
 {
     wxString lexerName = XmlUtils::ReadString(node, "Name");
     lexerName.MakeLower();
-    if(lexerName.IsEmpty()) return NULL;
+    if(lexerName.IsEmpty())
+        return NULL;
 
     LexerConf::Ptr_t lexer(new LexerConf);
     lexer->FromXml(node);
@@ -214,7 +270,9 @@ LexerConf::Ptr_t ColoursAndFontsManager::DoAddLexer(wxXmlNode* node)
 
     // Hack: fix Java lexer which is using the same
     // file extensions as C++...
-    if(lexer->GetName() == "java" && lexer->GetFileSpec().Contains(".cpp")) { lexer->SetFileSpec("*.java"); }
+    if(lexer->GetName() == "java" && lexer->GetFileSpec().Contains(".cpp")) {
+        lexer->SetFileSpec("*.java");
+    }
 
     // Append *.sqlite to the SQL lexer if missing
     if(lexer->GetName() == "sql" && !lexer->GetFileSpec().Contains(".sqlite")) {
@@ -251,19 +309,12 @@ LexerConf::Ptr_t ColoursAndFontsManager::DoAddLexer(wxXmlNode* node)
     }
 
     if(lexer->GetName() == "javascript") {
-        wxString jsWords = lexer->GetKeyWords(0);
-        wxArrayString arrWords = ::wxStringTokenize(jsWords, " ", wxTOKEN_STRTOK);
-        // use std::set to make sure that the elements are sorted
-        std::set<wxString> uniqueSet;
-        for(size_t i = 0; i < arrWords.size(); ++i) {
-            uniqueSet.insert(arrWords.Item(i));
-        }
-        uniqueSet.insert("class");
-        uniqueSet.insert("await");
-        uniqueSet.insert("async");
-        jsWords.clear();
-        std::for_each(uniqueSet.begin(), uniqueSet.end(), [&](const wxString& word) { jsWords << word << " "; });
-        lexer->SetKeyWords(jsWords, 0);
+        AddLexerKeywords(lexer, 0, { "class", "await", "async" });
+    }
+
+    // update script lexer with additional keywords
+    if(lexer->GetName() == "script") {
+        AddLexerKeywords(lexer, 0, { "return", "exit", "local", "function" });
     }
 
     // Add *.scss file extension to the css lexer
@@ -308,10 +359,14 @@ LexerConf::Ptr_t ColoursAndFontsManager::DoAddLexer(wxXmlNode* node)
     // name
     ColoursAndFontsManager::Vec_t::iterator iter =
         std::find_if(vec.begin(), vec.end(), LexerConf::FindByNameAndTheme(lexer->GetName(), lexer->GetThemeName()));
-    if(iter != vec.end()) { vec.erase(iter); }
+    if(iter != vec.end()) {
+        vec.erase(iter);
+    }
     iter = std::find_if(m_allLexers.begin(), m_allLexers.end(),
                         LexerConf::FindByNameAndTheme(lexer->GetName(), lexer->GetThemeName()));
-    if(iter != m_allLexers.end()) { m_allLexers.erase(iter); }
+    if(iter != m_allLexers.end()) {
+        m_allLexers.erase(iter);
+    }
     vec.push_back(lexer);
     m_allLexers.push_back(lexer);
     return lexer;
@@ -320,7 +375,8 @@ LexerConf::Ptr_t ColoursAndFontsManager::DoAddLexer(wxXmlNode* node)
 wxArrayString ColoursAndFontsManager::GetAvailableThemesForLexer(const wxString& lexerName) const
 {
     ColoursAndFontsManager::Map_t::const_iterator iter = m_lexersMap.find(lexerName.Lower());
-    if(iter == m_lexersMap.end()) return wxArrayString();
+    if(iter == m_lexersMap.end())
+        return wxArrayString();
 
     wxArrayString themes;
     const ColoursAndFontsManager::Vec_t& lexers = iter->second;
@@ -336,60 +392,109 @@ wxArrayString ColoursAndFontsManager::GetAvailableThemesForLexer(const wxString&
 LexerConf::Ptr_t ColoursAndFontsManager::GetLexer(const wxString& lexerName, const wxString& theme) const
 {
     ColoursAndFontsManager::Map_t::const_iterator iter = m_lexersMap.find(lexerName.Lower());
-    if(iter == m_lexersMap.end()) return m_defaultLexer;
+    if(iter == m_lexersMap.end())
+        return m_defaultLexer;
 
     // Locate the requested theme
     LexerConf::Ptr_t firstLexer(NULL);
     LexerConf::Ptr_t defaultLexer(NULL);
+    LexerConf::Ptr_t defaultDarkLexer(NULL);
+    LexerConf::Ptr_t defaultLightLexer(NULL);
+
+    // assume that the text theme is always up to date and exist
+    // based on that information, extract the active theme
+    auto textThemeIter = m_lexersMap.find("text");
+    LexerConf::Ptr_t defaultTextLexer(nullptr);
+    for(auto textTheme : textThemeIter->second) {
+        if(textTheme->IsActive()) {
+            defaultTextLexer = textTheme;
+        }
+    }
 
     if(theme.IsEmpty()) {
         // return the active theme
-        const ColoursAndFontsManager::Vec_t& lexers = iter->second;
-        for(size_t i = 0; i < lexers.size(); ++i) {
+        auto& allLexers = iter->second;
+        for(auto lexer : allLexers) {
 
-            if(!firstLexer) { firstLexer = lexers.at(i); }
-
-            if(!defaultLexer && lexers.at(i)->GetThemeName() == "Default") { defaultLexer = lexers.at(i); }
-
-            if(lexers.at(i)->IsActive()) return lexers.at(i);
+            if(!firstLexer) {
+                firstLexer = lexer;
+            }
+            if(!defaultLexer && lexer->GetThemeName() == DEFAULT_THEME) {
+                defaultLexer = lexer;
+            }
+            if(!defaultDarkLexer && lexer->IsDark()) {
+                defaultDarkLexer = lexer;
+            }
+            if(!defaultLightLexer && !lexer->IsDark()) {
+                defaultLightLexer = lexer;
+            }
+            if(lexer->IsActive()) {
+                return lexer;
+            }
         }
 
-        // No match
-        if(defaultLexer)
+        //
+        // No match, we use this logic to determine the best lexer:
+        //
+        if(defaultDarkLexer && defaultTextLexer && defaultTextLexer->IsDark()) {
+            // return the first dark lexer for this language
+            return defaultDarkLexer;
+        } else if(defaultLightLexer && defaultTextLexer && !defaultTextLexer->IsDark()) {
+            // return the first light lexer for this language
+            return defaultLightLexer;
+        } else if(defaultLexer) {
+            // return the lexer that matches the DEFAULT_THEME theme
             return defaultLexer;
-        else if(firstLexer)
+        } else if(firstLexer) {
+            // return the first one that we found
             return firstLexer;
-        else
+        } else {
+            // no lexers for this language, return the default lexer (which always exist)
             return m_defaultLexer;
+        }
 
     } else {
         const ColoursAndFontsManager::Vec_t& lexers = iter->second;
         LexerConf::Ptr_t themeDefaultLexer = nullptr;
         for(size_t i = 0; i < lexers.size(); ++i) {
-            if(lexers[i]->GetThemeName() == "Default") { themeDefaultLexer = lexers[i]; }
-            if(lexers[i]->GetThemeName() == theme) { return lexers[i]; }
+            if(lexers[i]->GetThemeName() == DEFAULT_THEME) {
+                themeDefaultLexer = lexers[i];
+            }
+            if(lexers[i]->GetThemeName() == theme) {
+                return lexers[i];
+            }
         }
-        // We failed to find the requested theme for this language. If we have a "Default"
+        // We failed to find the requested theme for this language. If we have a DEFAULT_THEME
         // lexer, return it, else use the minimal lexer ("m_defaultLexer")
         return (themeDefaultLexer ? themeDefaultLexer : m_defaultLexer);
     }
 }
 
-void ColoursAndFontsManager::Save(bool forExport)
+void ColoursAndFontsManager::Save(const wxFileName& lexer_json)
 {
+    bool for_export = lexer_json.IsOk();
     ColoursAndFontsManager::Map_t::const_iterator iter = m_lexersMap.begin();
     JSON root(cJSON_Array);
     JSONItem element = root.toElement();
     for(; iter != m_lexersMap.end(); ++iter) {
         const ColoursAndFontsManager::Vec_t& lexers = iter->second;
         for(size_t i = 0; i < lexers.size(); ++i) {
-            element.arrayAppend(lexers.at(i)->ToJSON(forExport));
+            element.arrayAppend(lexers.at(i)->ToJSON(for_export));
         }
     }
 
-    wxFileName lexerFiles(clStandardPaths::Get().GetUserDataDir(), "lexers.json");
-    lexerFiles.AppendDir("lexers");
-    root.save(lexerFiles);
+    wxFileName output_file = lexer_json;
+    if(!output_file.IsOk()) {
+        output_file = wxFileName(clStandardPaths::Get().GetUserDataDir(), "lexers.json");
+        output_file.AppendDir("lexers");
+    }
+    output_file.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
+
+    root.save(output_file);
+    // store the global font as well
+    if(m_globalFont.IsOk()) {
+        clConfig::Get().Write("GlobalThemeFont", m_globalFont);
+    }
     SaveGlobalSettings();
 
     clCommandEvent event(wxEVT_CMD_COLOURS_FONTS_UPDATED);
@@ -401,7 +506,9 @@ wxArrayString ColoursAndFontsManager::GetAllLexersNames() const
     wxArrayString names;
     for(size_t i = 0; i < m_allLexers.size(); ++i) {
         LexerConf::Ptr_t lexer = m_allLexers.at(i);
-        if(names.Index(lexer->GetName()) == wxNOT_FOUND) { names.Add(lexer->GetName()); }
+        if(names.Index(lexer->GetName()) == wxNOT_FOUND) {
+            names.Add(lexer->GetName());
+        }
     }
     names.Sort();
     return names;
@@ -409,28 +516,37 @@ wxArrayString ColoursAndFontsManager::GetAllLexersNames() const
 
 LexerConf::Ptr_t ColoursAndFontsManager::GetLexerForFile(const wxString& filename) const
 {
-    if(filename.IsEmpty()) return GetLexer("text");
+    if(filename.IsEmpty())
+        return GetLexer("text");
 
     wxFileName fnFileName(filename);
     wxString fileNameLowercase = fnFileName.GetFullName();
     fileNameLowercase.MakeLower();
 
-    LexerConf::Ptr_t defaultLexer(NULL);
-    LexerConf::Ptr_t firstLexer(NULL);
+    LexerConf::Ptr_t defaultLexer = nullptr;
+    LexerConf::Ptr_t firstLexer = nullptr;
+    LexerConf::Ptr_t firstLexerForTheme = nullptr;
+
+    // try and find a match for the current theme
+    const wxString& theme_name = GetGlobalTheme();
 
     // Scan the list of lexers, locate the active lexer for it and return it
-    ColoursAndFontsManager::Vec_t::const_iterator iter = m_allLexers.begin();
-    for(; iter != m_allLexers.end(); ++iter) {
-        wxString fileMask = (*iter)->GetFileSpec();
+    for(auto lexer : m_allLexers) {
+        wxString fileMask = lexer->GetFileSpec();
         if(FileUtils::WildMatch(fileMask, filename)) {
-            if((*iter)->IsActive()) {
-                return *iter;
+            if(lexer->IsActive()) {
+                return lexer;
 
             } else if(!firstLexer) {
-                firstLexer = *iter;
+                firstLexer = lexer;
 
-            } else if(!defaultLexer && (*iter)->GetThemeName() == "Default") {
-                defaultLexer = *iter;
+            } else if(!defaultLexer && lexer->GetThemeName() == DEFAULT_THEME) {
+                defaultLexer = lexer;
+            }
+
+            // try to find a theme that matches the current one
+            if(!firstLexerForTheme && lexer->GetThemeName() == theme_name) {
+                firstLexerForTheme = lexer;
             }
         }
     }
@@ -439,15 +555,23 @@ LexerConf::Ptr_t ColoursAndFontsManager::GetLexerForFile(const wxString& filenam
     // the file mask. However, if we did find a "firstLexer" it means
     // that we do have a lexer that matches the file extension, its just that it is not
     // set as active
-    if(firstLexer) { return firstLexer; }
+    if(firstLexerForTheme) {
+        return firstLexerForTheme;
+    } else if(firstLexer) {
+        return firstLexer;
+    }
 
     // Try this:
     // Use the FileExtManager to get the file type by examinig its content
     LexerConf::Ptr_t lexerByContent; // Null by default
     FileExtManager::FileType fileType = FileExtManager::TypeOther;
-    if(FileExtManager::AutoDetectByContent(filename, fileType) && fileType != FileExtManager::TypeOther) {
+    if(!FileExtManager::AutoDetectByContent(filename, fileType)) {
+        fileType = FileExtManager::GetType(filename);
+    }
+
+    if(fileType != FileExtManager::TypeOther) {
         switch(fileType) {
-        case FileExtManager::TypeScript:
+        case FileExtManager::TypeShellScript:
             lexerByContent = GetLexer("script");
             break;
         case FileExtManager::TypeJS:
@@ -465,13 +589,35 @@ LexerConf::Ptr_t ColoursAndFontsManager::GetLexerForFile(const wxString& filenam
         case FileExtManager::TypePython:
             lexerByContent = GetLexer("python");
             break;
+        case FileExtManager::TypeRuby:
+            lexerByContent = GetLexer("ruby");
+            break;
+        case FileExtManager::TypeRust:
+            lexerByContent = GetLexer("rust");
+            break;
+        case FileExtManager::TypeJava:
+            lexerByContent = GetLexer("java");
+            break;
+        case FileExtManager::TypeWorkspaceDocker:
+        case FileExtManager::TypeWorkspaceFileSystem:
+        case FileExtManager::TypeWorkspaceNodeJS:
+        case FileExtManager::TypeWorkspacePHP:
+        case FileExtManager::TypeWxCrafter:
+        case FileExtManager::TypeJSON:
+#if wxCHECK_VERSION(3, 1, 0)
+            lexerByContent = GetLexer("json");
+#else
+            lexerByContent = GetLexer("javascript");
+#endif
+            break;
         default:
             break;
         }
     }
 
     // If we managed to find a lexer by content, use it
-    if(lexerByContent) return lexerByContent;
+    if(lexerByContent)
+        return lexerByContent;
 
     // If we reached here, it means we could not locate an active lexer for this file type
     if(defaultLexer) {
@@ -504,7 +650,9 @@ void ColoursAndFontsManager::SetActiveTheme(const wxString& lexerName, const wxS
     wxArrayString themes = GetAvailableThemesForLexer(lexerName);
     for(size_t i = 0; i < themes.GetCount(); ++i) {
         LexerConf::Ptr_t lexer = GetLexer(lexerName, themes.Item(i));
-        if(lexer && lexer->GetName() == lexerName) { lexer->SetIsActive(lexer->GetThemeName() == themeName); }
+        if(lexer && lexer->GetName() == lexerName) {
+            lexer->SetIsActive(lexer->GetThemeName() == themeName);
+        }
     }
 }
 
@@ -546,25 +694,32 @@ LexerConf::Ptr_t ColoursAndFontsManager::CopyTheme(const wxString& lexerName, co
 
 void ColoursAndFontsManager::RestoreDefaults()
 {
+    wxFont font = GetGlobalFont();
+    wxString globalTheme = GetGlobalTheme();
+
     // First we delete the user settings
     {
         wxLogNull noLog;
         wxFileName fnLexersJSON(clStandardPaths::Get().GetUserLexersDir(), "lexers.json");
-        if(fnLexersJSON.Exists()) { clRemoveFile(fnLexersJSON.GetFullPath()); }
+        if(fnLexersJSON.Exists()) {
+            clRemoveFile(fnLexersJSON.GetFullPath());
+        }
     }
 
     // Now, we simply reload the settings
     Reload();
+
+    SetGlobalFont(font);
+    SetGlobalTheme(globalTheme);
 }
 
-bool ColoursAndFontsManager::ImportEclipseTheme(const wxString& eclipseXml)
+wxString ColoursAndFontsManager::ImportEclipseTheme(const wxString& theme_file)
 {
-    bool res = false;
-    if(!eclipseXml.IsEmpty()) {
-        EclipseThemeImporterManager importer;
-        return importer.Import(eclipseXml);
+    if(!theme_file.IsEmpty()) {
+        ThemeImporterManager importer;
+        return importer.Import(theme_file);
     }
-    return res;
+    return wxEmptyString;
 }
 
 void ColoursAndFontsManager::OnLexerFilesLoaded(const std::vector<wxXmlDocument*>& userLexers)
@@ -625,7 +780,9 @@ void ColoursAndFontsManager::UpdateLexerColours(LexerConf::Ptr_t lexer, bool for
         } else {
             lexer->SetLineNumbersFgColour(wxSystemSettings::GetColour(wxSYS_COLOUR_GRAYTEXT));
             StyleProperty& lineNumbers = lexer->GetProperty(LINE_NUMBERS_ATTR_ID); // Line numbers
-            if(!lineNumbers.IsNull()) { lineNumbers.SetBgColour(defaultProp.GetBgColour()); }
+            if(!lineNumbers.IsNull()) {
+                lineNumbers.SetBgColour(defaultProp.GetBgColour());
+            }
 
             // don't adjust PHP and HTML default colours, since they also affects the various operators
             // foreground colours
@@ -688,10 +845,18 @@ void ColoursAndFontsManager::UpdateLexerColours(LexerConf::Ptr_t lexer, bool for
         StyleProperty& identifier3 = lexer->GetProperty(wxSTC_CSS_IDENTIFIER3);
         StyleProperty& oper = lexer->GetProperty(wxSTC_CSS_OPERATOR);
         if(!var.IsNull()) {
-            if(!identifier.IsNull()) { identifier.SetFgColour(var.GetFgColour()); }
-            if(!identifier2.IsNull()) { identifier2.SetFgColour(var.GetFgColour()); }
-            if(!identifier3.IsNull()) { identifier3.SetFgColour(var.GetFgColour()); }
-            if(!oper.IsNull()) { oper.SetFgColour(isDark ? "WHITE" : "BLACK"); }
+            if(!identifier.IsNull()) {
+                identifier.SetFgColour(var.GetFgColour());
+            }
+            if(!identifier2.IsNull()) {
+                identifier2.SetFgColour(var.GetFgColour());
+            }
+            if(!identifier3.IsNull()) {
+                identifier3.SetFgColour(var.GetFgColour());
+            }
+            if(!oper.IsNull()) {
+                oper.SetFgColour(isDark ? "WHITE" : "BLACK");
+            }
         }
     }
 
@@ -701,7 +866,7 @@ void ColoursAndFontsManager::UpdateLexerColours(LexerConf::Ptr_t lexer, bool for
         indentGuides.SetFgColour(defaultProp.GetBgColour());
         indentGuides.SetBgColour(defaultProp.GetBgColour());
     }
-    
+
     if(force || m_lexersVersion < 6) {
         StyleProperty& caret = lexer->GetProperty(CARET_ATTR_ID);
         if(lexer->IsDark()) {
@@ -733,7 +898,7 @@ void ColoursAndFontsManager::SetTheme(const wxString& themeName)
         }
     }
     SetGlobalTheme(themeName);
-    
+
     clColours colours;
     bool useCustomColour = clConfig::Get().Read("UseCustomBaseColour", false);
     if(useCustomColour) {
@@ -744,7 +909,8 @@ void ColoursAndFontsManager::SetTheme(const wxString& themeName)
 
 void ColoursAndFontsManager::LoadJSON(const wxFileName& path)
 {
-    if(!path.FileExists()) return;
+    if(!path.FileExists())
+        return;
 
     JSON root(path);
     JSONItem arr = root.toElement();
@@ -763,7 +929,8 @@ LexerConf::Ptr_t ColoursAndFontsManager::DoAddLexer(JSONItem json)
     lexer->FromJSON(json);
 
     wxString lexerName = lexer->GetName().Lower();
-    if(lexerName.IsEmpty()) return NULL;
+    if(lexerName.IsEmpty())
+        return NULL;
 
     // ensure that the theme name is capitalized - this helps
     // when displaying the content in a wxListBox sorted
@@ -773,17 +940,20 @@ LexerConf::Ptr_t ColoursAndFontsManager::DoAddLexer(JSONItem json)
 
     clDEBUG1() << "Loading lexer:" << lexerName;
 
-    if(lexer->GetName() == "c++" && !lexer->GetKeyWords(0).Contains("final")) {
-        lexer->SetKeyWords(lexer->GetKeyWords(0) + " final", 0);
-    }
-
-    if(lexer->GetName() == "c++" && !lexer->GetKeyWords(0).Contains("override")) {
-        lexer->SetKeyWords(lexer->GetKeyWords(0) + " override", 0);
+    // Fix C++ lexer
+    if(lexer->GetName() == "c++") {
+        AddLexerKeywords(lexer, 0, { "override", "final", "constexpr" });
+        wxString filespec = lexer->GetFileSpec();
+        filespec.Replace("*.javascript", wxEmptyString);
+        filespec.Replace("*.js", wxEmptyString);
+        lexer->SetFileSpec(filespec);
     }
 
     // Hack: fix Java lexer which is using the same
     // file extensions as C++...
-    if(lexer->GetName() == "java" && lexer->GetFileSpec().Contains(".cpp")) { lexer->SetFileSpec("*.java"); }
+    if(lexer->GetName() == "java" && lexer->GetFileSpec().Contains(".cpp")) {
+        lexer->SetFileSpec("*.java");
+    }
 
     // Append *.sqlite to the SQL lexer if missing
     if(lexer->GetName() == "sql" && !lexer->GetFileSpec().Contains(".sqlite")) {
@@ -801,13 +971,10 @@ LexerConf::Ptr_t ColoursAndFontsManager::DoAddLexer(JSONItem json)
         lexer->SetFileSpec("*.vbs;*.vbe;*.wsf;*.wsc;*.asp;*.aspx");
     }
 
-    // Hack4: all the HTML support to PHP which have much more colour themes
-    if(lexer->GetName() == "javascript" && !lexer->GetFileSpec().Contains(".qml")) {
-        lexer->SetFileSpec("*.js;*.javascript;*.qml;*.json");
-    }
-
     // Hack5: all the remove *.scss from the css lexer (it now has its own lexer)
-    if(lexer->GetName() == "css" && lexer->GetFileSpec().Contains(".scss")) { lexer->SetFileSpec("*.css"); }
+    if(lexer->GetName() == "css" && lexer->GetFileSpec().Contains(".scss")) {
+        lexer->SetFileSpec("*.css");
+    }
 
     // Add *.less file extension to the css lexer
     if(lexer->GetName() == "css" && !lexer->GetFileSpec().Contains(".less")) {
@@ -831,30 +998,84 @@ LexerConf::Ptr_t ColoursAndFontsManager::DoAddLexer(JSONItem json)
     }
 
     // Add wxcp file extension to the JavaScript lexer
-    if(lexer->GetName() == "javascript" && !lexer->GetFileSpec().Contains(".wxcp")) {
-        lexer->SetFileSpec(lexer->GetFileSpec() + ";*.wxcp");
-    }
-
     if(lexer->GetName() == "javascript") {
-        wxString jsWords = lexer->GetKeyWords(0);
-        wxArrayString arrWords = ::wxStringTokenize(jsWords, " ", wxTOKEN_STRTOK);
-        // use std::set to make sure that the elements are sorted
-        std::set<wxString> uniqueSet;
-        for(size_t i = 0; i < arrWords.size(); ++i) {
-            uniqueSet.insert(arrWords.Item(i));
+#if wxCHECK_VERSION(3, 1, 0)
+        // remove the JSON file from the JavaScript
+        if(lexer->GetFileSpec().Contains("*.json")) {
+            auto specs = ::wxStringTokenize(lexer->GetFileSpec(), ";,", wxTOKEN_STRTOK);
+            int where = specs.Index("*.json");
+            if(where != wxNOT_FOUND) {
+                specs.RemoveAt(where);
+            }
+            lexer->SetFileSpec(wxJoin(specs, ';'));
         }
-        uniqueSet.insert("class");
-        uniqueSet.insert("await");
-        uniqueSet.insert("async");
-        uniqueSet.insert("extends");
-        uniqueSet.insert("constructor");
-        uniqueSet.insert("super");
-        jsWords.clear();
-        std::for_each(uniqueSet.begin(), uniqueSet.end(), [&](const wxString& word) { jsWords << word << " "; });
-        lexer->SetKeyWords(jsWords, 0);
+#else
+        // wxCrafter files
+        if(!lexer->GetFileSpec().Contains(".wxcp")) {
+            lexer->SetFileSpec(lexer->GetFileSpec() + ";*.wxcp");
+        }
+
+#endif
+        if(!lexer->GetFileSpec().Contains(".qml")) {
+            lexer->SetFileSpec(lexer->GetFileSpec() + ";*.qml");
+        }
+        // typescript
+        if(!lexer->GetFileSpec().Contains(".ts")) {
+            lexer->SetFileSpec(lexer->GetFileSpec() + ";*.ts");
+        }
+        const wxString ts_keywords = "break as any "
+                                     "case implements boolean "
+                                     "catch interface constructor "
+                                     "class let declare "
+                                     "const package get "
+                                     "continue private module "
+                                     "debugger protected require "
+                                     "default public number "
+                                     "delete static set "
+                                     "do yield string "
+                                     "else symbol "
+                                     "enum type "
+                                     "export from "
+                                     "extends of "
+                                     "false  "
+                                     "finally  "
+                                     "for  "
+                                     "function  "
+                                     "if  "
+                                     "import  "
+                                     "in  "
+                                     "instanceof  "
+                                     "new  "
+                                     "null  "
+                                     "readonly "
+                                     "return  "
+                                     "super  "
+                                     "switch  "
+                                     "this  "
+                                     "throw  "
+                                     "true  "
+                                     "try  "
+                                     "typeof  "
+                                     "var  "
+                                     "void  "
+                                     "while  "
+                                     "with ";
+        wxArrayString arr_keywords = ::wxStringTokenize(ts_keywords, " \t\n", wxTOKEN_STRTOK);
+        std::vector<wxString> vec_keywords;
+        vec_keywords.reserve(arr_keywords.size());
+        vec_keywords.insert(vec_keywords.end(), arr_keywords.begin(), arr_keywords.end());
+
+        AddLexerKeywords(lexer, 0, vec_keywords);
     }
 
-    if(lexer->GetName() == "text") { lexer->SetFileSpec(wxEmptyString); }
+    // update script lexer with additional keywords
+    if(lexer->GetName() == "script") {
+        AddLexerKeywords(lexer, 0, { "return", "exit", "local", "function" });
+    }
+
+    if(lexer->GetName() == "text") {
+        lexer->SetFileSpec(wxEmptyString);
+    }
 
     // Set the JavaScript keywords
     if(lexer->GetName() == "php" && !lexer->GetKeyWords(1).Contains("instanceof")) {
@@ -870,15 +1091,39 @@ LexerConf::Ptr_t ColoursAndFontsManager::DoAddLexer(JSONItem json)
             1);
     }
 
+    if(lexer->GetName() == "python") {
+        AddLexerKeywords(lexer, 0, { "await", "async", "True", "False", "None", "pass", "self" });
+        lexer->SetKeyWords("", 1);
+        lexer->SetKeyWords("", 2);
+        lexer->SetKeyWords("", 3);
+        lexer->SetKeyWords("", 4);
+        auto& sp_word_0 = lexer->GetProperty(wxSTC_P_WORD);
+        auto& sp_word_2 = lexer->GetProperty(wxSTC_P_WORD2);
+        if(sp_word_2.GetFgColour() == sp_word_0.GetFgColour()) {
+            // old configuration, dont set the variables fg colour to the same colour as the keywords
+            sp_word_2.SetFgColour(lexer->GetProperty(wxSTC_P_DEFNAME).GetFgColour());
+        }
+    }
+
+    // make sure we include Rakefile as a Ruby file
+    if(lexer->GetName() == "ruby") {
+        if(!lexer->GetFileSpec().Contains("Rakefile")) {
+            lexer->SetFileSpec(lexer->GetFileSpec() + ";Rakefile");
+        }
+    }
+
     if(lexer->GetName() == "makefile" && !lexer->GetFileSpec().Contains("*akefile.am")) {
         lexer->SetFileSpec(lexer->GetFileSpec() + ";*akefile.in;*akefile.am");
     }
+    if(lexer->GetName() == "properties") {
+        AddFileExtension(lexer, "*.toml");
+    }
 
     // Upgrade the lexer colours
     UpdateLexerColours(lexer, false);
 
     if(m_lexersMap.count(lexerName) == 0) {
-        m_lexersMap.insert(std::make_pair(lexerName, ColoursAndFontsManager::Vec_t()));
+        m_lexersMap.insert({ lexerName, ColoursAndFontsManager::Vec_t() });
     }
 
     ColoursAndFontsManager::Vec_t& vec = m_lexersMap.find(lexerName)->second;
@@ -888,11 +1133,15 @@ LexerConf::Ptr_t ColoursAndFontsManager::DoAddLexer(JSONItem json)
     // name
     ColoursAndFontsManager::Vec_t::iterator iter =
         std::find_if(vec.begin(), vec.end(), LexerConf::FindByNameAndTheme(lexer->GetName(), lexer->GetThemeName()));
-    if(iter != vec.end()) { vec.erase(iter); }
+    if(iter != vec.end()) {
+        vec.erase(iter);
+    }
 
     iter = std::find_if(m_allLexers.begin(), m_allLexers.end(),
                         LexerConf::FindByNameAndTheme(lexer->GetName(), lexer->GetThemeName()));
-    if(iter != m_allLexers.end()) { m_allLexers.erase(iter); }
+    if(iter != m_allLexers.end()) {
+        m_allLexers.erase(iter);
+    }
     vec.push_back(lexer);
     m_allLexers.push_back(lexer);
     return lexer;
@@ -936,7 +1185,9 @@ bool ColoursAndFontsManager::ExportThemesToFile(const wxFileName& outputFile, co
     JSONItem arr = root.toElement();
     std::vector<LexerConf::Ptr_t> Lexers;
     std::for_each(m_allLexers.begin(), m_allLexers.end(), [&](LexerConf::Ptr_t lexer) {
-        if(M.empty() || M.count(lexer->GetThemeName().Lower())) { Lexers.push_back(lexer); }
+        if(M.empty() || M.count(lexer->GetThemeName().Lower())) {
+            Lexers.push_back(lexer);
+        }
     });
     std::for_each(Lexers.begin(), Lexers.end(), [&](LexerConf::Ptr_t lexer) { arr.append(lexer->ToJSON(true)); });
     return FileUtils::WriteFileContent(outputFile, root.toElement().format());
@@ -969,7 +1220,9 @@ bool ColoursAndFontsManager::ImportLexersFile(const wxFileName& inputFile, bool
     }
 
     std::for_each(Lexers.begin(), Lexers.end(), [&](LexerConf::Ptr_t lexer) {
-        if(m_lexersMap.count(lexer->GetName()) == 0) { m_lexersMap[lexer->GetName()] = Vec_t(); }
+        if(m_lexersMap.count(lexer->GetName()) == 0) {
+            m_lexersMap[lexer->GetName()] = Vec_t();
+        }
         Vec_t& v = m_lexersMap[lexer->GetName()];
         Vec_t::iterator iter = std::find_if(
             v.begin(), v.end(), [&](LexerConf::Ptr_t l) { return l->GetThemeName() == lexer->GetThemeName(); });
@@ -982,7 +1235,9 @@ bool ColoursAndFontsManager::ImportLexersFile(const wxFileName& inputFile, bool
             v.push_back(lexer);
         } else {
             // We dont have this theme, add it
-            if(iter == v.end()) { v.push_back(lexer); }
+            if(iter == v.end()) {
+                v.push_back(lexer);
+            }
         }
     });
 
@@ -1010,14 +1265,20 @@ wxArrayString ColoursAndFontsManager::GetAllThemes() const
 void ColoursAndFontsManager::OnAdjustTheme(clCommandEvent& event)
 {
     event.Skip();
-    if(event.GetInt() != XRCID("adjust-current-theme")) { return; }
+    if(event.GetInt() != XRCID("adjust-current-theme")) {
+        return;
+    }
     event.Skip(false);
 
     LexerConf::Ptr_t lexer = ColoursAndFontsManager::Get().GetLexer("text");
-    if(!lexer) { return; }
+    if(!lexer) {
+        return;
+    }
 
     wxColour bgColour = GetBackgroundColourFromLexer(lexer);
-    if(!bgColour.IsOk()) { return; }
+    if(!bgColour.IsOk()) {
+        return;
+    }
 
     // Adjust the colours
     // Save the base colour changes
@@ -1027,14 +1288,13 @@ void ColoursAndFontsManager::OnAdjustTheme(clCommandEvent& event)
     // Notify this change
     clCommandEvent evt(wxEVT_CMD_COLOURS_FONTS_UPDATED);
     EventNotifier::Get()->AddPendingEvent(evt);
-
-    clGetManager()->DisplayMessage(_("A CodeLite restart is needed. Would you like to restart it now?"),
-                                   wxICON_QUESTION, { { XRCID("restart-codelite"), _("Yes") }, { wxID_NO, _("No") } });
 }
 
 wxColour ColoursAndFontsManager::GetBackgroundColourFromLexer(LexerConf::Ptr_t lexer) const
 {
-    if(!lexer) { return wxNullColour; }
+    if(!lexer) {
+        return wxNullColour;
+    }
     wxColour bgColour;
     if(lexer->IsDark()) {
         bgColour = lexer->GetProperty(0).GetBgColour();
@@ -1049,6 +1309,40 @@ wxColour ColoursAndFontsManager::GetBackgroundColourFromLexer(LexerConf::Ptr_t l
 bool ColoursAndFontsManager::IsDarkTheme() const
 {
     LexerConf::Ptr_t lexer = GetLexer("text");
-    if(!lexer) { return false; }
+    if(!lexer) {
+        return false;
+    }
     return lexer->IsDark();
 }
+
+void ColoursAndFontsManager::SetThemeTextSelectionColours(const wxString& theme_name, const wxColour& bg,
+                                                          const wxColour& fg, bool useCustomerFgColour)
+{
+    wxString theme_name_lc = theme_name.Lower();
+    for(auto& lexer : m_allLexers) {
+        if(lexer->GetThemeName().CmpNoCase(theme_name) == 0) {
+            auto& sp = lexer->GetProperty(SEL_TEXT_ATTR_ID);
+            sp.SetBgColour(bg.GetAsString(wxC2S_HTML_SYNTAX));
+            sp.SetFgColour(fg.GetAsString(wxC2S_HTML_SYNTAX));
+            lexer->SetUseCustomTextSelectionFgColour(useCustomerFgColour);
+        }
+    }
+}
+
+wxFont ColoursAndFontsManager::GetFixedFont(bool small) const
+{
+    auto lexer = GetLexer("text");
+    auto font = lexer->GetFontForSyle(0, EventNotifier::Get()->TopFrame());
+#ifndef __WXMAC__
+    if(small) {
+#if wxCHECK_VERSION(3, 1, 2)
+        font.SetFractionalPointSize(font.GetPointSize() * 0.9);
+#else
+        font.SetPointSize(font.GetPointSize() * 0.9);
+#endif
+    }
+#else
+    wxUnusedVar(small);
+#endif
+    return font;
+}
