@@ -1,8 +1,10 @@
-#include "Notebook.h"
 #include "NotebookNavigationDlg.h"
+
+#include "Notebook.h"
 #include "bitmap_loader.h"
 #include "file_logger.h"
 #include "globals.h"
+
 #include <algorithm>
 #include <imanager.h>
 #include <list>
@@ -91,71 +93,6 @@ NotebookNavigationDlg::NotebookNavigationDlg(wxWindow* parent, Notebook* book)
     FinalizeCtor();
 }
 
-NotebookNavigationDlg::NotebookNavigationDlg(wxWindow* parent, clMultiBook* book)
-    : NotebookNavigationDlgBase(parent)
-    , m_multibook(book)
-{
-    clTab::Vec_t allTabs;
-    clGetManager()->GetAllTabs(allTabs);
-    std::map<void*, clTab> tabsInfoMap;
-    for(size_t i = 0; i < allTabs.size(); ++i) {
-        tabsInfoMap.insert(std::make_pair((void*)allTabs.at(i).window, allTabs.at(i)));
-    }
-    m_dvListCtrl->SetBitmaps(clGetManager()->GetStdIcons()->GetStandardMimeBitmapListPtr());
-    m_dvListCtrl->SetColumnWidth(0, wxCOL_WIDTH_AUTOSIZE);
-    m_dvListCtrl->SetColumnWidth(1, wxCOL_WIDTH_AUTOSIZE);
-    clTabHistory::Ptr_t history = m_multibook->GetHistory();
-    const std::vector<wxWindow*>& windows = history->GetHistory();
-    // Populate the list
-    for(size_t i = 0; i < windows.size(); ++i) {
-        int index = m_multibook->GetPageIndex(windows[i]);
-        if(index != wxNOT_FOUND) {
-            wxString label = m_multibook->GetPageText(index);
-            wxBitmap bmp = m_multibook->GetPageBitmap(index);
-
-            wxVector<wxVariant> cols;
-            wxVariant colPath;
-            wxVariant colSaveIndicator;
-            TabData* d = new TabData;
-            d->bmp = bmp;
-            d->label = label;
-            d->index = index;
-
-            // add extra info
-            std::map<void*, clTab>::iterator iter = tabsInfoMap.find(windows[i]);
-            wxVariant mod;
-            int saveImgId = wxNOT_FOUND;
-            if(iter != tabsInfoMap.end()) {
-                d->isFile = iter->second.isFile;
-                d->filename = iter->second.filename;
-                if(iter->second.isModified) {
-                    saveImgId = clGetManager()->GetStdIcons()->GetImageIndex(BitmapLoader::kSave);
-                }
-            }
-            colSaveIndicator = ::MakeBitmapIndexText("", saveImgId);
-
-            // Prepare the display item
-            wxString text;
-            if(d->isFile && d->filename.GetDirCount()) {
-                wxFileName fn(d->filename.GetFullName());
-                fn.AppendDir(d->filename.GetDirs().Last());
-                text << fn.GetFullPath();
-            } else {
-                text << d->label;
-            }
-
-            // If the tab has a bitmap - use it
-            // otherwise, try to assign one
-            int imgId = clGetManager()->GetStdIcons()->GetMimeImageId(d->filename.GetFullName());
-            colPath = ::MakeBitmapIndexText(text, imgId);
-            cols.push_back(colPath);
-            cols.push_back(colSaveIndicator);
-            m_dvListCtrl->AppendItem(cols, (wxUIntPtr)d);
-        }
-    }
-    FinalizeCtor();
-}
-
 NotebookNavigationDlg::~NotebookNavigationDlg()
 {
     wxTheApp->Unbind(wxEVT_KEY_DOWN, &NotebookNavigationDlg::OnKeyDown, this);
