@@ -1,8 +1,9 @@
 #include "cLToolBarControl.h"
+
 #include "drawingutils.h"
 
 clToolBarControl::clToolBarControl(clToolBar* parent, wxWindow* control)
-    : clToolBarButtonBase(parent, wxID_ANY, wxNullBitmap, "", kControl)
+    : clToolBarButtonBase(parent, wxID_ANY, INVALID_BITMAP_ID, "", kControl)
     , m_ctrl(control)
 {
 }
@@ -19,10 +20,14 @@ void clToolBarControl::Render(wxDC& dc, const wxRect& rect)
 {
     wxUnusedVar(dc);
     wxRect controlRect = m_ctrl->GetRect();
+    controlRect.SetHeight(rect.GetHeight() - m_toolbar->GetYSpacer());
+    m_ctrl->SetSize(controlRect);
     controlRect = controlRect.CenterIn(rect, wxVERTICAL);
     controlRect.SetX(rect.GetX());
     m_ctrl->Move(controlRect.GetTopLeft());
     m_ctrl->SetBackgroundColour(DrawingUtils::GetMenuBarBgColour(m_toolbar->HasFlag(clToolBar::kMiniToolBar)));
     m_ctrl->SetForegroundColour(DrawingUtils::GetTextCtrlTextColour());
-    if(!m_ctrl->IsShown()) { m_ctrl->Show(); }
+    if(!m_ctrl->IsShown()) {
+        m_ctrl->Show();
+    }
 }
