@@ -1,20 +1,25 @@
+#include "clFileSystemWorkspaceConfig.hpp"
+
 #include "ICompilerLocator.h"
 #include "build_settings_config.h"
 #include "clFileSystemWorkspace.hpp"
-#include "clFileSystemWorkspaceConfig.hpp"
 #include "compiler_command_line_parser.h"
 #include "ctags_manager.h"
 #include "debuggermanager.h"
 #include "dirsaver.h"
+#include "event_notifier.h"
 #include "file_logger.h"
 #include "fileextmanager.h"
 #include "macromanager.h"
 #include "procutils.h"
 
-#define DEFAULT_FILE_EXTENSIONS "*.cpp;*.c;*.txt;*.json;*.hpp;*.cc;*.cxx;*.xml;*.h;*.wxcp;*.py;*.php;*.rb;*.html;*.js"
+#define DEFAULT_FILE_EXTENSIONS \
+    "*.cpp;*.c;*.txt;*.json;*.hpp;*.cc;*.cxx;*.xml;*.h;*.wxcp;*.py;*.php;*.rb;*.html;*.js;*.ts;*.rs"
 #define WORKSPACE_TYPE "File System Workspace"
 #define DEFAULT_EXCLUDE_FILE_PATTERN "*.o;*.pyc;*.obj;*.workspace;*.o.d;*.exe;*.dll;*.project"
 
+wxDEFINE_EVENT(wxEVT_FSW_SETTINGS_SAVED, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_FSW_SETTINGS_LOADED, clCommandEvent);
 clFileSystemWorkspaceConfig::clFileSystemWorkspaceConfig()
     : m_fileExtensions(DEFAULT_FILE_EXTENSIONS)
     , m_excludeFilesPattern(DEFAULT_EXCLUDE_FILE_PATTERN)
@@ -65,6 +70,9 @@ std::pair<JSONItem, JSONItem> clFileSystemWorkspaceConfig::ToJSON() const
     local.addProperty("remoteFolder", m_remoteFolder);
     local.addProperty("remoteAccount", m_remoteAccount);
     local.addProperty("workingDirectory", m_workingDirectory);
+    local.addProperty("debuggerPath", m_debuggerPath);
+    local.addProperty("debuggerCommands", m_debuggerCommands);
+    local.addProperty("last_executables", m_lastExecutables);
     return { shared, local };
 }
 
@@ -93,12 +101,19 @@ void clFileSystemWorkspaceConfig::FromLocalJSON(const JSONItem& json)
     m_flags = json["flags"].toSize_t(m_flags);
     m_compileFlags = json["compile_flags"].toArrayString();
     m_executable = json["executable"].toString();
+    wxArrayString last_execs = json["last_executables"].toArrayString();
+
+    // calling SetLastExecutables ensures that we dont add empty paths
+    SetLastExecutables(last_execs);
+
     m_args = json["arguments"].toString();
     m_environment = json["environment"].toString();
     m_compiler = json["compiler"].toString(m_compiler);
     m_remoteFolder = json["remoteFolder"].toString();
     m_remoteAccount = json["remoteAccount"].toString();
     m_workingDirectory = json["workingDirectory"].toString();
+    m_debuggerPath = json["debuggerPath"].toString();
+    m_debuggerCommands = json["debuggerCommands"].toString();
 }
 
 void clFileSystemWorkspaceConfig::FromJSONOld(const JSONItem& json)
@@ -154,16 +169,11 @@ clFileSystemWorkspaceConfig::Ptr_t clFileSystemWorkspaceConfig::Clone() const
 static wxArrayString GetExtraFlags(CompilerPtr compiler)
 {
     wxArrayString flags;
-#ifdef __WXMSW__
-    if(compiler->GetCompilerFamily() == COMPILER_FAMILY_MINGW) {
+    if(compiler->HasMetadata()) {
         flags.Add("-target");
-        if(compiler->Is64BitCompiler()) {
-            flags.Add("x86_64-pc-windows-gnu");
-        } else {
-            flags.Add("i686-pc-windows-gnu");
-        }
+        auto md = compiler->GetMetadata();
+        flags.Add(md.GetTarget());
     }
-#endif
     return flags;
 }
 
@@ -175,6 +185,11 @@ wxArrayString clFileSystemWorkspaceConfig::GetCompilerOptions(clBacktickCache::p
     CompilerPtr compiler = BuildSettingsConfigST::Get()->GetCompiler(GetCompiler());
     if(compiler) {
         wxArrayString compilerPaths = compiler->GetDefaultIncludePaths();
+        if(!compiler->GetGlobalIncludePath().IsEmpty()) {
+            wxArrayString globalIncludePaths =
+                ::wxStringTokenize(compiler->GetGlobalIncludePath(), ";", wxTOKEN_STRTOK);
+            compilerPaths.insert(compilerPaths.end(), globalIncludePaths.begin(), globalIncludePaths.end());
+        }
         for(wxString& compilerPath : compilerPaths) {
             compilerPath.Prepend("-I");
         }
@@ -246,6 +261,8 @@ wxArrayString clFileSystemWorkspaceConfig::ExpandUserCompletionFlags(const wxStr
             // -std=NNN
             searchPaths.push_back(cclp.GetStandardWithPrefix());
         }
+        // Other options
+        searchPaths.insert(searchPaths.end(), cclp.GetOtherOptions().begin(), cclp.GetOtherOptions().end());
     }
 
     // expand any macro
@@ -285,6 +302,21 @@ wxArrayString clFileSystemWorkspaceConfig::GetWorkspaceIncludes(bool withPrefix)
     return workspaceDirsArr;
 }
 
+void clFileSystemWorkspaceConfig::SetLastExecutables(const wxArrayString& lastExecutables)
+{
+    m_lastExecutables.clear();
+    m_lastExecutables.reserve(lastExecutables.size());
+    for(auto path : lastExecutables) {
+        path.Trim().Trim(false);
+        if(path.empty()) {
+            continue;
+        }
+        m_lastExecutables.Add(path);
+    }
+}
+
+const wxArrayString& clFileSystemWorkspaceConfig::GetLastExecutables() const { return m_lastExecutables; }
+
 ///===-------------------------------------
 /// Workspace settings
 ///===-------------------------------------
@@ -327,21 +359,37 @@ void clFileSystemWorkspaceSettings::FromJSON(const JSONItem& shared, const JSONI
     // The "selected config" is kept in the local workspace
     m_selectedConfig = local.namedObject("selected_config").toString();
     // load the configurations
-    JSONItem localConfigs = shared.namedObject("configs");
-    JSONItem sharedConfigs = local.namedObject("configs");
+    JSONItem sharedConfigs = shared.namedObject("configs");
+    JSONItem localConfigs = local.namedObject("configs");
     if(sharedConfigs.arraySize() != localConfigs.arraySize()) {
-        clWARNING() << "Local config and shared configs do not match!" << clEndl;
-        return;
+        clSYSTEM() << "Notice: File System Workspace: local config and shared configs do not match!" << endl;
     }
 
-    int nCount = localConfigs.arraySize();
+    // Loop over the local configs and keep them in a map
+    // this is because the number of confiugration entires in
+    // the local workspace does not match to the shared one
+    // this can happen when loading the workspace on different
+    // machines (when the shared version is kept in SCM)
+    std::unordered_map<wxString, JSONItem> localConfigsMap;
+
+    int localCount = localConfigs.arraySize();
+    for(int i = 0; i < localCount; ++i) {
+        auto c = localConfigs[i];
+        localConfigsMap.insert({ c["name"].toString(), c });
+    }
+
+    int nCount = sharedConfigs.arraySize();
     wxString firstConfig;
     bool selectedConfigFound = false;
     m_configsMap.clear();
     for(int i = 0; i < nCount; ++i) {
         clFileSystemWorkspaceConfig::Ptr_t conf(new clFileSystemWorkspaceConfig);
-        conf->FromSharedJSON(localConfigs.arrayItem(i));
-        conf->FromLocalJSON(sharedConfigs.arrayItem(i));
+        conf->FromSharedJSON(sharedConfigs.arrayItem(i));
+        auto iter = localConfigsMap.find(conf->GetName());
+        if(iter != localConfigsMap.end()) {
+            conf->FromLocalJSON(iter->second);
+        }
+
         if(firstConfig.empty()) {
             firstConfig = conf->GetName();
         }
@@ -356,11 +404,17 @@ void clFileSystemWorkspaceSettings::FromJSON(const JSONItem& shared, const JSONI
     }
 }
 
-bool clFileSystemWorkspaceSettings::Save(const wxFileName& filename)
+bool clFileSystemWorkspaceSettings::Save(const wxFileName& filename, const wxFileName& localSettings)
 {
     // store the
-    wxFileName localWorkspace = filename;
-    localWorkspace.AppendDir(".codelite");
+    wxFileName localWorkspace;
+
+    if(localSettings.IsOk()) {
+        localWorkspace = localSettings;
+    } else {
+        localWorkspace = filename;
+        localWorkspace.AppendDir(".codelite");
+    }
     localWorkspace.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
     JSON root_local(cJSON_Object);
     JSON root_shared(cJSON_Object);
@@ -370,14 +424,27 @@ bool clFileSystemWorkspaceSettings::Save(const wxFileName& filename)
     ToJSON(itemShared, itemLocal);
     root_shared.save(filename);
     root_local.save(localWorkspace);
+
+    clCommandEvent eventSaved(wxEVT_FSW_SETTINGS_SAVED);
+    EventNotifier::Get()->AddPendingEvent(eventSaved);
     return true;
 }
 
-bool clFileSystemWorkspaceSettings::Load(const wxFileName& filename)
+bool clFileSystemWorkspaceSettings::Load(const wxFileName& filename, const wxFileName& localSettings)
 {
-    wxFileName localWorkspace = filename;
-    localWorkspace.AppendDir(".codelite");
+    wxFileName localWorkspace;
+    if(localSettings.IsOk()) {
+        localWorkspace = localSettings;
+    } else {
+        localWorkspace = filename;
+        localWorkspace.AppendDir(".codelite");
+    };
+
     JSON root_shared(filename);
+    if(!root_shared.isOk()) {
+        clWARNING() << "Invalid File System Workspace file:" << filename << endl;
+        return false;
+    }
     JSON root_local(localWorkspace);
     if(!root_local.isOk()) {
         // old version
@@ -391,16 +458,27 @@ bool clFileSystemWorkspaceSettings::Load(const wxFileName& filename)
         auto iLocal = root_local.toElement();
         FromJSON(iShared, iLocal);
     }
+    clCommandEvent eventSaved(wxEVT_FSW_SETTINGS_LOADED);
+    EventNotifier::Get()->AddPendingEvent(eventSaved);
     return true;
 }
 
-bool clFileSystemWorkspaceSettings::AddConfig(const wxString& name)
+bool clFileSystemWorkspaceSettings::AddConfig(const wxString& name, const wxString& copyfrom)
 {
     if(m_configsMap.count(name)) {
         // already exists
+        clWARNING() << "Can't add new configurtion:" << name << ". Already exists" << endl;
         return false;
     }
-    clFileSystemWorkspaceConfig::Ptr_t conf(new clFileSystemWorkspaceConfig);
+
+    clFileSystemWorkspaceConfig::Ptr_t conf;
+    if(!copyfrom.IsEmpty() && GetConfig(copyfrom)) {
+        // clone the config
+        conf = GetConfig(copyfrom)->Clone();
+    } else {
+        // create an empty one
+        conf.reset(new clFileSystemWorkspaceConfig());
+    }
     conf->SetName(name);
     m_configsMap.insert({ name, conf });
     if(m_configsMap.size() == 1) {
