@@ -1,8 +1,10 @@
 #include "clKeyboardBindingConfig.h"
+
 #include "JSON.h"
-#include <wx/filename.h>
 #include "cl_standard_paths.h"
 
+#include <wx/filename.h>
+
 clKeyboardBindingConfig::clKeyboardBindingConfig() {}
 
 clKeyboardBindingConfig::~clKeyboardBindingConfig() {}
@@ -11,7 +13,9 @@ clKeyboardBindingConfig& clKeyboardBindingConfig::Load()
 {
     wxFileName fn(clStandardPaths::Get().GetUserDataDir(), "keybindings.conf");
     fn.AppendDir("config");
-    if(!fn.Exists()) return *this;
+    if(!fn.Exists()) {
+        return *this;
+    }
 
     m_bindings.clear();
     JSON root(fn);
@@ -22,21 +26,11 @@ clKeyboardBindingConfig& clKeyboardBindingConfig::Load()
         for(int i = 0; i < arrSize; ++i) {
             JSONItem item = menus.arrayItem(i);
             MenuItemData binding;
-            binding.action = item.namedObject("description").toString();
-            binding.accel = item.namedObject("accelerator").toString();
-            binding.parentMenu = item.namedObject("parentMenu").toString();
             binding.resourceID = item.namedObject("resourceID").toString();
-            if(binding.resourceID == "text_word_complete") {
-                // This entry was moved from Word Completion plugin to CodeLite Edit menu entry
-                binding.resourceID = "simple_word_completion";
-                binding.parentMenu = "Edit";
-                binding.action = "Complete Word";
-            } else if(binding.resourceID == "complete_word") {
-                // The "action" was changed
-                binding.action = "Code Complete";
-            } else if(binding.resourceID == "word_complete") {
-                binding.resourceID = "complete_word";
-            }
+            binding.parentMenu = item.namedObject("parentMenu").toString();
+            binding.action = item.namedObject("description").toString();
+            binding.accel.FromString(item.namedObject("accelerator").toString());
+            MigrateOldResourceID(binding.resourceID);
             m_bindings.insert(std::make_pair(binding.resourceID, binding));
         }
     }
@@ -51,10 +45,10 @@ clKeyboardBindingConfig& clKeyboardBindingConfig::Save()
     mainObj.append(menuArr);
     for(MenuItemDataMap_t::iterator iter = m_bindings.begin(); iter != m_bindings.end(); ++iter) {
         JSONItem binding = JSONItem::createObject();
-        binding.addProperty("description", iter->second.action);
-        binding.addProperty("accelerator", iter->second.accel);
         binding.addProperty("resourceID", iter->second.resourceID);
         binding.addProperty("parentMenu", iter->second.parentMenu);
+        binding.addProperty("description", iter->second.action);
+        binding.addProperty("accelerator", iter->second.accel.ToString());
         menuArr.arrayAppend(binding);
     }
     wxFileName fn(clStandardPaths::Get().GetUserDataDir(), "keybindings.conf");
@@ -62,3 +56,13 @@ clKeyboardBindingConfig& clKeyboardBindingConfig::Save()
     root.save(fn);
     return *this;
 }
+
+void clKeyboardBindingConfig::MigrateOldResourceID(wxString& resourceID) const
+{
+    if(resourceID == "text_word_complete") {
+        // This entry was moved from Word Completion plugin to CodeLite Edit menu entry
+        resourceID = "simple_word_completion";
+    } else if(resourceID == "word_complete") {
+        resourceID = "complete_word";
+    }
+}
