@@ -1,11 +1,15 @@
+#include "clRowEntry.h"
+
 #include "clCellValue.h"
 #include "clHeaderBar.h"
 #include "clHeaderItem.h"
-#include "clRowEntry.h"
 #include "clTreeCtrl.h"
+#include "file_logger.h"
+
 #include <algorithm>
 #include <drawingutils.h>
 #include <functional>
+#include <globals.h>
 #include <wx/dataview.h>
 #include <wx/dc.h>
 #include <wx/renderer.h>
@@ -16,33 +20,9 @@
 #define wxCONTROL_NONE 0
 #endif
 
-#ifdef __WXMSW__
-#define PEN_STYLE wxPENSTYLE_SHORT_DASH
-#define IS_MSW 1
-#else
-#define PEN_STYLE wxPENSTYLE_DOT
-#define IS_MSW 0
-#endif
-
-#ifdef __WXMSW__
-int clRowEntry::X_SPACER = 4;
-int clRowEntry::Y_SPACER = 0;
-#elif defined(__WXOSX__)
-int clRowEntry::X_SPACER = 4;
-int clRowEntry::Y_SPACER = 2;
-#else
-int clRowEntry::X_SPACER = 5;
-int clRowEntry::Y_SPACER = 2;
-#endif
-
-#ifdef __WXOSX__
-#define IS_OSX 1
-#else
-#define IS_OSX 0
-#endif
-
+namespace
+{
 struct clClipperHelper {
-
     bool m_used = false;
     wxRect m_oldRect;
     wxDC& m_dc;
@@ -78,26 +58,62 @@ struct clClipperHelper {
     }
 };
 
+wxString GetTextForRendering(const wxString& text)
+{
+    if(text.find('\n') != wxString::npos) {
+        wxString fixed_text = text;
+        fixed_text.Replace("\n", "\\n");
+        return fixed_text;
+    } else {
+        return text;
+    }
+}
+
+void DoDrawSimpleSelection(wxWindow* win, wxDC& dc, const wxRect& rect, const clColours& colours)
+{
+    wxColour c = win->HasFocus() ? colours.GetSelItemBgColour() : colours.GetSelItemBgColourNoFocus();
+    dc.SetPen(c);
+    dc.SetBrush(c);
+    dc.DrawRectangle(rect);
+}
+} // namespace
+
+#ifdef __WXMSW__
+int clRowEntry::X_SPACER = 4;
+int clRowEntry::Y_SPACER = 0;
+#elif defined(__WXOSX__)
+int clRowEntry::X_SPACER = 4;
+int clRowEntry::Y_SPACER = 2;
+#else
+int clRowEntry::X_SPACER = 5;
+int clRowEntry::Y_SPACER = 2;
+#endif
+
+// clang-format off
+#ifdef __WXMSW__
+#   define PEN_STYLE wxPENSTYLE_SHORT_DASH
+#   define IS_MSW 1
+#else
+#   define PEN_STYLE wxPENSTYLE_DOT
+#   define IS_MSW 0
+#endif
+
+#ifdef __WXOSX__
+#   define IS_OSX 1
+#else
+#   define IS_OSX 0
+#endif
+
+#ifdef __WXGTK__
+#   define IS_GTK 1
+#else
+#   define IS_GTK 0
+#endif
+// clang-format on
+
 void clRowEntry::DrawSimpleSelection(wxWindow* win, wxDC& dc, const wxRect& rect, const clColours& colours)
 {
-#ifdef __WXMSW__
-    if(m_tree->IsNativeTheme()) {
-        int flags = wxCONTROL_SELECTED;
-        if(win->HasFocus()) {
-            flags |= wxCONTROL_FOCUSED;
-        }
-        wxRendererNative::Get().DrawItemSelectionRect(win, dc, rect, flags);
-
-    } else {
-        dc.SetPen(win->HasFocus() ? colours.GetSelItemBgColour() : colours.GetSelItemBgColourNoFocus());
-        dc.SetBrush(win->HasFocus() ? colours.GetSelItemBgColour() : colours.GetSelItemBgColourNoFocus());
-        dc.DrawRectangle(rect);
-    }
-#else
-    dc.SetPen(win->HasFocus() ? colours.GetSelItemBgColour() : colours.GetSelItemBgColourNoFocus());
-    dc.SetBrush(win->HasFocus() ? colours.GetSelItemBgColour() : colours.GetSelItemBgColourNoFocus());
-    dc.DrawRectangle(rect);
-#endif
+    DoDrawSimpleSelection(win, dc, rect, colours);
 }
 
 clRowEntry::clRowEntry(clTreeCtrl* tree, const wxString& label, int bitmapIndex, int bitmapSelectedIndex)
@@ -154,18 +170,26 @@ void clRowEntry::InsertChild(clRowEntry* child, clRowEntry* prev)
     child->SetIndentsCount(GetIndentsCount() + 1);
 
     // We need the last item of this subtree (prev 'this' is the root)
-    if(prev == nullptr) {
+    if(prev == nullptr || prev == this) {
         // make it the first item
         m_children.insert(m_children.begin(), child);
     } else {
-        // Insert the item in the parent children list
-        clRowEntry::Vec_t::iterator iter = m_children.end();
-        iter = std::find_if(m_children.begin(), m_children.end(), [&](clRowEntry* c) { return c == prev; });
-        if(iter != m_children.end()) {
-            ++iter;
+
+        // optimization:
+        // we often get here by calling AddChild(), so don't loop over the list, check if `prev`
+        // is the last item
+        if(!m_children.empty() && m_children.back() == prev) {
+            m_children.insert(m_children.end(), child);
+        } else {
+            // Insert the item in the parent children list
+            clRowEntry::Vec_t::iterator iter = m_children.end();
+            iter = std::find_if(m_children.begin(), m_children.end(), [&](clRowEntry* c) { return c == prev; });
+            if(iter != m_children.end()) {
+                ++iter;
+            }
+            // if iter is end(), than the is actually appending the item
+            m_children.insert(iter, child);
         }
-        // if iter is end(), than the is actually appending the item
-        m_children.insert(iter, child);
     }
 
     // Connect the linked list for sequential iteration
@@ -341,16 +365,58 @@ void clRowEntry::ClearRects()
     m_rowRect = wxRect();
 }
 
-static int GetSizeDIP(int size, wxWindow* win)
+vector<size_t> clRowEntry::GetColumnWidths(wxWindow* win, wxDC& dc)
 {
-    if(!win) {
-        return size;
+    vector<size_t> v;
+    wxRect rowRect = GetItemRect();
+    int itemIndent = IsListItem() ? clHeaderItem::X_SPACER : (GetIndentsCount() * m_tree->GetIndent());
+    wxFont f = m_tree->GetDefaultFont();
+    dc.SetFont(f);
+    v.reserve(m_cells.size());
+
+    for(size_t i = 0; i < m_cells.size(); ++i) {
+        auto& cell = m_cells[i];
+        v.emplace_back();
+        size_t& width = v.back();
+
+        if((i == 0) && !IsListItem()) {
+            // space for the button
+            width += rowRect.GetHeight();
+        }
+
+        if(cell.IsBool()) {
+            // Render the checkbox
+            width += X_SPACER;
+            width += GetCheckBoxWidth(win);
+            width += X_SPACER;
+        }
+
+        int bitmapIndex = cell.GetBitmapIndex();
+        if(IsExpanded() && HasChildren() && cell.GetBitmapSelectedIndex() != wxNOT_FOUND) {
+            bitmapIndex = cell.GetBitmapSelectedIndex();
+        }
+
+        if(bitmapIndex != wxNOT_FOUND) {
+            const wxBitmap& bmp = m_tree->GetBitmap(bitmapIndex);
+            if(bmp.IsOk()) {
+                width += IsListItem() ? 0 : X_SPACER;
+                width += bmp.GetScaledWidth();
+                width += X_SPACER;
+            }
+        }
+
+        wxString text_to_render = GetTextForRendering(cell.GetValueString());
+        width += (i == 0 ? itemIndent : clHeaderItem::X_SPACER);
+        width += dc.GetTextExtent(text_to_render).GetWidth();
+        width += X_SPACER;
+
+        if(cell.IsChoice()) {
+            width += X_SPACER;
+            width += GetCheckBoxWidth(win);
+            width += X_SPACER;
+        }
     }
-#if wxCHECK_VERSION(3, 1, 0)
-    return win->FromDIP(size);
-#else
-    return size;
-#endif
+    return v;
 }
 
 void clRowEntry::Render(wxWindow* win, wxDC& dc, const clColours& c, int row_index, clSearchText* searcher)
@@ -394,10 +460,11 @@ void clRowEntry::Render(wxWindow* win, wxDC& dc, const clColours& c, int row_ind
         bool last_cell = (i == (m_cells.size() - 1));
         colours = c; // reset the colours
         clCellValue& cell = GetColumn(i);
-        wxFont f = cell.GetFont().IsOk() ? cell.GetFont() : m_tree->GetDefaultFont();
+        wxFont f = m_tree->GetDefaultFont();
         if(cell.GetFont().IsOk()) {
             f = cell.GetFont();
         }
+
         if(cell.GetTextColour().IsOk()) {
             colours.SetItemTextColour(cell.GetTextColour());
         }
@@ -405,13 +472,13 @@ void clRowEntry::Render(wxWindow* win, wxDC& dc, const clColours& c, int row_ind
             colours.SetItemBgColour(cell.GetBgColour());
         }
         dc.SetFont(f);
-        wxColour buttonColour = IsSelected() ? colours.GetSelbuttonColour() : colours.GetButtonColour();
+        wxColour buttonColour = IsSelected() ? colours.GetSelItemTextColour() : colours.GetItemTextColour();
         wxRect cellRect = GetCellRect(i);
 
         // We use a helper class to clip the drawings this ensures that if we exit the scope
         // the clipping region is restored properly
         clClipperHelper clipper(dc);
-        if(hasHeader) {
+        if(hasHeader && !last_cell) {
             clipper.Clip(cellRect);
         }
 
@@ -422,44 +489,33 @@ void clRowEntry::Render(wxWindow* win, wxDC& dc, const clColours& c, int row_ind
                 wxRect buttonRect = GetButtonRect();
                 buttonRect.Deflate(1);
                 textXOffset += buttonRect.GetWidth();
-                if(m_tree->IsNativeTheme() && (!IS_OSX && !IS_MSW)) {
-                    int flags = wxCONTROL_CURRENT;
-                    if(IsExpanded()) {
-                        flags |= wxCONTROL_EXPANDED;
-                    }
-                    int button_width = wxSystemSettings::GetMetric(wxSYS_SMALLICON_X);
-                    wxRect modButtonRect = buttonRect;
-                    modButtonRect.SetWidth(button_width);
-                    modButtonRect.SetHeight(button_width);
-                    modButtonRect = modButtonRect.CenterIn(buttonRect);
-                    wxRendererNative::Get().DrawTreeItemButton(win, dc, modButtonRect, flags);
+
+                buttonRect = GetButtonRect();
+                if(textXOffset >= cellRect.GetWidth()) {
+                    // if we cant draw the button (off screen etc)
+                    SetRects(GetItemRect(), wxRect());
+                    continue;
+                }
+
+                buttonRect.Deflate((buttonRect.GetWidth() / 4), (buttonRect.GetHeight() / 4));
+                wxRect tribtn = buttonRect;
+                dc.SetPen(wxPen(buttonColour, 2));
+                if(IsExpanded()) {
+                    dc.SetPen(wxPen(buttonColour, 2));
+                    tribtn.SetHeight(tribtn.GetHeight() - tribtn.GetHeight() / 2);
+                    tribtn = tribtn.CenterIn(buttonRect);
+                    wxPoint middleLeft = wxPoint((tribtn.GetLeft() + tribtn.GetWidth() / 2), tribtn.GetBottom());
+                    dc.DrawLine(tribtn.GetTopLeft(), middleLeft);
+                    dc.DrawLine(tribtn.GetTopRight(), middleLeft);
                 } else {
-                    wxRect buttonRect = GetButtonRect();
-                    if(textXOffset >= cellRect.GetWidth()) {
-                        // if we cant draw the button (off screen etc)
-                        SetRects(GetItemRect(), wxRect());
-                        continue;
-                    }
+                    tribtn.SetWidth(tribtn.GetWidth() - tribtn.GetWidth() / 2);
+                    tribtn = tribtn.CenterIn(buttonRect);
 
-                    buttonRect.Deflate((buttonRect.GetWidth() / 3), (buttonRect.GetHeight() / 3));
-                    wxRect tribtn = buttonRect;
-                    dc.SetPen(wxPen(buttonColour, GetSizeDIP(2, win)));
-                    if(IsExpanded()) {
-                        tribtn.SetHeight(tribtn.GetHeight() - tribtn.GetHeight() / 2);
-                        tribtn = tribtn.CenterIn(buttonRect);
-                        wxPoint middleLeft = wxPoint((tribtn.GetLeft() + tribtn.GetWidth() / 2), tribtn.GetBottom());
-                        dc.DrawLine(tribtn.GetTopLeft(), middleLeft);
-                        dc.DrawLine(tribtn.GetTopRight(), middleLeft);
-                    } else {
-                        tribtn.SetWidth(tribtn.GetWidth() - tribtn.GetWidth() / 2);
-                        tribtn = tribtn.CenterIn(buttonRect);
-
-                        wxPoint middleLeft = wxPoint(tribtn.GetRight(), (tribtn.GetY() + (tribtn.GetHeight() / 2)));
-                        wxPoint p1 = tribtn.GetTopLeft();
-                        wxPoint p2 = tribtn.GetBottomLeft();
-                        dc.DrawLine(p1, middleLeft);
-                        dc.DrawLine(middleLeft, p2);
-                    }
+                    wxPoint middleLeft = wxPoint(tribtn.GetRight(), (tribtn.GetY() + (tribtn.GetHeight() / 2)));
+                    wxPoint p1 = tribtn.GetTopLeft();
+                    wxPoint p2 = tribtn.GetBottomLeft();
+                    dc.DrawLine(p1, middleLeft);
+                    dc.DrawLine(middleLeft, p2);
                 }
 
             } else {
@@ -509,11 +565,12 @@ void clRowEntry::Render(wxWindow* win, wxDC& dc, const clColours& c, int row_ind
         }
 
         // Draw the text
-        wxRect textRect(dc.GetTextExtent(cell.GetValueString()));
+        wxString text_to_render = GetTextForRendering(cell.GetValueString());
+        wxRect textRect(dc.GetTextExtent(text_to_render));
         textRect = textRect.CenterIn(rowRect, wxVERTICAL);
         int textY = textRect.GetY();
         int textX = (i == 0 ? itemIndent : clHeaderItem::X_SPACER) + textXOffset;
-        RenderText(win, dc, colours, cell.GetValueString(), textX, textY, i);
+        RenderText(win, dc, colours, text_to_render, textX, textY, i);
         textXOffset += textRect.GetWidth();
         textXOffset += X_SPACER;
 
@@ -522,18 +579,18 @@ void clRowEntry::Render(wxWindow* win, wxDC& dc, const clColours& c, int row_ind
             wxRect dropDownRect(cellRect.GetTopRight().x - rowRect.GetHeight(), rowRect.GetY(), rowRect.GetHeight(),
                                 rowRect.GetHeight());
             dropDownRect = dropDownRect.CenterIn(rowRect, wxVERTICAL);
-            DrawingUtils::DrawDropDownArrow(win, dc, dropDownRect, wxNullColour);
+            dropDownRect.Deflate(1);
+            dc.SetPen(colours.GetHeaderVBorderColour());
+            dc.SetBrush(colours.GetHeaderVBorderColour());
+            dc.DrawRectangle(dropDownRect);
+            dropDownRect.Inflate(1);
+            DrawingUtils::DrawDropDownArrow(win, dc, dropDownRect,
+                                            colours.IsLightTheme() ? wxColour("DARK GREY") : wxColour("WHITE"));
             // Keep the rect to test clicks
             cell.SetDropDownRect(dropDownRect);
             textXOffset += dropDownRect.GetWidth();
             textXOffset += X_SPACER;
 
-            // Draw a separator line between the drop down arrow and the rest of the cell content
-            dropDownRect.Deflate(3);
-            dropDownRect = dropDownRect.CenterIn(rowRect, wxVERTICAL);
-            dc.SetPen(wxPen(colours.GetHeaderVBorderColour(), 1, PEN_STYLE));
-            dc.DrawLine(dropDownRect.GetTopLeft(), dropDownRect.GetBottomLeft());
-
         } else {
             cell.SetDropDownRect(wxRect());
         }
@@ -556,6 +613,7 @@ void clRowEntry::RenderText(wxWindow* win, wxDC& dc, const clColours& colours, c
             RenderTextSimple(win, dc, colours, text, x, y, col);
             return;
         }
+        dc.SetFont(m_tree->GetDefaultFont());
 #ifdef __WXMSW__
         const wxColour& defaultTextColour =
             m_tree->IsNativeTheme() ? colours.GetItemTextColour()
@@ -575,10 +633,11 @@ void clRowEntry::RenderText(wxWindow* win, wxDC& dc, const clColours& colours, c
             rowRect.SetWidth(sz.GetWidth());
             if(is_match) {
                 // draw a match rectangle
-                dc.SetPen(matchBgColour);
-                dc.SetBrush(matchBgColour);
-                dc.SetTextForeground(matchTextColour);
-                dc.DrawRoundedRectangle(rowRect, 3.0);
+                dc.SetPen(matchBgColour.IsOk() ? matchBgColour : GetBgColour());
+                dc.SetBrush(matchBgColour.IsOk() ? matchBgColour : GetBgColour());
+                dc.SetTextForeground(matchTextColour.IsOk() ? matchTextColour : defaultTextColour);
+                rowRect.Deflate(1);
+                dc.DrawRoundedRectangle(rowRect, 0);
             } else {
                 dc.SetTextForeground(defaultTextColour);
             }
@@ -596,16 +655,27 @@ void clRowEntry::RenderTextSimple(wxWindow* win, wxDC& dc, const clColours& colo
 {
     wxUnusedVar(win);
     wxUnusedVar(col);
+
+    // fix multiline text
 #ifdef __WXMSW__
     if(m_tree->IsNativeTheme()) {
         dc.SetTextForeground(colours.GetItemTextColour());
         dc.DrawText(text, x, y);
     } else {
-        dc.SetTextForeground(IsSelected() ? colours.GetSelItemTextColour() : colours.GetItemTextColour());
+        if(!IsSelected()) {
+            dc.SetTextForeground(colours.GetItemTextColour());
+        } else {
+            dc.SetTextForeground(win->HasFocus() ? colours.GetSelItemTextColour()
+                                                 : colours.GetSelItemTextColourNoFocus());
+        }
         dc.DrawText(text, x, y);
     }
 #else
-    dc.SetTextForeground(IsSelected() ? colours.GetSelItemTextColour() : colours.GetItemTextColour());
+    if(!IsSelected()) {
+        dc.SetTextForeground(colours.GetItemTextColour());
+    } else {
+        dc.SetTextForeground(win->HasFocus() ? colours.GetSelItemTextColour() : colours.GetSelItemTextColourNoFocus());
+    }
     dc.DrawText(text, x, y);
 #endif
 }
@@ -685,26 +755,22 @@ int clRowEntry::CalcItemWidth(wxDC& dc, int rowHeight, size_t col)
     }
 
     clCellValue& cell = GetColumn(col);
-    wxFont f = GetFont().IsOk() ? GetFont() : m_tree->GetDefaultFont();
-    if(cell.GetFont().IsOk()) {
-        f = cell.GetFont();
-    }
-    dc.SetFont(f);
 
     int item_width = X_SPACER;
     if(cell.IsBool()) {
         // add the checkbox size
-        item_width += rowHeight;
+        item_width += clGetSize(rowHeight, m_tree);
         item_width += X_SPACER;
     } else if(cell.IsChoice()) {
-        item_width += rowHeight;
+        item_width += clGetSize(rowHeight, m_tree);
         item_width += X_SPACER;
     }
 
+    dc.SetFont(m_tree->GetDefaultFont());
     wxSize textSize = dc.GetTextExtent(cell.GetValueString());
     if((col == 0) && !IsListItem()) {
         // always make room for the twist button
-        item_width += rowHeight;
+        item_width += clGetSize(rowHeight, m_tree);
     }
     int bitmapIndex = cell.GetBitmapIndex();
     if(IsExpanded() && HasChildren() && cell.GetBitmapSelectedIndex() != wxNOT_FOUND) {
@@ -714,17 +780,17 @@ int clRowEntry::CalcItemWidth(wxDC& dc, int rowHeight, size_t col)
     if(bitmapIndex != wxNOT_FOUND) {
         const wxBitmap& bmp = m_tree->GetBitmap(bitmapIndex);
         if(bmp.IsOk()) {
-            item_width += X_SPACER;
+            item_width += clGetSize(X_SPACER, m_tree);
             item_width += bmp.GetScaledWidth();
-            item_width += X_SPACER;
+            item_width += clGetSize(X_SPACER, m_tree);
         }
     }
     if((col == 0) && !IsListItem()) {
         int itemIndent = (GetIndentsCount() * m_tree->GetIndent());
-        item_width += itemIndent;
+        item_width += clGetSize(itemIndent, m_tree);
     }
     item_width += textSize.GetWidth();
-    item_width += clHeaderItem::X_SPACER;
+    item_width += clGetSize(clHeaderItem::X_SPACER, m_tree);
     return item_width;
 }
 
@@ -920,32 +986,12 @@ const wxRect& clRowEntry::GetChoiceRect(size_t col) const
 
 void clRowEntry::RenderCheckBox(wxWindow* win, wxDC& dc, const clColours& colours, const wxRect& rect, bool checked)
 {
-#if 1
-    wxUnusedVar(win);
-    wxUnusedVar(colours);
-    wxRendererNative::Get().DrawCheckBox(win, dc, rect, checked ? wxCONTROL_CHECKED : wxCONTROL_NONE);
-#else
-    dc.SetPen(wxPen(colours.GetBorderColour(), 2));
-    dc.SetBrush(checked ? colours.GetBorderColour() : *wxTRANSPARENT_BRUSH);
-    dc.DrawRoundedRectangle(rect, 2.0);
+    // on mac/linux, use native drawings
+    int flags = wxCONTROL_CURRENT;
     if(checked) {
-        wxRect innerRect = rect;
-        innerRect.Deflate(5);
-        const wxColour& penColour = IsSelected() ? colours.GetSelItemTextColour() : colours.GetDarkBorderColour();
-        dc.SetPen(wxPen(penColour, 3));
-
-        wxPoint p1, p2, p3;
-        p1.x = innerRect.GetTopLeft().x;
-        p1.y = innerRect.GetTopLeft().y + (innerRect.GetHeight() / 2);
-
-        p2.x = innerRect.GetBottomLeft().x + (innerRect.GetWidth() / 3);
-        p2.y = innerRect.GetBottomLeft().y;
-
-        p3 = innerRect.GetTopRight();
-        dc.DrawLine(p1, p2);
-        dc.DrawLine(p2, p3);
+        flags |= wxCONTROL_CHECKED;
     }
-#endif
+    wxRendererNative::Get().DrawCheckBox(win, dc, rect, flags);
 }
 
 int clRowEntry::GetCheckBoxWidth(wxWindow* win)
