@@ -1,12 +1,15 @@
-#include "ColoursAndFontsManager.h"
 #include "clThemedSTC.hpp"
 
+#include "ColoursAndFontsManager.h"
+
 clThemedSTC::clThemedSTC(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style,
                          const wxString& name)
     : wxStyledTextCtrl(parent, id, pos, size, style, name)
 {
     LexerConf::Ptr_t lex = ColoursAndFontsManager::Get().GetLexer("text");
-    if(lex) { lex->Apply(this); }
+    if(lex) {
+        lex->Apply(this);
+    }
 }
 
 clThemedSTC::clThemedSTC() {}
@@ -17,7 +20,9 @@ bool clThemedSTC::Create(wxWindow* parent, wxWindowID id, const wxPoint& pos, co
     bool res = wxStyledTextCtrl::Create(parent, id, pos, size, style, name);
     if(res) {
         LexerConf::Ptr_t lex = ColoursAndFontsManager::Get().GetLexer("text");
-        if(lex) { lex->Apply(this); }
+        if(lex) {
+            lex->Apply(this);
+        }
     }
     return res;
 }
