@@ -6,7 +6,8 @@
 class WXDLLIMPEXP_SDK clToolBarButton : public clToolBarButtonBase
 {
 public:
-    clToolBarButton(clToolBar* parent, wxWindowID winid, const wxBitmap& bmp, const wxString& label = "");
+    clToolBarButton(clToolBar* parent, wxWindowID winid, size_t bitmapId = INVALID_BITMAP_ID,
+                    const wxString& label = "");
     virtual ~clToolBarButton();
 
 public:
