@@ -1,14 +1,16 @@
 #include "clToolBarButtonBase.h"
+
+#include "clToolBar.h"
 #include "drawingutils.h"
 
 // -----------------------------------------------
 // Button base
 // -----------------------------------------------
-clToolBarButtonBase::clToolBarButtonBase(clToolBar* parent, wxWindowID id, const wxBitmap& bmp, const wxString& label,
+clToolBarButtonBase::clToolBarButtonBase(clToolBar* parent, wxWindowID id, int bmpId, const wxString& label,
                                          size_t flags)
     : m_toolbar(parent)
     , m_id(id)
-    , m_bmp(bmp)
+    , m_bmpId(bmpId)
     , m_label(label)
     , m_flags(flags)
     , m_renderFlags(0)
@@ -16,7 +18,13 @@ clToolBarButtonBase::clToolBarButtonBase(clToolBar* parent, wxWindowID id, const
 {
 }
 
-clToolBarButtonBase::~clToolBarButtonBase() { wxDELETE(m_menu); }
+clToolBarButtonBase::~clToolBarButtonBase()
+{
+    wxDELETE(m_menu);
+    if(m_toolbar && m_toolbar->GetBitmaps()) {
+        m_toolbar->GetBitmaps()->Delete(m_bmpId);
+    }
+}
 
 void clToolBarButtonBase::Render(wxDC& dc, const wxRect& rect)
 {
@@ -26,25 +34,18 @@ void clToolBarButtonBase::Render(wxDC& dc, const wxRect& rect)
     wxColour textColour = colours.GetItemTextColour();
     wxColour penColour;
     wxColour buttonColour;
-#if defined(__WXMSW__) || defined(__WXOSX__)
-    wxColour bgHighlightColour("rgb(153, 209, 255)");
-    penColour = bgHighlightColour;
-#else
-    wxColour bgHighlightColour(wxSystemSettings::GetColour(wxSYS_COLOUR_HIGHLIGHT));
-    if(DrawingUtils::IsDark(bgHighlightColour)) { bgHighlightColour = bgHighlightColour.ChangeLightness(140); }
-#endif
 
     const wxColour bgColour = DrawingUtils::GetMenuBarBgColour(m_toolbar->HasFlag(clToolBar::kMiniToolBar));
     bool isdark = DrawingUtils::IsDark(bgColour);
     if(IsEnabled() && (IsPressed() || IsChecked())) {
-        wxColour pressBgColour = isdark ? bgColour.ChangeLightness(110) : bgColour.ChangeLightness(70);
+        wxColour pressBgColour = isdark ? bgColour.ChangeLightness(110) : bgColour.ChangeLightness(80);
         wxRect highlightRect = m_buttonRect;
         highlightRect.Inflate(1);
 
-        penColour = isdark ? pressBgColour.ChangeLightness(30) : pressBgColour;
+        penColour = isdark ? pressBgColour.ChangeLightness(120) : pressBgColour.ChangeLightness(80);
         dc.SetBrush(pressBgColour);
         dc.SetPen(penColour);
-        dc.DrawRoundedRectangle(highlightRect, 0);
+        dc.DrawRectangle(highlightRect);
         textColour = colours.GetSelItemTextColour();
         buttonColour = colours.GetSelbuttonColour();
 
@@ -75,9 +76,12 @@ void clToolBarButtonBase::Render(wxDC& dc, const wxRect& rect)
     wxCoord yy = 0;
     xx += m_toolbar->GetXSpacer();
 
+    const wxBitmap& m_bmp = m_toolbar->GetBitmap(m_bmpId);
     if(m_bmp.IsOk()) {
         wxBitmap bmp(m_bmp);
-        if(!IsEnabled()) { bmp = DrawingUtils::CreateDisabledBitmap(m_bmp); }
+        if(!IsEnabled()) {
+            bmp = DrawingUtils::CreateDisabledBitmap(m_bmp);
+        }
         yy = (m_buttonRect.GetHeight() - bmp.GetScaledHeight()) / 2 + m_buttonRect.GetY();
         dc.DrawBitmap(bmp, wxPoint(xx, yy));
         xx += bmp.GetScaledWidth();
@@ -115,3 +119,5 @@ void clToolBarButtonBase::SetMenu(wxMenu* menu)
     wxDELETE(m_menu);
     m_menu = menu;
 }
+
+const wxBitmap& clToolBarButtonBase::GetBitmap() const { return m_toolbar->GetBitmap(m_bmpId); }
