@@ -1,12 +1,19 @@
-#include "clScrollBar.h"
 #include "clTreeCtrl.h"
+
+#include "clRowEntry.h"
+#include "clScrollBar.h"
 #include "clTreeCtrlModel.h"
 #include "clTreeNodeVisitor.h"
+#include "drawingutils.h"
+#include "globals.h"
+#include "macros.h"
+
 #include <algorithm>
 #include <cmath>
 #include <cstdlib>
 #include <wx/app.h>
 #include <wx/dcbuffer.h>
+#include <wx/dcclient.h>
 #include <wx/dcgraph.h>
 #include <wx/dcmemory.h>
 #include <wx/dnd.h>
@@ -17,38 +24,93 @@
 #include <wx/utils.h>
 #include <wx/wupdlock.h>
 
+#if CL_BUILD
+#include "globals.h"
+#endif
+
 #ifdef __WXMSW__
 #include <uxtheme.h>
 #endif
 
-#define CHECK_PTR_RET(p) \
-    if(!p) { return; }
-
-#define CHECK_ITEM_RET(item) \
-    if(!item.IsOk()) { return; }
-
 #define CHECK_ITEM_RET_INVALID_ITEM(item) \
-    if(!item.IsOk()) { return wxTreeItemId(); }
+    if(!item.IsOk()) {                    \
+        return wxTreeItemId();            \
+    }
 
-#define CHECK_ITEM_RET_FALSE(item) \
-    if(!item.IsOk()) { return false; }
-
-#define CHECK_ROOT_RET() \
-    if(!m_model.GetRoot()) { return; }
+#define CHECK_ROOT_RET()     \
+    if(!m_model.GetRoot()) { \
+        return;              \
+    }
 
 wxDEFINE_EVENT(wxEVT_TREE_ITEM_VALUE_CHANGED, wxTreeEvent);
 wxDEFINE_EVENT(wxEVT_TREE_CHOICE, wxTreeEvent);
 
-static void MSWSetNativeTheme(wxWindow* win)
+namespace
 {
-#if defined(__WXMSW__) && defined(_WIN64)
+void SetNativeThemeMSW(wxWindow* win)
+{
+#ifdef __WXMSW__
+#if CL_BUILD
+    ::MSWSetWindowDarkTheme(win);
+#else
     SetWindowTheme((HWND)win->GetHWND(), wxT("Explorer"), NULL);
 #endif
+#endif
 }
 
+struct DCLocker {
+    wxDC* pdc = nullptr;
+    DCLocker(wxDC* d)
+        : pdc(d)
+    {
+    }
+    ~DCLocker() { wxDELETE(pdc); }
+};
+
+wxDC& CreateGCDC(wxDC& dc, wxGCDC& gdc, eRendererType t)
+{
+    wxGraphicsRenderer* renderer = nullptr;
+    switch(t) {
+    case eRendererType::RENDERER_DEFAULT:
+    case eRendererType::RENDERER_CAIRO:
+#if defined(__WXGTK__)
+        renderer = wxGraphicsRenderer::GetCairoRenderer();
+#else
+        renderer = wxGraphicsRenderer::GetDefaultRenderer();
+#endif
+        break;
+    case eRendererType::RENDERER_DIRECT2D:
+#if defined(__WXMSW__) && wxUSE_GRAPHICS_DIRECT2D
+        renderer = wxGraphicsRenderer::GetDirect2DRenderer();
+#else
+        renderer = wxGraphicsRenderer::GetDefaultRenderer();
+#endif
+        break;
+    }
+
+    wxGraphicsContext* context;
+    if(wxPaintDC* paintdc = wxDynamicCast(&dc, wxPaintDC)) {
+        context = renderer->CreateContext(*paintdc);
+
+    } else if(wxMemoryDC* memdc = wxDynamicCast(&dc, wxMemoryDC)) {
+        context = renderer->CreateContext(*memdc);
+
+    } else {
+        return dc;
+    }
+    context->SetAntialiasMode(wxANTIALIAS_DEFAULT);
+    gdc.SetGraphicsContext(context);
+    return gdc;
+}
+
+bool ShouldDrawBorder(long style) { return style & wxBORDER_MASK; }
+
+} // namespace
+
 clTreeCtrl::clTreeCtrl(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style)
-    : clControlWithItems(parent, id, pos, size, style | wxWANTS_CHARS)
+    : clControlWithItems(parent, id, pos, size, (style | wxWANTS_CHARS))
     , m_model(this)
+    , m_drawBorder(ShouldDrawBorder(style))
 {
     m_treeStyle = style & ~wxWINDOW_STYLE_MASK; // remove the non window style
     DoInitialize();
@@ -62,22 +124,22 @@ clTreeCtrl::clTreeCtrl()
 bool clTreeCtrl::Create(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style)
 {
     m_treeStyle = style & ~wxWINDOW_STYLE_MASK;
-    if(!clControlWithItems::Create(parent, id, pos, size, style | wxWANTS_CHARS)) { return false; }
+    m_drawBorder = ShouldDrawBorder(style);
+    if(!clControlWithItems::Create(parent, id, pos, size, (style | wxWANTS_CHARS))) {
+        return false;
+    }
     DoInitialize();
     return true;
 }
 
 void clTreeCtrl::UpdateLineHeight()
 {
-    wxMemoryDC tmpDC;
-    wxBitmap bmp(1, 1);
-    tmpDC.SelectObject(bmp);
-    wxGCDC gcdc(tmpDC);
+    wxClientDC dc(this);
+    dc.SetFont(GetDefaultFont());
 
-    gcdc.SetFont(GetDefaultFont());
-    wxSize textSize = gcdc.GetTextExtent("Tp");
+    wxSize textSize = dc.GetTextExtent("Tp");
 
-    SetLineHeight(clRowEntry::Y_SPACER + textSize.GetHeight() + clRowEntry::Y_SPACER);
+    SetLineHeight(m_spacerY + textSize.GetHeight() + m_spacerY);
     SetIndent(GetLineHeight());
 }
 
@@ -101,7 +163,7 @@ void clTreeCtrl::DoInitialize()
     // There is always a header
     GetHeader()->Add("");
     SetShowHeader(false);
-    MSWSetNativeTheme(this);
+    SetNativeThemeMSW(this);
 }
 
 clTreeCtrl::~clTreeCtrl()
@@ -121,10 +183,28 @@ clTreeCtrl::~clTreeCtrl()
 void clTreeCtrl::OnPaint(wxPaintEvent& event)
 {
     wxUnusedVar(event);
+
+#ifdef __WXMSW__
+    wxDC* dc_ptr = nullptr;
+    if(m_renderer == eRendererType::RENDERER_DIRECT2D) {
+        dc_ptr = new wxPaintDC(this);
+    } else {
+        dc_ptr = new wxAutoBufferedPaintDC(this);
+    }
+
+    DCLocker locker(dc_ptr);
+    PrepareDC(*dc_ptr);
+    wxGCDC gcdc;
+    wxDC& dc = CreateGCDC(*dc_ptr, gcdc, m_renderer);
+#elif defined(__WXMAC__)
+    wxPaintDC pdc(this);
+    PrepareDC(pdc);
+    wxGCDC dc(pdc);
+#else
     wxAutoBufferedPaintDC pdc(this);
     PrepareDC(pdc);
-
-    wxGCDC dc(pdc);
+    wxDC& dc = pdc;
+#endif
 
     // Call the parent's Render method
     Render(dc);
@@ -143,16 +223,22 @@ void clTreeCtrl::OnPaint(wxPaintEvent& event)
         needToUpdateScrollbar = true;
     }
     clRowEntry* firstItem = GetFirstItemOnScreen();
-    if(!firstItem) { return; }
+    if(!firstItem) {
+        return;
+    }
 
     // Get list of items to draw
     clRowEntry::Vec_t items;
     size_t maxItems = GetNumLineCanFitOnScreen();
-    if(maxItems == 0) { return; }
+    if(maxItems == 0) {
+        return;
+    }
     m_model.GetNextItems(firstItem, maxItems, items);
 
     // Always try to get maximum entries to draw on the canvas
-    if(items.empty()) { return; }
+    if(items.empty()) {
+        return;
+    }
     bool canScrollDown = GetVScrollBar()->CanScollDown();
 
     // An action took that requires us to try to maximimze the list
@@ -166,7 +252,9 @@ void clTreeCtrl::OnPaint(wxPaintEvent& event)
                                                                    // up to max-items -1, this means that the last item
                                                                    // is always fully visible
             firstItem = m_model.GetRowBefore(firstItem, true);
-            if(!firstItem) { break; }
+            if(!firstItem) {
+                break;
+            }
             items.insert(items.begin(), firstItem);
             needToUpdateScrollbar = true;
         }
@@ -182,7 +270,9 @@ void clTreeCtrl::OnPaint(wxPaintEvent& event)
             // basically what we are doing here is sliding the window (visible items) 1 row up
             items.erase(items.begin());
             clRowEntry* new_last_item = m_model.GetRowAfter(lastRow, true);
-            if(new_last_item) { items.push_back(new_last_item); }
+            if(new_last_item) {
+                items.push_back(new_last_item);
+            }
         }
     }
 
@@ -199,18 +289,26 @@ void clTreeCtrl::OnPaint(wxPaintEvent& event)
 
     // Keep the visible items
     m_model.SetOnScreenItems(items); // Keep track of the visible items
-    if(needToUpdateScrollbar) { CallAfter(&clTreeCtrl::UpdateScrollBar); }
+    if(needToUpdateScrollbar) {
+        CallAfter(&clTreeCtrl::UpdateScrollBar);
+    }
 
     // Update the header as well
-    if(GetHeader() && GetHeader()->IsShown()) { GetHeader()->Update(); }
+    if(GetHeader() && GetHeader()->IsShown()) {
+        GetHeader()->Update();
+    }
 }
 
 wxTreeItemId clTreeCtrl::InsertItem(const wxTreeItemId& parent, const wxTreeItemId& previous, const wxString& text,
                                     int image, int selImage, wxTreeItemData* data)
 {
     wxTreeItemId item = m_model.InsertItem(parent, previous, text, image, selImage, data);
-    DoUpdateHeader(item);
-    if(IsExpanded(parent)) { UpdateScrollBar(); }
+    if(!m_bulkInsert) {
+        DoUpdateHeader(item);
+        if(IsExpanded(parent)) {
+            UpdateScrollBar();
+        }
+    }
     return item;
 }
 
@@ -218,8 +316,12 @@ wxTreeItemId clTreeCtrl::AppendItem(const wxTreeItemId& parent, const wxString&
                                     wxTreeItemData* data)
 {
     wxTreeItemId item = m_model.AppendItem(parent, text, image, selImage, data);
-    DoUpdateHeader(item);
-    if(IsExpanded(parent)) { UpdateScrollBar(); }
+    if(!m_bulkInsert) {
+        DoUpdateHeader(item);
+        if(IsExpanded(parent)) {
+            UpdateScrollBar();
+        }
+    }
     return item;
 }
 
@@ -236,20 +338,24 @@ void clTreeCtrl::Expand(const wxTreeItemId& item)
 {
     CHECK_ITEM_RET(item);
     clRowEntry* child = m_model.ToPtr(item);
-    if(!child) return;
+    if(!child)
+        return;
     child->SetExpanded(true);
     m_maxList = true;
     DoUpdateHeader(item);
     UpdateScrollBar();
     Refresh();
-    if(GetVScrollBar() && GetVScrollBar()->IsShown()) { GetVScrollBar()->CallAfter(&clScrollBar::Update); }
+    if(GetVScrollBar() && GetVScrollBar()->IsShown()) {
+        GetVScrollBar()->CallAfter(&clScrollBar::Update);
+    }
 }
 
 void clTreeCtrl::Collapse(const wxTreeItemId& item)
 {
     CHECK_ITEM_RET(item);
     clRowEntry* child = m_model.ToPtr(item);
-    if(!child) return;
+    if(!child)
+        return;
     child->SetExpanded(false);
     m_maxList = true;
     UpdateScrollBar();
@@ -260,7 +366,9 @@ void clTreeCtrl::Collapse(const wxTreeItemId& item)
 void clTreeCtrl::SelectItem(const wxTreeItemId& item, bool select)
 {
     CHECK_ITEM_RET(item);
-    if((select && m_model.IsItemSelected(item)) || (!select && !m_model.IsItemSelected(item))) { return; }
+    if((select && m_model.IsItemSelected(item)) || (!select && !m_model.IsItemSelected(item))) {
+        return;
+    }
     m_model.SelectItem(item, select, false, true);
     Refresh();
 }
@@ -355,7 +463,9 @@ wxTreeItemId clTreeCtrl::HitTest(const wxPoint& point, int& flags, int& column)
 {
     column = wxNOT_FOUND;
     flags = 0;
-    if(!m_model.GetRoot()) { return wxTreeItemId(); }
+    if(!m_model.GetRoot()) {
+        return wxTreeItemId();
+    }
     for(size_t i = 0; i < m_model.GetOnScreenItems().size(); ++i) {
         const clRowEntry* item = m_model.GetOnScreenItems()[i];
 
@@ -385,10 +495,14 @@ wxTreeItemId clTreeCtrl::HitTest(const wxPoint& point, int& flags, int& column)
                         if(!checkboxRect.IsEmpty()) {
                             // Adjust the coordiantes incase we got h-scroll
                             checkboxRect.SetX(checkboxRect.GetX() - GetFirstColumn());
-                            if(checkboxRect.Contains(point)) { flags |= wxTREE_HITTEST_ONITEMSTATEICON; }
+                            if(checkboxRect.Contains(point)) {
+                                flags |= wxTREE_HITTEST_ONITEMSTATEICON;
+                            }
                         } else if(!dropDownRect.IsEmpty()) {
                             dropDownRect.SetX(dropDownRect.GetX() - GetFirstColumn());
-                            if(dropDownRect.Contains(point)) { flags |= wxTREE_HITTEST_ONDROPDOWNARROW; }
+                            if(dropDownRect.Contains(point)) {
+                                flags |= wxTREE_HITTEST_ONDROPDOWNARROW;
+                            }
                         }
                         column = col;
                         break;
@@ -407,7 +521,9 @@ wxTreeItemId clTreeCtrl::HitTest(const wxPoint& point, int& flags, int& column)
 
 void clTreeCtrl::UnselectAll()
 {
-    if(!m_model.GetRoot()) { return; }
+    if(!m_model.GetRoot()) {
+        return;
+    }
     m_model.UnselectAll();
     Refresh();
 }
@@ -420,9 +536,13 @@ wxPoint clTreeCtrl::DoFixPoint(const wxPoint& pt)
 
 void clTreeCtrl::EnsureVisible(const wxTreeItemId& item)
 {
-    if(!item.IsOk()) { return; }
+    if(!item.IsOk()) {
+        return;
+    }
     // Make sure that all parents of ítem are expanded
-    if(!m_model.ExpandToItem(item)) { return; }
+    if(!m_model.ExpandToItem(item)) {
+        return;
+    }
 
     // We need to paint to take place now so all the items will be assigned with the updated geometry
     Update();
@@ -432,9 +552,13 @@ void clTreeCtrl::EnsureVisible(const wxTreeItemId& item)
 void clTreeCtrl::DoEnsureVisible(const wxTreeItemId& item)
 {
     // scroll to the item
-    if(!item.IsOk()) { return; }
+    if(!item.IsOk()) {
+        return;
+    }
     clRowEntry* pNode = m_model.ToPtr(item);
-    if(IsItemVisible(pNode) && IsItemFullyVisible(pNode)) { return; }
+    if(IsItemVisible(pNode) && IsItemFullyVisible(pNode)) {
+        return;
+    }
     EnsureItemVisible(pNode, false); // make it visible at the bottom
     UpdateScrollBar();               // Make sure that the scrollbar fits the view
     Refresh();
@@ -457,7 +581,9 @@ void clTreeCtrl::OnMouseLeftDClick(wxMouseEvent& event)
         evt.SetEventObject(this);
         evt.SetItem(where);
         evt.SetInt(column);
-        if(GetEventHandler()->ProcessEvent(evt)) { return; }
+        if(GetEventHandler()->ProcessEvent(evt)) {
+            return;
+        }
 
         // Process the default action
         if(ItemHasChildren(where)) {
@@ -472,17 +598,21 @@ void clTreeCtrl::OnMouseLeftDClick(wxMouseEvent& event)
 
 bool clTreeCtrl::IsExpanded(const wxTreeItemId& item) const
 {
-    if(!item.GetID()) return false;
+    if(!item.GetID())
+        return false;
     clRowEntry* child = m_model.ToPtr(item);
-    if(!child) return false;
+    if(!child)
+        return false;
     return child->IsExpanded();
 }
 
 bool clTreeCtrl::ItemHasChildren(const wxTreeItemId& item) const
 {
-    if(!item.GetID()) return false;
+    if(!item.GetID())
+        return false;
     clRowEntry* child = m_model.ToPtr(item);
-    if(!child) return false;
+    if(!child)
+        return false;
     return child->HasChildren();
 }
 
@@ -493,20 +623,22 @@ void clTreeCtrl::SetIndent(int size)
     Refresh();
 }
 
-int clTreeCtrl::GetIndent() const { return m_model.GetIndentSize(); }
+int clTreeCtrl::GetIndent() const { return clGetSize(m_model.GetIndentSize(), this); }
 
 bool clTreeCtrl::IsEmpty() const { return m_model.IsEmpty(); }
 
 size_t clTreeCtrl::GetChildrenCount(const wxTreeItemId& item, bool recursively) const
 {
-    if(!item.GetID()) return 0;
+    if(!item.GetID())
+        return 0;
     clRowEntry* node = m_model.ToPtr(item);
     return node->GetChildrenCount(recursively);
 }
 
 void clTreeCtrl::DeleteChildren(const wxTreeItemId& item)
 {
-    if(!item.GetID()) return;
+    if(!item.GetID())
+        return;
     clRowEntry* node = m_model.ToPtr(item);
     node->DeleteAllChildren();
     UpdateScrollBar();
@@ -515,10 +647,12 @@ void clTreeCtrl::DeleteChildren(const wxTreeItemId& item)
 
 wxTreeItemId clTreeCtrl::GetFirstChild(const wxTreeItemId& item, wxTreeItemIdValue& cookie) const
 {
-    if(!item.GetID()) return wxTreeItemId();
+    if(!item.GetID())
+        return wxTreeItemId();
     clRowEntry* node = m_model.ToPtr(item);
     const clRowEntry::Vec_t& children = node->GetChildren();
-    if(children.empty()) return wxTreeItemId(); // No children
+    if(children.empty())
+        return wxTreeItemId(); // No children
     int* pidx = (int*)&cookie;
     int& idx = (*pidx);
     idx = 1; // the next item
@@ -527,12 +661,14 @@ wxTreeItemId clTreeCtrl::GetFirstChild(const wxTreeItemId& item, wxTreeItemIdVal
 
 wxTreeItemId clTreeCtrl::GetNextChild(const wxTreeItemId& item, wxTreeItemIdValue& cookie) const
 {
-    if(!item.GetID()) return wxTreeItemId();
+    if(!item.GetID())
+        return wxTreeItemId();
     int* pidx = (int*)&cookie;
     int& idx = (*pidx);
     clRowEntry* node = m_model.ToPtr(item);
     const clRowEntry::Vec_t& children = node->GetChildren();
-    if(idx >= (int)children.size()) return wxTreeItemId();
+    if(idx >= (int)children.size())
+        return wxTreeItemId();
     wxTreeItemId child(children[idx]);
     idx++;
     return child;
@@ -540,14 +676,16 @@ wxTreeItemId clTreeCtrl::GetNextChild(const wxTreeItemId& item, wxTreeItemIdValu
 
 wxString clTreeCtrl::GetItemText(const wxTreeItemId& item, size_t col) const
 {
-    if(!item.GetID()) return "";
+    if(!item.GetID())
+        return "";
     clRowEntry* node = m_model.ToPtr(item);
     return node->GetLabel(col);
 }
 
 wxTreeItemData* clTreeCtrl::GetItemData(const wxTreeItemId& item) const
 {
-    if(!item.GetID()) return nullptr;
+    if(!item.GetID())
+        return nullptr;
     clRowEntry* node = m_model.ToPtr(item);
     return node->GetClientObject();
 }
@@ -555,10 +693,14 @@ wxTreeItemData* clTreeCtrl::GetItemData(const wxTreeItemId& item) const
 void clTreeCtrl::DoMouseScroll(const wxMouseEvent& event)
 {
     CHECK_ROOT_RET();
-    if(!GetFirstItemOnScreen()) { return; }
+    if(!GetFirstItemOnScreen()) {
+        return;
+    }
 
     const clRowEntry::Vec_t& onScreenItems = m_model.GetOnScreenItems();
-    if(onScreenItems.empty()) { return; }
+    if(onScreenItems.empty()) {
+        return;
+    }
     clRowEntry* lastItem = onScreenItems.back();
     clRowEntry* firstItem = onScreenItems.front();
 
@@ -591,12 +733,16 @@ void clTreeCtrl::DoMouseScroll(const wxMouseEvent& event)
     }
     if(event.GetWheelRotation() > 0) { // Scrolling up
         m_model.GetPrevItems(GetFirstItemOnScreen(), std::abs((double)lines), items, false);
-        if(items.empty()) { return; }
+        if(items.empty()) {
+            return;
+        }
         SetFirstItemOnScreen(items.front()); // first item
         UpdateScrollBar();
     } else {
         m_model.GetNextItems(GetFirstItemOnScreen(), std::abs((double)lines), items, false);
-        if(items.empty()) { return; }
+        if(items.empty()) {
+            return;
+        }
         SetFirstItemOnScreen(items.back()); // the last item
         UpdateScrollBar();
     }
@@ -606,13 +752,18 @@ void clTreeCtrl::DoMouseScroll(const wxMouseEvent& event)
 void clTreeCtrl::DoBitmapAdded()
 {
     // Also, we adjust the indent size
-    if(!GetBitmaps()) { return; }
+    if(!GetBitmaps()) {
+        return;
+    }
+
     int heighestBitmap = 0;
     for(size_t i = 0; i < GetBitmaps()->size(); ++i) {
         const wxBitmap& bmp = GetBitmaps()->at(i);
-        if(bmp.IsOk()) { heighestBitmap = wxMax(heighestBitmap, bmp.GetScaledHeight()); }
+        if(bmp.IsOk()) {
+            heighestBitmap = wxMax(heighestBitmap, bmp.GetScaledHeight());
+        }
     }
-    heighestBitmap += 2 * clRowEntry::Y_SPACER;
+    heighestBitmap += 2 * m_spacerY;
     SetLineHeight(wxMax(heighestBitmap, GetLineHeight()));
     SetIndent(GetLineHeight());
 }
@@ -639,10 +790,14 @@ void clTreeCtrl::ProcessIdle()
             for(size_t i = 0; i < items.size(); ++i) {
                 bool new_state = hoveredNode == items[i];
                 bool old_state = items[i]->IsHovered();
-                if(!refreshNeeded) { refreshNeeded = (new_state != old_state); }
+                if(!refreshNeeded) {
+                    refreshNeeded = (new_state != old_state);
+                }
                 items[i]->SetHovered(hoveredNode == items[i]);
             }
-            if(refreshNeeded) { Refresh(); }
+            if(refreshNeeded) {
+                Refresh();
+            }
         }
     }
 }
@@ -681,7 +836,9 @@ void clTreeCtrl::CollapseAllChildren(const wxTreeItemId& item)
 wxTreeItemId clTreeCtrl::GetFirstVisibleItem() const
 {
     const clRowEntry::Vec_t& items = m_model.GetOnScreenItems();
-    if(items.empty()) { return wxTreeItemId(); }
+    if(items.empty()) {
+        return wxTreeItemId();
+    }
     return wxTreeItemId(items[0]);
 }
 
@@ -690,20 +847,32 @@ wxTreeItemId clTreeCtrl::GetPrevVisible(const wxTreeItemId& item) const { return
 
 wxTreeItemId clTreeCtrl::DoGetSiblingVisibleItem(const wxTreeItemId& item, bool next) const
 {
-    if(!item.IsOk()) { return wxTreeItemId(); }
+    if(!item.IsOk()) {
+        return wxTreeItemId();
+    }
     const clRowEntry::Vec_t& items = m_model.GetOnScreenItems();
-    if(items.empty()) { return wxTreeItemId(); }
+    if(items.empty()) {
+        return wxTreeItemId();
+    }
     clRowEntry* from = m_model.ToPtr(item);
     clRowEntry::Vec_t::const_iterator iter =
         std::find_if(items.begin(), items.end(), [&](clRowEntry* p) { return p == from; });
-    if(next && (iter == items.end())) { return wxTreeItemId(); }
-    if(!next && (iter == items.begin())) { return wxTreeItemId(); }
+    if(next && (iter == items.end())) {
+        return wxTreeItemId();
+    }
+    if(!next && (iter == items.begin())) {
+        return wxTreeItemId();
+    }
     if(next) {
         ++iter;
-        if(iter == items.end()) { return wxTreeItemId(); }
+        if(iter == items.end()) {
+            return wxTreeItemId();
+        }
     } else {
         --iter;
-        if(iter == items.begin()) { return wxTreeItemId(); }
+        if(iter == items.begin()) {
+            return wxTreeItemId();
+        }
     }
     return wxTreeItemId(*iter);
 }
@@ -715,7 +884,9 @@ wxTreeItemId clTreeCtrl::GetFocusedItem() const { return GetSelection(); }
 size_t clTreeCtrl::GetSelections(wxArrayTreeItemIds& selections) const
 {
     const clRowEntry::Vec_t& items = m_model.GetSelections();
-    if(items.empty()) { return 0; }
+    if(items.empty()) {
+        return 0;
+    }
     std::for_each(items.begin(), items.end(), [&](clRowEntry* item) { selections.Add(wxTreeItemId(item)); });
     return selections.size();
 }
@@ -727,17 +898,23 @@ bool clTreeCtrl::DoKeyDown(const wxKeyEvent& event)
     evt.SetEventObject(this);
     evt.SetKeyEvent(event);
     evt.SetItem(GetSelection()); // can be an invalid item
-    if(GetEventHandler()->ProcessEvent(evt)) { return true; }
+    if(GetEventHandler()->ProcessEvent(evt)) {
+        return true;
+    }
 
     // Let the parent process this
-    if(clControlWithItems::DoKeyDown(event)) { return false; }
+    if(clControlWithItems::DoKeyDown(event)) {
+        return false;
+    }
 
     if(!m_model.GetRoot()) {
         // we didnt process this event, carry on
         return true;
     }
     wxTreeItemId selectedItem = GetSelection();
-    if(!selectedItem.IsOk()) { return true; }
+    if(!selectedItem.IsOk()) {
+        return true;
+    }
 
     clRowEntry* row = m_model.ToPtr(selectedItem);
     if(event.GetKeyCode() == WXK_LEFT) {
@@ -780,13 +957,16 @@ bool clTreeCtrl::IsItemVisible(clRowEntry* item) const
 bool clTreeCtrl::IsItemFullyVisible(clRowEntry* item) const
 {
     const wxRect& itemRect = item->GetItemRect();
-    const wxRect clientRect = GetItemsRect();
+    wxRect clientRect = GetItemsRect();
+    // since we mainly ensure visibility on the Y axis, we need to make sure that the client rect
+    // has the same width as the item rect (incase of scrollbars, item rect will be wider)
+    clientRect.SetWidth(wxMax(itemRect.GetWidth(), clientRect.GetWidth()));
     return clientRect.Contains(itemRect);
 }
 
 void clTreeCtrl::EnsureItemVisible(clRowEntry* item, bool fromTop)
 {
-    CHECK_PTR_RET(item)
+    CHECK_PTR_RET(item);
     if(m_model.GetOnScreenItems().empty()) {
         // requesting to ensure item visibility before we drawn anyting on the screen
         // to reduce any strange behaviours (e.g. 1/2 screen is displayed while we can display more items)
@@ -794,15 +974,21 @@ void clTreeCtrl::EnsureItemVisible(clRowEntry* item, bool fromTop)
         m_maxList = true;
     }
 
-    if(IsItemFullyVisible(item)) { return; }
+    if(IsItemFullyVisible(item)) {
+        return;
+    }
     if(fromTop) {
         SetFirstItemOnScreen(item);
     } else {
         int max_lines_on_screen = GetNumLineCanFitOnScreen();
         clRowEntry::Vec_t items;
         m_model.GetPrevItems(item, max_lines_on_screen, items);
-        if(items.empty()) { return; }
-        if(!IsItemFullyVisible(item) && (items.size() > 1)) { items.erase(items.begin()); }
+        if(items.empty()) {
+            return;
+        }
+        if(!IsItemFullyVisible(item) && (items.size() > 1)) {
+            items.erase(items.begin());
+        }
         SetFirstItemOnScreen(items[0]);
     }
 }
@@ -835,7 +1021,9 @@ void clTreeCtrl::SetItemBackgroundColour(const wxTreeItemId& item, const wxColou
 wxColour clTreeCtrl::GetItemBackgroundColour(const wxTreeItemId& item, size_t col) const
 {
     clRowEntry* node = m_model.ToPtr(item);
-    if(!node) { return wxNullColour; }
+    if(!node) {
+        return wxNullColour;
+    }
     return node->GetBgColour(col);
 }
 
@@ -850,7 +1038,9 @@ void clTreeCtrl::SetItemTextColour(const wxTreeItemId& item, const wxColour& col
 wxColour clTreeCtrl::GetItemTextColour(const wxTreeItemId& item, size_t col) const
 {
     clRowEntry* node = m_model.ToPtr(item);
-    if(!node) { return wxNullColour; }
+    if(!node) {
+        return wxNullColour;
+    }
     return node->GetTextColour(col);
 }
 
@@ -868,7 +1058,9 @@ void clTreeCtrl::SetItemBold(const wxTreeItemId& item, bool bold, size_t col)
     clRowEntry* node = m_model.ToPtr(item);
     CHECK_PTR_RET(node);
     wxFont f = node->GetFont(col);
-    if(!f.IsOk()) { f = GetDefaultFont(); }
+    if(!f.IsOk()) {
+        f = GetDefaultFont();
+    }
     f.SetWeight(bold ? wxFONTWEIGHT_BOLD : wxFONTWEIGHT_NORMAL);
     node->SetFont(f, col);
 
@@ -888,7 +1080,9 @@ void clTreeCtrl::SetItemFont(const wxTreeItemId& item, const wxFont& font, size_
 wxFont clTreeCtrl::GetItemFont(const wxTreeItemId& item, size_t col) const
 {
     clRowEntry* node = m_model.ToPtr(item);
-    if(!node) { return wxNullFont; }
+    if(!node) {
+        return wxNullFont;
+    }
     return node->GetFont(col);
 }
 
@@ -924,7 +1118,9 @@ void clTreeCtrl::OnRightDown(wxMouseEvent& event)
         evt.SetItem(where);
         evt.SetInt(column);
         event.Skip(false);
-        if(GetEventHandler()->ProcessEvent(evt)) { return; }
+        if(GetEventHandler()->ProcessEvent(evt)) {
+            return;
+        }
         event.Skip();
     }
 }
@@ -940,7 +1136,9 @@ void clTreeCtrl::ScrollToRow(int firstLine)
     // Thumbtrack sends the top-line index in event.GetPosition()
     newTopLine = m_model.GetItemFromIndex(firstLine);
     if(newTopLine) {
-        if(newTopLine->IsHidden()) { newTopLine = newTopLine->GetFirstChild(); }
+        if(newTopLine->IsHidden()) {
+            newTopLine = newTopLine->GetFirstChild();
+        }
         SetFirstItemOnScreen(newTopLine);
         if(!GetVScrollBar()->CanScollDown()) {
             // we cant scroll down anymore
@@ -951,14 +1149,21 @@ void clTreeCtrl::ScrollToRow(int firstLine)
             AssignRects(items);
             if(!items.empty() && !IsItemFullyVisible(items.back()) && (firstLine != 0)) {
                 newTopLine = m_model.GetRowAfter(newTopLine, true);
-                if(newTopLine) { SetFirstItemOnScreen(newTopLine); }
+                if(newTopLine) {
+                    SetFirstItemOnScreen(newTopLine);
+                }
             }
         }
     }
-#if CL_USE_NATIVE_SCROLLBAR
+
+#if wxUSE_NATIVE_SCROLLBAR
     UpdateScrollBar();
 #endif
+
     Refresh();
+#ifndef __WXGTK3__
+    wxYieldIfNeeded();
+#endif
 }
 
 void clTreeCtrl::ScrollRows(int steps, wxDirection direction)
@@ -994,7 +1199,11 @@ void clTreeCtrl::ScrollRows(int steps, wxDirection direction)
         SelectItem(nextSelection);
     }
     EnsureItemVisible(m_model.ToPtr(nextSelection), fromTop);
+
     Refresh();
+#ifndef __WXGTK3__
+    wxYieldIfNeeded();
+#endif
     UpdateScrollBar();
 }
 
@@ -1024,7 +1233,9 @@ wxTreeItemId clTreeCtrl::GetPrevSibling(const wxTreeItemId& item) const
 wxTreeItemId clTreeCtrl::DoScrollLines(int numLines, bool up, wxTreeItemId from, bool selectIt)
 {
     wxTreeItemId selectedItem = from;
-    if(!selectedItem.IsOk()) { return wxTreeItemId(); }
+    if(!selectedItem.IsOk()) {
+        return wxTreeItemId();
+    }
 
     int counter = 0;
     wxTreeItemId nextItem = selectedItem;
@@ -1034,10 +1245,14 @@ wxTreeItemId clTreeCtrl::DoScrollLines(int numLines, bool up, wxTreeItemId from,
         } else {
             nextItem = m_model.GetItemAfter(selectedItem, true);
         }
-        if(nextItem.IsOk()) { selectedItem = nextItem; }
+        if(nextItem.IsOk()) {
+            selectedItem = nextItem;
+        }
         counter++;
     }
-    if(selectIt) { SelectItem(selectedItem); }
+    if(selectIt) {
+        SelectItem(selectedItem);
+    }
     return selectedItem;
 }
 
@@ -1049,10 +1264,14 @@ void clTreeCtrl::EnableStyle(int style, bool enable, bool refresh)
         m_treeStyle &= ~style;
     }
 
-    if(style == wxTR_ENABLE_SEARCH) { GetSearch().SetEnabled(enable); }
+    if(style == wxTR_ENABLE_SEARCH) {
+        GetSearch().SetEnabled(enable);
+    }
 
     // From this point on, we require a root item
-    if(!m_model.GetRoot()) { return; }
+    if(!m_model.GetRoot()) {
+        return;
+    }
 
     // When changing the wxTR_HIDE_ROOT style
     // we need to fix the indentation for each node in the tree
@@ -1060,15 +1279,21 @@ void clTreeCtrl::EnableStyle(int style, bool enable, bool refresh)
         m_model.GetRoot()->SetHidden(IsRootHidden());
         std::function<bool(clRowEntry*, bool)> UpdateIndentsFunc = [=](clRowEntry* node, bool visibleItem) {
             wxUnusedVar(visibleItem);
-            if(node->GetParent()) { node->SetIndentsCount(node->GetParent()->GetIndentsCount() + 1); }
+            if(node->GetParent()) {
+                node->SetIndentsCount(node->GetParent()->GetIndentsCount() + 1);
+            }
             return true;
         };
         clTreeNodeVisitor V;
         V.Visit(m_model.GetRoot(), false, UpdateIndentsFunc);
         wxTreeItemId newRoot(m_model.GetRoot()->GetFirstChild());
-        if(newRoot) { DoUpdateHeader(newRoot); }
+        if(newRoot) {
+            DoUpdateHeader(newRoot);
+        }
+    }
+    if(refresh) {
+        Refresh();
     }
-    if(refresh) { Refresh(); }
 }
 
 wxTreeItemId clTreeCtrl::GetItemParent(const wxTreeItemId& item) const
@@ -1088,7 +1313,9 @@ void clTreeCtrl::SetItemImage(const wxTreeItemId& item, int imageId, int openIma
 
 int clTreeCtrl::GetItemImage(const wxTreeItemId& item, bool selectedImage, size_t col) const
 {
-    if(!item.GetID()) { return wxNOT_FOUND; }
+    if(!item.GetID()) {
+        return wxNOT_FOUND;
+    }
     clRowEntry* node = m_model.ToPtr(item);
     return selectedImage ? node->GetBitmapSelectedIndex(col) : node->GetBitmapIndex(col);
 }
@@ -1106,7 +1333,9 @@ wxTreeItemId clTreeCtrl::GetRow(const wxPoint& pt) const
     int flags = 0;
     int column = wxNOT_FOUND;
     wxTreeItemId item = HitTest(pt, flags, column);
-    if(item.IsOk() && (flags & wxTREE_HITTEST_ONITEM)) { return item; }
+    if(item.IsOk() && (flags & wxTREE_HITTEST_ONITEM)) {
+        return item;
+    }
     return wxTreeItemId();
 }
 int clTreeCtrl::GetFirstItemPosition() const { return m_model.GetItemIndex(m_model.GetFirstItemOnScreen()); }
@@ -1141,13 +1370,17 @@ wxTreeItemId clTreeCtrl::FindPrev(const wxTreeItemId& from, const wxString& what
 
 void clTreeCtrl::HighlightText(const wxTreeItemId& item, bool b)
 {
-    if(!item.IsOk()) { return; }
+    if(!item.IsOk()) {
+        return;
+    }
     m_model.ToPtr(item)->SetHighlight(b);
 }
 
 void clTreeCtrl::ClearHighlight(const wxTreeItemId& item)
 {
-    if(!item.IsOk()) { return; }
+    if(!item.IsOk()) {
+        return;
+    }
     clRowEntry* row = m_model.ToPtr(item);
     row->SetHighlight(false);
     row->SetHighlightInfo({});
@@ -1196,8 +1429,10 @@ void clTreeCtrl::ClearAllHighlights()
 
 void clTreeCtrl::UpdateScrollBar()
 {
-    clControlWithItems::UpdateScrollBar();
-    m_scrollLines = 0;
+    if(!m_bulkInsert) {
+        clControlWithItems::UpdateScrollBar();
+        m_scrollLines = 0;
+    }
 }
 
 void clTreeCtrl::AddHeader(const wxString& label, const wxBitmap& bmp, int width) { DoAddHeader(label, bmp, width); }
@@ -1210,13 +1445,17 @@ void clTreeCtrl::DoAddHeader(const wxString& label, const wxBitmap& bmp, int wid
         GetHeader()->Clear();
     }
     clHeaderItem& col = GetHeader()->Add(label);
-    if(width > 0) { col.SetWidthValue(width); }
+    if(width > 0) {
+        col.SetWidthValue(width);
+    }
 }
 
 void clTreeCtrl::Check(const wxTreeItemId& item, bool check, size_t col)
 {
     clRowEntry* row = m_model.ToPtr(item);
-    if(!row) { return; }
+    if(!row) {
+        return;
+    }
     row->SetChecked(check, row->GetBitmapIndex(col), row->GetLabel(col), col);
 
     // Fire value changed event
@@ -1231,7 +1470,9 @@ void clTreeCtrl::Check(const wxTreeItemId& item, bool check, size_t col)
 bool clTreeCtrl::IsChecked(const wxTreeItemId& item, size_t col) const
 {
     clRowEntry* row = m_model.ToPtr(item);
-    if(!row) { return false; }
+    if(!row) {
+        return false;
+    }
     return row->IsChecked(col);
 }
 
@@ -1252,13 +1493,55 @@ void clTreeCtrl::PageUp() { ScrollRows(GetNumLineCanFitOnScreen(), wxUP); }
 
 void clTreeCtrl::SetDefaultFont(const wxFont& font)
 {
-    m_defaultFont = font;
+    clControlWithItems::SetDefaultFont(font);
     UpdateLineHeight();
     Refresh();
 }
 
-wxFont clTreeCtrl::GetDefaultFont() const
+void clTreeCtrl::Begin()
 {
-    if(m_defaultFont.IsOk()) { return m_defaultFont; }
-    return clScrolledPanel::GetDefaultFont();
+    m_bulkInsert = true;
+    m_oldSortFunc = m_model.GetSortFunction();
+    m_model.SetSortFunction(nullptr);
+}
+
+void clTreeCtrl::Commit()
+{
+    m_bulkInsert = false;
+    m_model.SetSortFunction(m_oldSortFunc);
+    const auto& items = m_model.GetOnScreenItems();
+
+    // update the header according to the visible items
+    for(const auto& item : items) {
+        DoUpdateHeader(item);
+    }
+    UpdateScrollBar();
+    Refresh();
+}
+
+void clTreeCtrl::SetLineSpacing(size_t pixels)
+{
+    m_spacerY = pixels;
+    UpdateLineHeight();
+    Refresh();
+}
+
+void clTreeCtrl::SetItemHighlightInfo(const wxTreeItemId& item, size_t start_pos, size_t len, size_t col)
+{
+    // sanity checks
+    CHECK_ITEM_RET(item);
+    clRowEntry* child = m_model.ToPtr(item);
+    CHECK_PTR_RET(child);
+
+    const wxString& text = child->GetLabel(col);
+    CHECK_EXPECTED_RETURN(start_pos + len < text.length(), true);
+
+    clMatchResult match_result;
+    Str3Arr_t triplet;
+    triplet[0] = text.Mid(0, start_pos);    // before the match
+    triplet[1] = text.Mid(start_pos, len);  // the string to highlight
+    triplet[2] = text.Mid(start_pos + len); // remainder
+
+    match_result.Add(col, triplet);
+    m_model.ToPtr(item)->SetHighlightInfo(match_result);
 }
