@@ -23,10 +23,12 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
+#include "cl_aui_dock_art.h"
+
+#include "ColoursAndFontsManager.h"
 #include "clStatusBar.h"
 #include "clSystemSettings.h"
 #include "clTabRenderer.h"
-#include "cl_aui_dock_art.h"
 #include "cl_command_event.h"
 #include "cl_config.h"
 #include "codelite_events.h"
@@ -34,13 +36,16 @@
 #include "event_notifier.h"
 #include "globals.h"
 #include "imanager.h"
+
 #include <editor_config.h>
 #include <wx/dcmemory.h>
 #include <wx/settings.h>
 #include <wx/xrc/xmlres.h>
 
 // --------------------------------------------
-static bool IsRectOK(wxDC& dc, const wxRect& rect)
+namespace
+{
+bool IsRectOK(wxDC& dc, const wxRect& rect)
 {
     const wxSize dc_size = dc.GetSize();
 
@@ -50,7 +55,8 @@ static bool IsRectOK(wxDC& dc, const wxRect& rect)
     return (true);
 }
 
-static wxString wxAuiChopText(wxDC& dc, const wxString& text, int max_size)
+#ifndef __WXMSW__
+wxString wxAuiChopText(wxDC& dc, const wxString& text, int max_size)
 {
     wxCoord x, y;
 
@@ -76,46 +82,31 @@ static wxString wxAuiChopText(wxDC& dc, const wxString& text, int max_size)
     ret += wxT("...");
     return ret;
 }
-
-static void clDockArtGetColours(wxColour& bgColour, wxColour& penColour)
-{
-    bgColour = clSystemSettings::GetColour(wxSYS_COLOUR_BTNFACE);
-    bgColour = bgColour.ChangeLightness(80);
-    penColour = clSystemSettings::GetColour(wxSYS_COLOUR_BTNTEXT);
-}
-
+#endif
+} // namespace
 // ------------------------------------------------------------
 
 clAuiDockArt::clAuiDockArt(IManager* manager)
     : m_manager(manager)
 {
-    EventNotifier::Get()->Bind(wxEVT_EDITOR_CONFIG_CHANGED, &clAuiDockArt::OnSettingsChanged, this);
-    m_captionColour = DrawingUtils::GetCaptionColour();
-    m_captionTextColour = DrawingUtils::GetCaptionTextColour();
-    m_useCustomCaptionColour = clConfig::Get().Read("UseCustomCaptionsColour", false);
+    EventNotifier::Get()->Bind(wxEVT_SYS_COLOURS_CHANGED, &clAuiDockArt::OnSettingsChanged, this);
 
-    m_bgColour = DrawingUtils::GetPanelBgColour();
-    EventNotifier::Get()->Bind(wxEVT_CMD_COLOURS_FONTS_UPDATED, [&](clCommandEvent& event) {
-        event.Skip();
-        m_bgColour = DrawingUtils::GetPanelBgColour();
-        bool useCustomColour = clConfig::Get().Read("UseCustomBaseColour", false);
-        if(useCustomColour) {
-            m_bgColour = clConfig::Get().Read("BaseColour", m_bgColour);
-        }
-
-        // Trigger a refresh
-        m_manager->GetDockingManager()->Update();
-    });
+    // initialise the colours to avoid assertion
+    clCommandEvent dummy;
+    OnSettingsChanged(dummy);
 }
 
 clAuiDockArt::~clAuiDockArt()
 {
-    EventNotifier::Get()->Unbind(wxEVT_EDITOR_CONFIG_CHANGED, &clAuiDockArt::OnSettingsChanged, this);
+    EventNotifier::Get()->Unbind(wxEVT_SYS_COLOURS_CHANGED, &clAuiDockArt::OnSettingsChanged, this);
 }
 
 void clAuiDockArt::DrawPaneButton(wxDC& dc, wxWindow* window, int button, int button_state, const wxRect& _rect,
                                   wxAuiPaneInfo& pane)
 {
+#ifdef __WXMSW__
+    wxAuiDefaultDockArt::DrawPaneButton(dc, window, button, button_state, _rect, pane);
+#else
     wxRect buttonRect = _rect;
 
     if(!IsRectOK(dc, _rect))
@@ -127,6 +118,10 @@ void clAuiDockArt::DrawPaneButton(wxDC& dc, wxWindow* window, int button, int bu
     } else {
         buttonRect.Deflate(1);
     }
+    if(buttonRect.GetHeight() < 2) {
+        // A wx3.0.x build may arrive here with a 1*1 rect -> a sigabort in libcairo
+        return;
+    }
     buttonRect = buttonRect.CenterIn(_rect);
     eButtonState buttonState = eButtonState::kNormal;
     switch(button_state) {
@@ -143,15 +138,12 @@ void clAuiDockArt::DrawPaneButton(wxDC& dc, wxWindow* window, int button, int bu
     }
 
     // Prepare the colours
-    wxColour bgColour, penColour;
-    clDockArtGetColours(bgColour, penColour);
-
     switch(button) {
     case wxAUI_BUTTON_CLOSE:
-        DrawingUtils::DrawButtonX(dc, window, buttonRect, penColour, bgColour, buttonState);
+        DrawingUtils::DrawButtonX(dc, window, buttonRect, m_penColour, m_bgColour, buttonState);
         break;
     case wxAUI_BUTTON_MAXIMIZE_RESTORE:
-        DrawingUtils::DrawButtonMaximizeRestore(dc, window, buttonRect, penColour, bgColour, buttonState);
+        DrawingUtils::DrawButtonMaximizeRestore(dc, window, buttonRect, m_penColour, m_bgColour, buttonState);
         break;
     default:
         // Make sure that the pane buttons are drawn with proper colours
@@ -159,40 +151,31 @@ void clAuiDockArt::DrawPaneButton(wxDC& dc, wxWindow* window, int button, int bu
         wxAuiDefaultDockArt::DrawPaneButton(dc, window, button, button_state, _rect, pane);
         break;
     }
+#endif
 }
 
 void clAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text, const wxRect& rect,
                                wxAuiPaneInfo& pane)
 {
     wxRect tmpRect;
+    window->PrepareDC(dc);
 
     if(!IsRectOK(dc, rect))
         return;
 
-#if defined(__WXOSX__)
+#ifdef __WXMAC__
     tmpRect = rect;
     tmpRect.Inflate(1);
-    window->PrepareDC(dc);
 
     // Prepare the colours
     wxFont f = DrawingUtils::GetDefaultGuiFont();
     dc.SetFont(f);
 
-    if(m_useCustomCaptionColour) {
-        dc.SetPen(m_captionColour);
-        dc.SetBrush(m_captionColour);
-        dc.DrawRectangle(tmpRect);
-    } else {
-        DrawingUtils::FillMenuBarBgColour(dc, tmpRect);
-    }
+    dc.SetPen(*wxTRANSPARENT_PEN);
+    dc.SetBrush(m_captionColour);
+    dc.DrawRectangle(tmpRect);
 
-    int caption_offset = 0;
-    if(pane.icon.IsOk()) {
-        DrawIcon(dc, tmpRect, pane);
-        caption_offset += pane.icon.GetWidth() + 3;
-    } else {
-        caption_offset = 3;
-    }
+    int caption_offset = 5;
     dc.SetTextForeground(m_captionTextColour);
     wxCoord w, h;
     dc.GetTextExtent(wxT("ABCDEFHXfgkj"), &w, &h);
@@ -212,8 +195,9 @@ void clAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text,
 
     wxString draw_text = wxAuiChopText(dc, text, clip_rect.width);
     wxSize textSize = dc.GetTextExtent(draw_text);
-
     dc.DrawText(draw_text, tmpRect.x + 3 + caption_offset, tmpRect.y + ((tmpRect.height - textSize.y) / 2));
+#elif defined(__WXMSW__)
+    wxAuiDefaultDockArt::DrawCaption(dc, window, text, rect, pane);
 #else
     tmpRect = rect;
     tmpRect.SetPosition(wxPoint(0, 0));
@@ -222,26 +206,16 @@ void clAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text,
         wxMemoryDC memDc;
         memDc.SelectObject(bmp);
 
-        wxGCDC gdc;
-        wxDC* pDC = NULL;
-        if(!DrawingUtils::GetGCDC(memDc, gdc)) {
-            pDC = &memDc;
-        } else {
-            pDC = &gdc;
-        }
-
         wxFont f = DrawingUtils::GetDefaultGuiFont();
-        pDC->SetFont(f);
+        memDc.SetFont(f);
 
-        wxColour captionBgColour, textColour;
-        clDockArtGetColours(captionBgColour, textColour);
-
-        pDC->SetPen(captionBgColour);
-        pDC->SetBrush(captionBgColour);
-        pDC->DrawRectangle(tmpRect);
+        // we inflate the rect by 1 to fix a one pixel glitch
+        memDc.SetPen(*wxTRANSPARENT_PEN);
+        memDc.SetBrush(m_captionColour);
+        tmpRect.Inflate(2);
+        memDc.DrawRectangle(tmpRect);
 
         int caption_offset = 5;
-
         wxRect clip_rect = tmpRect;
         clip_rect.width -= caption_offset; // text offset
         clip_rect.width -= 2;              // button padding
@@ -253,14 +227,14 @@ void clAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text,
             clip_rect.width -= m_buttonSize;
 
         // Truncate the text if needed
-        wxString draw_text = wxAuiChopText(gdc, text, clip_rect.width);
-        wxSize textSize = pDC->GetTextExtent(draw_text);
+        wxString draw_text = wxAuiChopText(memDc, text, clip_rect.width);
+        wxSize textSize = memDc.GetTextExtent(draw_text);
         wxRect textRect(textSize);
         textRect = textRect.CenterIn(clip_rect, wxVERTICAL);
         textRect.SetX(caption_offset);
 
-        pDC->SetTextForeground(textColour);
-        pDC->DrawText(draw_text, textRect.GetTopLeft());
+        memDc.SetTextForeground(m_captionTextColour);
+        memDc.DrawText(draw_text, textRect.GetTopLeft());
         memDc.SelectObject(wxNullBitmap);
     }
     dc.DrawBitmap(bmp, rect.x, rect.y, true);
@@ -269,44 +243,60 @@ void clAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text,
 
 void clAuiDockArt::DrawBackground(wxDC& dc, wxWindow* window, int orientation, const wxRect& rect)
 {
-    if(!IsRectOK(dc, rect))
-        return;
+#ifdef __WXMAC__
+    dc.SetBrush(m_bgColour);
+    dc.SetPen(m_bgColour);
+    dc.DrawRectangle(rect);
+#else
+    wxRect tmpRect = rect;
+    tmpRect.SetPosition(wxPoint(0, 0));
+    wxBitmap bmp(tmpRect.GetSize());
+
+    wxMemoryDC memDc;
+    memDc.SelectObject(bmp);
+
+    wxGCDC gdc(memDc);
+
+    gdc.SetPen(m_bgColour);
+    gdc.SetBrush(m_bgColour);
+    gdc.DrawRectangle(tmpRect);
+    memDc.SelectObject(wxNullBitmap);
+    dc.DrawBitmap(bmp, rect.GetTopLeft(), true);
+#endif
+}
+
+void clAuiDockArt::DrawBorder(wxDC& dc, wxWindow* window, const wxRect& rect, wxAuiPaneInfo& pane)
+{
+    wxUnusedVar(dc);
     wxUnusedVar(window);
+    wxUnusedVar(rect);
+    wxUnusedVar(pane);
+}
+
+void clAuiDockArt::DrawSash(wxDC& dc, wxWindow* window, int orientation, const wxRect& rect)
+{
     wxUnusedVar(orientation);
+    wxUnusedVar(window);
+
     dc.SetPen(m_bgColour);
     dc.SetBrush(m_bgColour);
     dc.DrawRectangle(rect);
 }
 
-void clAuiDockArt::DrawBorder(wxDC& dc, wxWindow* window, const wxRect& rect, wxAuiPaneInfo& pane)
-{
-    if(!IsRectOK(dc, rect))
-        return;
-    dc.SetPen(m_bgColour);
-    dc.SetBrush(*wxTRANSPARENT_BRUSH);
-    dc.DrawRectangle(rect);
-}
-
-void clAuiDockArt::DrawSash(wxDC& dc, wxWindow* window, int orientation, const wxRect& rect)
-{
-    if(!IsRectOK(dc, rect))
-        return;
-
-    wxUnusedVar(window);
-    wxUnusedVar(orientation);
-
-    wxColour c = clSystemSettings::GetColour(wxSYS_COLOUR_3DFACE);
-    c = c.ChangeLightness(DrawingUtils::IsDark(c) ? 115 : 85);
-
-    dc.SetPen(c);
-    dc.SetBrush(c);
-    dc.DrawRectangle(rect);
-}
-
-void clAuiDockArt::OnSettingsChanged(wxCommandEvent& event)
+void clAuiDockArt::OnSettingsChanged(clCommandEvent& event)
 {
     event.Skip();
-    m_captionColour = DrawingUtils::GetCaptionColour();
-    m_captionTextColour = DrawingUtils::GetCaptionTextColour();
-    m_useCustomCaptionColour = false;
+    m_bgColour = clSystemSettings::GetDefaultPanelColour();
+    if(DrawingUtils::IsDark(m_bgColour)) {
+        m_captionTextColour = wxColour(*wxWHITE).ChangeLightness(80);
+        m_captionColour = m_bgColour.ChangeLightness(50);
+        m_penColour = m_bgColour.ChangeLightness(50);
+    } else {
+        m_captionTextColour = wxColour(*wxBLACK).ChangeLightness(120);
+        m_captionColour = wxColour("#9CC0E7"); // Pale Cerulean
+        m_penColour = m_bgColour;
+    }
+
+    // trigger a refresh
+    clGetManager()->GetDockingManager()->Update();
 }
