@@ -25,13 +25,19 @@
 #ifndef COMPILER_H
 #define COMPILER_H
 
+#include "GCCMetadata.hpp"
+#include "asyncprocess.h"
 #include "codelite_exports.h"
 #include "configuration_object.h"
 #include "smart_ptr.h"
+
 #include <list>
 #include <map>
+#include <memory>
 #include <vector>
 #include <wx/arrstr.h>
+#include <wx/clntdata.h>
+#include <wx/regex.h>
 #include <wx/string.h>
 
 /**
@@ -48,7 +54,7 @@
 class WXDLLIMPEXP_SDK Compiler : public ConfObject
 {
 public:
-    enum { eErrorPattern, eWarningPattern };
+    enum eSeverity { kSevError, kSevWarning, kSevNote };
 
     enum CmpFileKind { CmpFileKindSource, CmpFileKindResource };
 
@@ -69,13 +75,23 @@ public:
         wxString lineNumberIndex;
         wxString fileNameIndex;
         wxString columnIndex;
+        std::shared_ptr<wxRegEx> re;
     };
-    
+
+    /// If a file matches a regular expression, this structure
+    /// will hold the information about it
+    struct PatternMatch : public wxClientData {
+        wxString file_path;
+        Compiler::eSeverity sev = kSevError;
+        int line_number = wxNOT_FOUND;
+        int column = wxNOT_FOUND;
+    };
+
     struct LinkLine {
         wxString lineFromFile;
         wxString line;
     };
-    
+
     enum eRegexType { kRegexVC = 0, kRegexGNU };
     typedef std::list<CmpInfoPattern> CmpListInfoPattern;
 
@@ -113,6 +129,8 @@ private:
     wxString GetGCCVersion() const;
     wxString GetIncludePath(const wxString& pathSuffix) const;
     wxArrayString POSIXGetIncludePaths() const;
+    bool IsMatchesPattern(CmpInfoPattern& pattern, eSeverity severity, const wxString& line,
+                          PatternMatch* match_result) const;
 
 public:
     typedef std::map<wxString, wxString>::const_iterator ConstIterator;
@@ -120,6 +138,21 @@ public:
     Compiler(wxXmlNode* node, Compiler::eRegexType regexType = Compiler::kRegexGNU);
     virtual ~Compiler();
 
+    /**
+     * @brief attempt to parse line and provide details about the parsed data
+     */
+    bool Matches(const wxString& line, PatternMatch* match_result);
+
+    /**
+     * @brief return { "PATH", "/compiler/bin:$PATH"} pair
+     */
+    void CreatePathEnv(clEnvList_t* env_list);
+
+    /**
+     * @brief check if this compiler is a 64 bit compiler
+     */
+    bool Is64BitCompiler();
+
     /**
      * @brief return the compiler default include paths
      */
@@ -146,10 +179,10 @@ public:
 
     void AddCompilerOption(const wxString& name, const wxString& desc);
     void AddLinkerOption(const wxString& name, const wxString& desc);
-    
+
     wxString GetLinkLine(const wxString& type, bool inputFromFile) const;
     void SetLinkLine(const wxString& type, const wxString& line, bool inputFromFile);
-    
+
     /**
      * @brief return list of builtin macros for this compiler instance
      * @return
@@ -203,11 +236,11 @@ public:
 
     void SetLinkerOptions(const CmpCmdLineOptions& cmpOptions) { m_linkerOptions = cmpOptions; }
 
-    void SetGenerateDependeciesFile(const bool& generateDependeciesFile)
+    void SetGenerateDependeciesFile(bool generateDependeciesFile)
     {
         this->m_generateDependeciesFile = generateDependeciesFile;
     }
-    const bool& GetGenerateDependeciesFile() const { return m_generateDependeciesFile; }
+    bool GetGenerateDependeciesFile() const { return IsGnuCompatibleCompiler() && m_generateDependeciesFile; }
     void SetReadObjectFilesFromList(bool readObjectFilesFromList)
     {
         this->m_readObjectFilesFromList = readObjectFilesFromList;
@@ -220,6 +253,15 @@ public:
         this->m_objectNameIdenticalToFileName = objectNameIdenticalToFileName;
     }
     bool GetObjectNameIdenticalToFileName() const { return m_objectNameIdenticalToFileName; }
+    /**
+     * @brief return the compiler metadata info
+     */
+    GCCMetadata GetMetadata() const;
+
+    /**
+     * @brief does this compiler support metadata object?
+     */
+    bool HasMetadata() const;
 };
 
 typedef SmartPtr<Compiler> CompilerPtr;
