@@ -1,5 +1,7 @@
-#include "drawingutils.h"
 #include "wxCustomStatusBar.h"
+
+#include "drawingutils.h"
+
 #include <wx/dcbuffer.h>
 #include <wx/dcclient.h>
 #include <wx/dcgraph.h>
@@ -37,6 +39,17 @@ void wxCustomStatusBarArt::DrawFieldSeparator(wxDC& dc, const wxRect& fieldRect)
     dc.DrawLine(topPt, bottomPt);
 }
 
+wxColour wxCustomStatusBarArt::GetBgColour() const
+{
+    wxColour c = clSystemSettings::GetDefaultPanelColour();
+    bool is_dark = DrawingUtils::IsDark(c);
+    return c.ChangeLightness(is_dark ? 115 : 85);
+}
+
+wxColour wxCustomStatusBarArt::GetPenColour() const { return GetBgColour(); }
+wxColour wxCustomStatusBarArt::GetTextColour() const { return clSystemSettings::GetColour(wxSYS_COLOUR_BTNTEXT); }
+wxColour wxCustomStatusBarArt::GetSeparatorColour() const { return GetBgColour(); }
+
 //========================------------------------------------
 //========================------------------------------------
 
@@ -224,7 +237,8 @@ void wxCustomStatusBar::OnPaint(wxPaintEvent& event)
 {
     wxAutoBufferedPaintDC abdc(this);
     PrepareDC(abdc);
-    wxGCDC dc(abdc);
+    wxGCDC gcdc;
+    wxDC& dc = DrawingUtils::GetGCDC(abdc, gcdc);
     wxRect rect = GetClientRect();
 
     dc.SetFont(DrawingUtils::GetDefaultGuiFont());
@@ -259,8 +273,8 @@ void wxCustomStatusBar::OnPaint(wxPaintEvent& event)
     wxRect mainRect(0, rect.y, offsetX, rect.height);
     dc.SetClippingRegion(mainRect);
     m_mainText->SetRect(mainRect);
-    m_mainText->Cast<wxCustomStatusBarFieldText>()->Render(dc, mainRect, m_art);
-    m_mainText->Cast<wxCustomStatusBarFieldText>()->SetTooltip(m_text);
+    m_mainText->Render(dc, mainRect, m_art);
+    m_mainText->SetTooltip(m_text);
     dc.DestroyClippingRegion();
 
     //===----------------------
@@ -358,15 +372,19 @@ void wxCustomStatusBar::SetText(const wxString& message, int secondsToLive)
 void wxCustomStatusBar::OnMouseMotion(wxMouseEvent& event)
 {
     event.Skip();
-    SetToolTip(wxEmptyString);
+    wxString current_tip = GetToolTipText();
+    wxString tip_text;
     wxPoint point = event.GetPosition();
     for(size_t i = 0; i < m_fields.size(); ++i) {
         if(m_fields.at(i)->HitTest(point)) {
-            SetToolTip(m_fields.at(i)->GetTooltip());
-            return;
+            tip_text = m_fields.at(i)->GetTooltip();
+            break;
         }
     }
-    SetToolTip(m_text);
+
+    if(current_tip != tip_text) {
+        SetToolTip(tip_text);
+    }
 }
 
 void wxCustomStatusBar::AnimationClicked(wxCustomStatusBarField* field)
