@@ -1,6 +1,6 @@
+#include "MainFrame.hpp"
 #include <wx/app.h>
 #include <wx/event.h>
-#include "MainFrame.h"
 #include <wx/image.h>
 
 // Define the MainApp
@@ -10,12 +10,13 @@ public:
     MainApp() {}
     virtual ~MainApp() {}
 
-    virtual bool OnInit() {
+    virtual bool OnInit()
+    {
         // Add the common image handlers
-        wxImage::AddHandler( new wxPNGHandler );
-        wxImage::AddHandler( new wxJPEGHandler );
+        wxImage::AddHandler(new wxPNGHandler);
+        wxImage::AddHandler(new wxJPEGHandler);
 
-        MainFrame *mainFrame = new MainFrame(NULL);
+        MainFrame* mainFrame = new MainFrame{ nullptr };
         SetTopWindow(mainFrame);
         return GetTopWindow()->Show();
     }
