@@ -58,7 +58,9 @@ GitEntry::GitEntry()
 {
     GitLocator locator;
     wxFileName gitpath;
-    if(locator.GetExecutable(gitpath)) { m_pathGIT = gitpath.GetFullPath(); }
+    if(locator.GetExecutable(gitpath)) {
+        m_pathGIT = gitpath.GetFullPath();
+    }
     locator.MSWGetGitShellCommand(m_gitShellCommand);
 }
 
@@ -108,8 +110,12 @@ void GitEntry::FromJSON(const JSONItem& json)
     }
 
     // override the colour only if it is a valid colour
-    if(!track.IsEmpty()) { m_colourTrackedFile = track; }
-    if(!diff.IsEmpty()) { m_colourDiffFile = diff; }
+    if(!track.IsEmpty()) {
+        m_colourTrackedFile = track;
+    }
+    if(!diff.IsEmpty()) {
+        m_colourDiffFile = diff;
+    }
 
     m_recentCommits = json.namedObject("m_recentCommits").toArrayString();
 
@@ -256,7 +262,9 @@ GitCommandsEntries& GitEntry::GetGitCommandsEntries(const wxString& entryName)
 
 void GitEntry::AddGitCommandsEntry(GitCommandsEntries& entries, const wxString& entryName)
 {
-    if(!m_commandsMap.count(entryName)) { m_commandsMap.insert(std::make_pair(entryName, entries)); }
+    if(!m_commandsMap.count(entryName)) {
+        m_commandsMap.insert(std::make_pair(entryName, entries));
+    }
     // Possible TODO: Append any novel items to the existing vector
 }
 
@@ -341,9 +349,12 @@ void GitEntry::AddRecentCommit(const wxString& commitMessage)
 {
     wxString msg = commitMessage;
     msg.Trim().Trim(false);
-    if(msg.IsEmpty()) return;
+    if(msg.IsEmpty())
+        return;
 
-    if(m_recentCommits.Index(msg) == wxNOT_FOUND) { m_recentCommits.Insert(msg, 0); }
+    if(m_recentCommits.Index(msg) == wxNOT_FOUND) {
+        m_recentCommits.Insert(msg, 0);
+    }
 
     if(m_recentCommits.size() > 20) {
         m_recentCommits.RemoveAt(m_recentCommits.size() - 1); // Remove the last commit
@@ -352,13 +363,19 @@ void GitEntry::AddRecentCommit(const wxString& commitMessage)
 
 void GitEntry::DeleteEntry(const wxString& workspace)
 {
-    if(m_entries.count(workspace)) { m_entries.erase(workspace); }
+    if(m_entries.count(workspace)) {
+        m_entries.erase(workspace);
+    }
 }
 
-wxString GitEntry::GetProjectLastRepoPath(const wxString& workspaceName, const wxString& projectName)
+wxString GitEntry::GetProjectUserEnteredRepoPath(const wxString& nameHash)
 {
-    wxString path;
-    if(workspaceName.empty() || projectName.empty()) return "";
+    wxString repoPath;
+    wxString projectName;
+    wxString workspaceName = nameHash.BeforeFirst('-', &projectName);
+    
+    if(workspaceName.empty() || projectName.empty())
+        return "";
 
     GitWorkspaceMap_t::iterator iter;
 
@@ -368,18 +385,21 @@ wxString GitEntry::GetProjectLastRepoPath(const wxString& workspaceName, const w
         m_workspacesMap.insert(std::make_pair(workspaceName, workspace));
     }
     iter = m_workspacesMap.find(workspaceName);
-    wxCHECK_MSG(iter != m_workspacesMap.end(), path, "Failed to add a workspace to the entry");
+    wxCHECK_MSG(iter != m_workspacesMap.end(), repoPath, "Failed to add a workspace to the entry");
 
     GitWorkspace workspace = iter->second;
-    path = workspace.GetProjectLastRepoPath(projectName);
+    repoPath = workspace.GetProjectUserEnteredRepoPath(projectName);
 
-    return path;
+    return repoPath;
 }
 
-void GitEntry::SetProjectLastRepoPath(const wxString& workspaceName, const wxString& projectName,
-                                      const wxString& lastRepoPath)
+void GitEntry::SetProjectUserEnteredRepoPath(const wxString& repoPath, const wxString& nameHash)
 {
-    if(workspaceName.empty() || projectName.empty()) return;
+    wxString projectName;
+    wxString workspaceName = nameHash.BeforeFirst('-', &projectName);
+    if(workspaceName.empty() || projectName.empty()) {
+        return;
+    }
 
     GitWorkspaceMap_t::iterator iter;
 
@@ -392,7 +412,7 @@ void GitEntry::SetProjectLastRepoPath(const wxString& workspaceName, const wxStr
     wxCHECK_RET(iter != m_workspacesMap.end(), "Failed to add a workspace to the entry");
 
     GitWorkspace& workspace = iter->second;
-    workspace.SetProjectLastRepoPath(projectName, lastRepoPath);
+    workspace.SetProjectUserEnteredRepoPath(projectName, repoPath);
 }
 
 void GitCommandsEntries::FromJSON(const JSONItem& json)
@@ -429,11 +449,11 @@ void GitCommandsEntries::ToJSON(JSONItem& arr) const
     arr.arrayAppend(obj);
 }
 
-const wxString GitWorkspace::GetProjectLastRepoPath(const wxString& projectName) { return m_projectData[projectName]; }
+const wxString GitWorkspace::GetProjectUserEnteredRepoPath(const wxString& projectName) { return m_userEnteredRepoPath[projectName]; }
 
-void GitWorkspace::SetProjectLastRepoPath(const wxString& projectName, const wxString& lastRepoPath)
+void GitWorkspace::SetProjectUserEnteredRepoPath(const wxString& projectName, const wxString& userEnteredRepoPath)
 {
-    m_projectData[projectName] = lastRepoPath;
+    m_userEnteredRepoPath[projectName] = userEnteredRepoPath;
 }
 
 void GitWorkspace::FromJSON(const JSONItem& json)
@@ -441,6 +461,7 @@ void GitWorkspace::FromJSON(const JSONItem& json)
     m_projectData.clear();
     SetWorkspaceName(json.namedObject("m_workspaceName").toString());
     m_projectData = json.namedObject("m_projectData").toStringMap();
+    m_userEnteredRepoPath = json.namedObject("m_userEnteredRepoPath").toStringMap();
 }
 
 void GitWorkspace::ToJSON(JSONItem& arr) const
@@ -449,6 +470,7 @@ void GitWorkspace::ToJSON(JSONItem& arr) const
         JSONItem json = JSONItem::createObject(GetWorkspaceName());
         json.addProperty("m_workspaceName", GetWorkspaceName());
         json.addProperty("m_projectData", m_projectData);
+        json.addProperty("m_userEnteredRepoPath", m_userEnteredRepoPath);
         arr.arrayAppend(json);
     }
 }
